@@ -46,17 +46,18 @@ assignOptions <- function(options) {
                 graphWidth 	= as.numeric(options[8]),
                 graphHeight	= as.numeric(options[9]),
                 device  	= options[10],
-                title 	 	= options[11],
-                datetime 	= options[12],
-                startAccel 	= options[13],
-                plotRawAccel 	= as.logical(options[14]),
-                plotFittedAccel = as.logical(options[15]),
-                plotRawForce 	= as.logical(options[16]),
-                plotFittedForce = as.logical(options[17]),
-                plotRawPower 	= as.logical(options[18]),
-                plotFittedPower = as.logical(options[19]),
-		triggersOnList  = as.numeric(unlist(strsplit(options[20], "\\;"))),
-		triggersOffList  = as.numeric(unlist(strsplit(options[21], "\\;")))
+		segmentMeters	= as.numeric(options[11]),
+                title 	 	= options[12],
+                datetime 	= options[13],
+                startAccel 	= options[14],
+                plotRawAccel 	= as.logical(options[15]),
+                plotFittedAccel = as.logical(options[16]),
+                plotRawForce 	= as.logical(options[17]),
+                plotFittedForce = as.logical(options[18]),
+                plotRawPower 	= as.logical(options[19]),
+                plotFittedPower = as.logical(options[20]),
+		triggersOnList  = as.numeric(unlist(strsplit(options[21], "\\;"))),
+		triggersOffList  = as.numeric(unlist(strsplit(options[22], "\\;")))
         ))
 }
 
@@ -234,6 +235,7 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
 }
 
 plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
+				  segmentMeters,
 				  title = "Test graph",
 				  subtitle = "",
 				  triggersOn = "",
@@ -312,9 +314,10 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
 
         #Plotting rawSpeed
         ylimits = c(0, sprintRawDynamics$rawVmax*1.05)
-        xlimits =c(0, sprintRawDynamics$time[sprintRawDynamics$endSample]*1.05)
-        #Calculing 5m lap times
-        splitPosition = min(sprintRawDynamics$testLength, 5)
+        xlimits =c(0, sprintRawDynamics$time[sprintRawDynamics$endSample])
+
+	#Calculing 5m lap times, this ca be configured as an exercise
+        splitPosition = min(sprintRawDynamics$testLength, segmentMeters)
         splitTime = interpolateXAtY(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                                   sprintRawDynamics$rawPosition[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                                   splitPosition)
@@ -322,9 +325,9 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
         meanForce =getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawForce, sprintRawDynamics$time[sprintRawDynamics$startSample], splitTime)
         meanPower =getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawPower, sprintRawDynamics$time[sprintRawDynamics$startSample], splitTime)
 
-        while(splitPosition[length(splitPosition)] + 5 < sprintRawDynamics$testLength)
+        while(splitPosition[length(splitPosition)] + segmentMeters < sprintRawDynamics$testLength)
         {
-                splitPosition = c(splitPosition, splitPosition[length(splitPosition)] + 5)
+                splitPosition = c(splitPosition, splitPosition[length(splitPosition)] + segmentMeters)
                 splitTime = c(splitTime, interpolateXAtY(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                                                      sprintRawDynamics$rawPosition[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                                                      splitPosition[length(splitPosition)]))
@@ -354,7 +357,7 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
         if(plotRawMeanSpeed)
         {
                 barplot(height = meanSpeed, width = diff(c(0,splitTime)), space = 0,
-                        ylim = ylimits,
+                        ylim = ylimits, xlim = xlimits,
                         xlab = "Time (s)", ylab = "Speed (m/s)",
                         yaxs = "i", xaxs = "i")
                 mtext(title, line = 2.5, cex = 1.5)
@@ -371,13 +374,13 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                 print("########")
                 lapTime = diff(c(0, splitTime))
                 textXPos = c(0,splitTime[1:length(splitTime) -1]) + lapTime/2
-                text(textXPos, meanSpeed, round(meanSpeed, digits = 2), pos = 3)
+                text(textXPos, meanSpeed/2, round(meanSpeed, digits = 2), pos = 3)
                 text(textXPos, 0, paste(round(lapTime, digits = 3), " s", sep = ""), pos = 3)
         } else
         {
                 plot(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                      sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                     type = "l", lty = 3, ylim = ylimits,
+                     type = "l", lty = 3, ylim = ylimits, xlim = xlimits,
                      main = title, xlab = "Time (s)", ylab = "Speed (m/s)",
                      yaxs = "i", xaxs = "i")
                 lines(x = c(0,sprintRawDynamics$time[sprintRawDynamics$startSample]), y = c(0,sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample]))
@@ -410,7 +413,7 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                         par(new = TRUE)
                         plot(c(0,sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample]),
                              c(0,sprintRawDynamics$rawAccel[(sprintRawDynamics$startSample + 0):(sprintRawDynamics$endSample + 0)]),
-                             ylim = ylimits,
+                             ylim = ylimits, xlim = xlimits,
                              type = "l", col = "magenta",
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
@@ -430,7 +433,8 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                         #Plotting rawAccel
                         par(new = TRUE)
                         plot(sprintFittedDynamics$t.fitted, sprintFittedDynamics$a.fitted,
-                             ylim = ylimits, type = "l", col = "magenta", lty = 2, lwd = 2,
+                             ylim = ylimits, xlim = xlimits,
+                             type = "l", col = "magenta", lty = 2, lwd = 2,
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
 
@@ -455,7 +459,8 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                         #Plotting rawForce
                         par(new = TRUE)
                         plot(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample], sprintRawDynamics$rawForce[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                             ylim = ylimits, type = "l", col = "blue",
+                             ylim = ylimits, xlim = xlimits,
+                             type = "l", col = "blue",
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
                         legendText = c(legendText, paste("F max (raw) =", round(sprintRawDynamics$rawFmax, digits = 2), "N"))
@@ -469,7 +474,8 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                         #Plotting fittedForce
                         par(new = TRUE)
                         plot(sprintFittedDynamics$t.fitted, sprintFittedDynamics$f.fitted,
-                             ylim = ylimits, type = "l", col = "blue", lty = 2, lwd = 2,
+                             ylim = ylimits, xlim = xlimits,
+                             type = "l", col = "blue", lty = 2, lwd = 2,
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
 
@@ -489,8 +495,7 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                 ylimits = c(min(sprintRawDynamics$rawForce[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95,
                             max(c(sprintRawDynamics$rawFmax, sprintFittedDynamics$fmax.fitted)*1.05))
                 plot(NULL, NULL,
-                     ylim = ylimits,
-                     xlim = c(sprintRawDynamics$time[sprintRawDynamics$startSample], sprintRawDynamics$time[sprintRawDynamics$endSample]),
+                     ylim = ylimits, xlim = xlimits,
                      xlab = "", ylab = "",
                      axes = FALSE, yaxs = "i", xaxs = "i")
                 text(splitTime[1]*0.2, meanForce[1], paste(round(meanForce[1], digits = 2), "N"), col = "blue")
@@ -517,7 +522,8 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                         #Plotting rawPower
                         par(new = TRUE)
                         plot(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample], sprintRawDynamics$rawPower[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                             ylim = ylimits, type = "l", col = "red",
+                             ylim = ylimits, xlim = xlimits,
+                             type = "l", col = "red",
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
                         legendText = c(legendText, paste("P max (raw) =", round(sprintRawDynamics$rawPmax, digits = 2), "N"))
@@ -531,7 +537,8 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                         #Plotting fittedPower
                         par(new = TRUE)
                         plot(sprintFittedDynamics$t.fitted, sprintFittedDynamics$p.fitted
-                             , ylim = ylimits , type = "l", col = "red", lty = 2, lwd = 2,
+                             ,ylim = ylimits , xlim = xlimits
+                             ,type = "l", col = "red", lty = 2, lwd = 2,
                              ,xlab = "", ylab = ""
                              ,axes = FALSE, yaxs = "i", xaxs = "i")
                         text(x = sprintFittedDynamics$tpmax.fitted, y = sprintFittedDynamics$pmax.fitted
@@ -559,8 +566,8 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                 ylimits = c(min(sprintRawDynamics$rawPower[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95,
                             max(c(sprintRawDynamics$rawPmax, sprintFittedDynamics$pmax.fitted)*1.05))
                 plot(NULL, NULL,
-                     ylim = ylimits,
-                     xlim = c(sprintRawDynamics$time[sprintRawDynamics$startSample], sprintRawDynamics$time[sprintRawDynamics$endSample]),
+                     ylim = ylimits, xlim = xlimits,
+                     #xlim = c(sprintRawDynamics$time[sprintRawDynamics$startSample], sprintRawDynamics$time[sprintRawDynamics$endSample]),
                      xlab = "", ylab = "",
                      axes = FALSE, yaxs = "i", xaxs = "i")
                 text(splitTime[1]*0.8, meanPower[1], paste(round(meanPower[1], digits = 2), "W"), col = "red")
@@ -648,6 +655,8 @@ getTrimmingSamples <- function(totalTime, position, speed, accel, testLength, st
 
 tryNLS <- function(data){
         print("#######Entering tryNLS#########")
+        print("data:")
+        print(data)
         tryCatch (
                 {
                         model = nls(speed ~ Vmax*(1-exp(-K*time)), data,
@@ -678,6 +687,7 @@ testEncoderCJ <- function(filename, testLength, mass, personHeight, tempC, start
                 sprintFittedDynamics = getDynamicsFromSprint(K = sprintRawDynamics$K, Vmax = sprintRawDynamics$Vmax, mass, tempC, personHeight)
                 print(paste("K =",sprintFittedDynamics$K.fitted, "Vmax =", sprintFittedDynamics$Vmax.fitted))
                 plotSprintFromEncoder(sprintRawDynamic = sprintRawDynamics, sprintFittedDynamics = sprintFittedDynamics,
+				      segmentMeters = op$segmentMeters,
                                       title = op$title,
                                       subtitle = op$datetime,
 				      triggersOn = op$triggersOnList,
