@@ -24,11 +24,17 @@ using Mono.Unix;
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * Copyright (C) 2016-2017   Carles Pina i Estany <carles@pina.cat>
+ * Copyright (C) 2019-2020   Xavier de Blas <xaviblas@gmail.com>
  */
 
+/*
+ * note there is a diagram on diagrams/processes/import
+ */
 
 class ChronojumpImporter
 {
+	public string MessageToPulsebar;
+
 	// Database that it's importing from
 	private string sourceFile;
 
@@ -42,6 +48,11 @@ class ChronojumpImporter
 	// a new session, otherwise it will import it into the session indicated by it
 	private int destinationSession;
 
+	// to debug to a file if debug mode is started on preferences;
+	private bool debugToFile;
+
+	Preferences.pythonVersionEnum pythonVersion;
+
 	Gtk.Window parentWindow;
 
 	// Result struct holds the output, error and success operations. It's used to pass
@@ -62,15 +73,25 @@ class ChronojumpImporter
 
 	// ChronojumpImporter class imports a specific session from sourceFile to destinationFile.
 	// The main method is "import()" which does all the work.
-	public ChronojumpImporter(Gtk.Window parentWindow, string sourceFile, string destinationFile, int sourceSession, int destinationSession)
+	public ChronojumpImporter(Gtk.Window parentWindow, string sourceFile, string destinationFile,
+			int sourceSession, int destinationSession, bool debugToFile, Preferences.pythonVersionEnum pythonVersion)
 	{
 		this.parentWindow = parentWindow;
 		this.sourceFile = sourceFile;
 		this.destinationFile = destinationFile;
 		this.sourceSession = sourceSession;
 		this.destinationSession = destinationSession;
+		this.debugToFile = debugToFile;
+
+		this.pythonVersion = pythonVersion;
+
+		MessageToPulsebar = "";
 	}
 
+	/*
+	 * interesting method for showing a dialog on the future
+	 * now we do not used because there is a notebook on session_load
+	 *
 	// Shows a dialogue to the user and lets him cancel the operation. The dialog information depends on
 	// this class configuration: depends if the session is going to be inserted in a new session or an
 	// existing one.
@@ -78,7 +99,7 @@ class ChronojumpImporter
 	public Gtk.ResponseType showImportConfirmation()
 	{
 		string message;
-		string sessionName = getSessionName (sourceFile, sourceSession);
+		string sessionName = GetSessionName (sourceFile, sourceSession);
 
 		if (importsToNew ()) {
 			// We don't need any confirmation to import into a new session (the user could delete it easily if it was a mistake)
@@ -101,18 +122,7 @@ class ChronojumpImporter
 			return response;
 		}
 	}
-
-	public void showImportCorrectlyFinished()
-	{
-		string message;
-
-		if (importsToNew()) {
-			message = Catalog.GetString ("Imported to a new session. You can load it now in Session - Load.");
-		} else {
-			message = Catalog.GetString ("Data merged into the open session.");
-		}
-		new DialogMessage (Catalog.GetString("Chronojump importer"), Constants.MessageTypes.INFO, message);
-	}
+	*/
 
 	private bool importsToNew()
 	{
@@ -126,12 +136,54 @@ class ChronojumpImporter
 	// tries to import a newer chronojump version.
 	public Result import()
 	{
+		//1) create temp dir for forceSensor and runEncoder and copy files there, original files will not be used
+		//   no need to be done for encoder files because there we will not to change filename
+		MessageToPulsebar = "Copying temporary files";
+
+LogB.Information("import A ");
+		string tempImportDir = Util.GetDatabaseTempImportDir();
+		if(Directory.Exists(tempImportDir))
+		{
+			try {
+				var dir = new DirectoryInfo(@tempImportDir);
+				dir.Delete(true); //recursive delete
+			} catch {
+				return new Result (false, "Could not delete directory: " + tempImportDir);
+			}
+		}
+LogB.Information("import B ");
+		string forceSensorName = "forceSensor";
+		string raceAnalyzerName = "raceAnalyzer";
+LogB.Information("import C ");
+		Directory.CreateDirectory(tempImportDir);
+LogB.Information("import D ");
+		Directory.CreateDirectory(Path.Combine(tempImportDir, forceSensorName, sourceSession.ToString()));
+LogB.Information("import E ");
+		Directory.CreateDirectory(Path.Combine(tempImportDir, raceAnalyzerName, sourceSession.ToString()));
+LogB.Information("import F ");
+
+		string sourceDir = Path.GetDirectoryName(sourceFile);
+		if(Directory.Exists(Path.Combine(sourceDir, "..", forceSensorName, sourceSession.ToString())))
+			foreach (FileInfo file in new DirectoryInfo(Path.Combine(sourceDir, "..", forceSensorName, sourceSession.ToString())).GetFiles())
+				file.CopyTo(Path.Combine(tempImportDir, forceSensorName, sourceSession.ToString(), file.Name));
+
+LogB.Information("import G ");
+		if(Directory.Exists(Path.Combine(sourceDir, "..", raceAnalyzerName, sourceSession.ToString())))
+			foreach (FileInfo file in new DirectoryInfo(Path.Combine(sourceDir, "..", raceAnalyzerName, sourceSession.ToString())).GetFiles())
+				file.CopyTo(Path.Combine(tempImportDir, raceAnalyzerName, sourceSession.ToString(), file.Name));
+
+LogB.Information("import H ");
+
+		//2) prepare SQL files
+
+		MessageToPulsebar = "Preparing database";
 		string temporarySourceFile = Path.GetTempFileName ();
 		File.Copy (sourceFile, temporarySourceFile, true);
 
 		Result sourceDatabaseVersion = getDatabaseVersionFromFile (temporarySourceFile);
 		Result destinationDatabaseVersion = getDatabaseVersionFromFile (destinationFile);
 
+LogB.Information("import A ");
 		if (! sourceDatabaseVersion.success)
 			return sourceDatabaseVersion;
 
@@ -141,16 +193,21 @@ class ChronojumpImporter
 		float destinationDatabaseVersionNum = float.Parse (destinationDatabaseVersion.output);
 		float sourceDatabaseVersionNum = float.Parse (sourceDatabaseVersion.output);
 
+		//3 check version of database to be imported
+
+		MessageToPulsebar = "Checking version";
 		if (destinationDatabaseVersionNum < sourceDatabaseVersionNum) {
 			return new Result (false, Catalog.GetString ("Trying to import a newer database version than this Chronojump\n" +
 				"Please, update the running Chronojump."));
 		} else if (destinationDatabaseVersionNum > sourceDatabaseVersionNum) {
 			LogB.Debug ("chronojump-importer version before update: ", sourceDatabaseVersion.output);
+			MessageToPulsebar = "Updating database";
 			updateDatabase (temporarySourceFile);
 			string versionAfterUpdate = getDatabaseVersionFromFile (temporarySourceFile).output;
 			LogB.Debug ("chronojump-importer version after update: ", versionAfterUpdate);
 		}
 
+		MessageToPulsebar = "Starting import";
 		List<string> parameters = new List<string> ();
 		parameters.Add ("--source");
 		parameters.Add (temporarySourceFile);
@@ -160,6 +217,8 @@ class ChronojumpImporter
 		// encoder files
 		parameters.Add ("--source_base_directory");
 		parameters.Add (Path.Combine(Path.GetDirectoryName(sourceFile), "..")); 
+		parameters.Add ("--source_temp_directory");
+		parameters.Add (Util.GetDatabaseTempImportDir());
 		parameters.Add ("--destination");
 		parameters.Add (destinationFile);
 		parameters.Add ("--source_session");
@@ -169,9 +228,15 @@ class ChronojumpImporter
 			parameters.Add ("--destination_session");
 			parameters.Add (Convert.ToString (destinationSession));
 		}
+		parameters.Add ("--debug_to_file");
+		if(debugToFile)
+			parameters.Add (Path.Combine(Path.GetTempPath(), "chronojumpImportDebug.txt"));
+		else
+			parameters.Add ("NONE");
 
-		Result result = executeChronojumpImporter (parameters);
+		Result result = executeChronojumpImporter (parameters, pythonVersion);
 
+		MessageToPulsebar = "Done!";
 		File.Delete (temporarySourceFile);
 
 		return result;
@@ -189,13 +254,15 @@ class ChronojumpImporter
 		Sqlite.setSqlFilePath (databaseFile);
 		Sqlite.Connect ();
 
+		Sqlite.UpdatingDBFrom = Sqlite.UpdatingDBFromEnum.IMPORTED_SESSION;
+
 		Sqlite.ConvertToLastChronojumpDBVersion ();
 
 		classOriginalState.writeAttributes (classOriginalState);
 		Sqlite.Connect ();
 	}
 
-	private static Result getImporterInformation(string filePath)
+	private static Result getImporterInformation(string filePath, Preferences.pythonVersionEnum pythonVersion)
 	{
 		// If Result.success == true Result.output contains a valid JSON string.
 		// It's a string and not a JsonValue for convenience with other methods (at the moment).
@@ -207,7 +274,7 @@ class ChronojumpImporter
 		parameters.Add (filePath);
 		parameters.Add ("--json_information");
 
-		Result result = executeChronojumpImporter (parameters);
+		Result result = executeChronojumpImporter (parameters, pythonVersion);
 
 		if (result.success) {
 			try {
@@ -223,9 +290,9 @@ class ChronojumpImporter
 		}
 	}
 
-	private static string getSessionName(string filePath, int sessionId)
+	public static string GetSessionName(string filePath, int sessionId, Preferences.pythonVersionEnum pythonVersion)
 	{
-		Result information = getImporterInformation (filePath);
+		Result information = getImporterInformation (filePath, pythonVersion);
 		if (information.success == false) {
 			// This shouldn't happen, other getImporterInformation is used in different ways.
 			LogB.Information ("chronojumpImporter::getSessionName failed. Output:" + information.output + "Error:" + information.error);
@@ -251,7 +318,7 @@ class ChronojumpImporter
 
 	private Result getDatabaseVersionFromFile(string filePath)
 	{
-		Result information = getImporterInformation (filePath);
+		Result information = getImporterInformation (filePath, pythonVersion);
 
 		if (information.success) {
 			JsonValue json = JsonValue.Parse (information.output);
@@ -261,18 +328,24 @@ class ChronojumpImporter
 		}
 	}
 
-	private static Result executeChronojumpImporter(List<string> parameters)
+	private static Result executeChronojumpImporter(List<string> parameters, Preferences.pythonVersionEnum pythonVersion)
 	{
 		string importer_executable;
 
 		if (UtilAll.IsWindows()) {
 			// On Windows we execute the .exe file (it's the Python with py2exe)
-			importer_executable = System.IO.Path.Combine (Util.GetPrefixDir (), "bin\\chronojump-importer\\chronojump_importer.exe");
+			// right now default to python2
+			if(pythonVersion == Preferences.pythonVersionEnum.Python ||
+					pythonVersion == Preferences.pythonVersionEnum.Python2)
+				importer_executable = System.IO.Path.Combine (Util.GetPrefixDir (), "bin\\chronojump-importer\\chronojump_importer.exe");
+			else
+				importer_executable = System.IO.Path.Combine (Util.GetPrefixDir (), "bin\\chronojump-importer-python3\\chronojump_importer.exe");
 		} else {
 			// On Linux and OSX we execute Python and we pass the path to the script as a first argument
 
-			importer_executable = "python";		// chronojump_importer.py works on Python 2 and Python 3
+			importer_executable = Preferences.GetPythonExecutable(pythonVersion);
 
+			LogB.Information("importer_executable: " + importer_executable);
 			string importer_script_path = System.IO.Path.Combine (Util.GetPrefixDir (), "bin/chronojump_importer.py");
 
 			// first argument of the Python: the path to the script
@@ -300,4 +373,15 @@ class ChronojumpImporter
 		// All good, returns the output
 		return new Result (true, execute_result.allOutput);
 	}
+
+	public string SourceFile
+	{
+		get { return sourceFile; }
+	}
+
+	public int SourceSession
+	{
+		get { return sourceSession; }
+	}
+
 }
