@@ -34,7 +34,7 @@ public class ChronopicRegisterPort
 	public string Port;
 	public bool FTDI;
 	public string SerialNumber;
-	public enum Types { UNKNOWN, CONTACTS, ENCODER, ARDUINO_RFID, ARDUINO_FORCE, ARDUINO_RUN_ENCODER, ACCELEROMETER }
+	public enum Types { UNKNOWN, CONTACTS, ENCODER, ARDUINO_RFID, ARDUINO_FORCE, ARDUINO_RUN_ENCODER, ACCELEROMETER, RUN_WIRELESS }
 	public Types Type;
 
 	public bool ConnectedReal; 	//if connexion has been done by ChronopicInit.Do
@@ -81,6 +81,8 @@ public class ChronopicRegisterPort
 			return "Race encoder";
 		else if(typeStatic == Types.ACCELEROMETER)
 			return "Accelerometer";
+		else if(typeStatic == Types.RUN_WIRELESS)
+			return "Races (wireless)";
 
 		return Catalog.GetString("Unknown");
 	}
@@ -91,9 +93,9 @@ public class ChronopicRegisterPortList
 	public List<ChronopicRegisterPort> L;
 
 	//constructor
-	public ChronopicRegisterPortList ()
+	public ChronopicRegisterPortList (bool showArduinoRFID, bool showRunWireless)
 	{
-		this.L = SqliteChronopicRegister.SelectAll(false);
+		this.L = SqliteChronopicRegister.SelectAll(false, showArduinoRFID, showRunWireless);
 	}
 
 	public void Print()
@@ -177,14 +179,14 @@ public class ChronopicRegisterSelectOS
 	public ChronopicRegisterSelectOS() {
 	}
 
-	public ChronopicRegister Do()
+	public ChronopicRegister Do(bool compujump, bool showRunWireless)
 	{
 		if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.LINUX)
-			return new ChronopicRegisterLinux();
+			return new ChronopicRegisterLinux(compujump, showRunWireless);
 		else if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.MACOSX)
-			return new ChronopicRegisterMac();
+			return new ChronopicRegisterMac(compujump, showRunWireless);
 		else // WINDOWS
-			return new ChronopicRegisterWindows();
+			return new ChronopicRegisterWindows(compujump, showRunWireless);
 	}
 }
 
@@ -192,10 +194,10 @@ public abstract class ChronopicRegister
 {
 	protected ChronopicRegisterPortList crpl;
 
-	protected void process()
+	protected void process(bool compujump, bool showRunWireless)
 	{
 		//1 print the registered ports on SQL
-		crpl = new ChronopicRegisterPortList();
+		crpl = new ChronopicRegisterPortList(compujump, showRunWireless); //compujump means: showArduinoRFID
 		crpl.Print();
 
 		//2 create list
@@ -326,9 +328,9 @@ public abstract class ChronopicRegister
 
 public class ChronopicRegisterLinux : ChronopicRegister
 {
-	public ChronopicRegisterLinux ()
+	public ChronopicRegisterLinux (bool compujump, bool showRunWireless)
 	{
-		process();
+		process(compujump, showRunWireless);
 	}
 
 	protected override ChronopicRegisterPort readFTDI(ChronopicRegisterPort crp) 
@@ -376,9 +378,9 @@ public class ChronopicRegisterLinux : ChronopicRegister
 
 public class ChronopicRegisterMac : ChronopicRegister
 {
-	public ChronopicRegisterMac ()
+	public ChronopicRegisterMac (bool compujump, bool showRunWireless)
 	{
-		process();
+		process(compujump, showRunWireless);
 	}
 
 	protected override ChronopicRegisterPort readFTDI(ChronopicRegisterPort crp)
@@ -400,9 +402,9 @@ public class ChronopicRegisterWindows : ChronopicRegister
 {
 	FTDI ftdiDeviceWin;
 
-	public ChronopicRegisterWindows ()
+	public ChronopicRegisterWindows (bool compujump, bool showRunWireless)
 	{
-		process();
+		process(compujump, showRunWireless);
 	}
 
 	protected override void createList()
