@@ -24,6 +24,11 @@ using System.IO;
 
 public class Config
 {
+	//to avoid passing this info to all the windows and dialogs, just read it here
+	public static bool UseSystemColor; //do nothing at all
+	public static Gdk.Color ColorBackground;
+	public static bool ColorBackgroundIsDark;
+
 	public enum SessionModeEnum { STANDARD, UNIQUE, MONTHLY }
 
 	public Preferences.MaximizedTypes Maximized;
@@ -51,6 +56,7 @@ public class Config
 
 	public bool Exhibition; //like YOMO. does not have rfid capture, user autologout management, and automatic configuration of gui
 	public ExhibitionTest.testTypes ExhibitionStationType;
+	public bool Raspberry;
 	/*
 	 * unused because the default serverURL chronojump.org is ok:
 	 * public string ExhibitionServerURL = "";
@@ -95,7 +101,7 @@ public class Config
 					if(parts.Length != 2)
 						continue;
 
-					if(parts[0] == "Compujump" && Util.StringToBool(parts[1]))
+					if(parts[0] == "Compujump" && Util.StringToBool(parts[1])) //Compujump is related to networks (usually the big screens)
 						Compujump = true;
 					else if(parts[0] == "CompujumpDjango" && Util.StringToBool(parts[1]))
 						CompujumpDjango = true;
@@ -128,6 +134,8 @@ public class Config
 					else if(parts[0] == "ExhibitionStationID" && parts[1] != "" && Util.IsNumber(parts[1], false))
 						ExhibitionStationID = Convert.ToInt32(parts[1]);
 						*/
+					if(parts[0] == "Raspberry" && Util.StringToBool(parts[1])) //Raspberry: small screens, could be networks or not. They are usually disconnected by cable removal, so do not show send log at start
+						Raspberry = true;
 				} while(true);
 			}
 		}
