@@ -472,6 +472,7 @@ public class EncoderCurve
 
 	public double WorkJD  { get { return Convert.ToDouble(WorkJ);  } }
 	public double WorkKcalD  { get { return Convert.ToDouble(WorkJ) * 0.000239006;  } }
+	public double ImpulseD  { get { return Convert.ToDouble(Impulse); } }
 	
 	~EncoderCurve() {}
 }
@@ -552,6 +553,9 @@ public class EncoderSignal
 		if(curves.Count - start < n)
 			n = curves.Count - start;
 
+		if(n <= 0)
+			return new List<int>();
+
 		//2) make a copy of curves and have a new EncoderSignal to work with
 		ArrayList curvesCopy = new ArrayList();
 		foreach(EncoderCurve curve in curves)
@@ -957,7 +961,9 @@ public class EncoderSQL
 	//used on encoder table
 	public enum Eccons { ALL, ecS, ceS, c } 
 
-	public string GetDate(bool pretty) {
+	//for new code on other parts, use static method: UtilDate.GetDatetimePrint (DateTime dt)
+	public string GetDatetimeStr (bool pretty)
+	{
 		int pointPos = filename.LastIndexOf('.');
 		int dateLength = 19; //YYYY-MM-DD_hh-mm-ss
 		string date = filename.Substring(pointPos - dateLength, dateLength);
@@ -968,6 +974,15 @@ public class EncoderSQL
 		return date;
 	}
 
+	public string GetDateStr ()
+	{
+		int pointPos = filename.LastIndexOf('.');
+		int dateLength = 19; //YYYY-MM-DD_hh-mm-ss
+		string date = filename.Substring(pointPos - dateLength, dateLength);
+		string [] dateParts = date.Split(new char[] {'_'});
+		return dateParts[0];
+	}
+
 	public string GetFullURL(bool convertPathToR) {
 		string str = url + Path.DirectorySeparatorChar + filename;
 		/*	
@@ -1027,7 +1042,7 @@ public class EncoderSQL
 			str[i++] = encoderConfiguration.code.ToString();
 		
 		str[i++] = ecconLong;
-		str[i++] = GetDate(true);
+		str[i++] = GetDatetimeStr (true);
 		
 		if(video) {
 			if(videoURL != "")
@@ -1078,9 +1093,9 @@ public class EncoderSQL
 		 */
 
 		if(signalOrCurve == "curve") 
-			newFilename = newPersonID + "-" + newPersonName + "-" + uniqueID + "-" + GetDate(false) + ".txt";
+			newFilename = newPersonID + "-" + newPersonName + "-" + uniqueID + "-" + GetDatetimeStr (false) + ".txt";
 		else 
-			newFilename = newPersonID + "-" + newPersonName + "-" + GetDate(false) + ".txt";
+			newFilename = newPersonID + "-" + newPersonName + "-" + GetDatetimeStr (false) + ".txt";
 
 		bool success = false;
 		success = Util.FileMove(url, filename, newFilename);
