@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -135,7 +135,7 @@ public abstract class EncoderCapture
 		}
 		else if(! simulated && ! capturingInertialBG)
 		{
-			LogB.Debug("runEncoderCaptureCsharp start port:", port);
+			LogB.Debug("encoderCaptureCsharp start port:", port);
 			sp = new SerialPort(port);
 			sp.BaudRate = 115200;
 			LogB.Information("sp created");
@@ -191,6 +191,12 @@ public abstract class EncoderCapture
 		 * When arrive to B, then store the ascending phase (2-3)
 		 */
 
+		/*
+		 * TODO:
+		 * this has to be related to distance and not to time
+		 * but we need to have an accurate distance calculation depending on encoderConfiguration (see encoder R files)
+		 * and it will be much better to have ecc and con separately to manage better weightlifting (double phase/or not) exercises
+		 */
 		directionChangePeriod = 25; //how long (ms) to recognize as change direction. (from 2 to A in ms)
 						//it's in ms and not in cm, because it's easier to calculate
 		directionChangeCount = 0; //counter for this period
@@ -241,6 +247,7 @@ public abstract class EncoderCapture
 
 		lastTriggerOn = 0;
 		inertialCalibratedFirstCross0Pos = 0;
+		int lastInertialPhase_i = 0;
 
 		//only for cutByTriggers == Preferences.TriggerTypes.START_AT_FIRST_ON
 		bool firstTriggerHappened = false;
@@ -286,7 +293,7 @@ public abstract class EncoderCapture
 				}
 
 				Trigger trigger = new Trigger(Trigger.Modes.ENCODER, i, true);
-				if(triggerList.IsSpurious(trigger))
+				if(triggerList.IsSpurious(trigger, TriggerList.Type3.ON, 50))
 				{
 					triggerList.RemoveLastOff();
 					continue;
@@ -338,7 +345,7 @@ public abstract class EncoderCapture
 			{
 				if(! playSoundsFromFile)
 				{
-					Trigger trigger  = new Trigger(Trigger.Modes.ENCODER, i, false);
+					Trigger trigger = new Trigger(Trigger.Modes.ENCODER, i, false);
 					triggerList.Add(trigger);
 				}
 
@@ -383,8 +390,9 @@ public abstract class EncoderCapture
 				/*
 				 * process ends
 				 * (
-				 * when a curve has been found and then there are n seconds of inactivity, or
-				 * when not in cont and a curve has not been found and then there are 2*n seconds of inactivity
+				 * -> when a curve has been found and then there are n seconds of inactivity, or
+				 * -> when not in cont and a curve has not been found and then there are 2*n seconds of inactivity
+				 * -> on inertial, if a curve has been found, and now passed double end time since last phase (to end when there is no capture but there is "activity" because cone is slowly rolling
 				 * ) and if consecutiveZeros > restClustersSeconds * 1.500
 				 *
 				 * 1500 is conversion to milliseconds and * 1.5 to have enough time to move after clusters res
@@ -393,7 +401,8 @@ public abstract class EncoderCapture
 						automaticallyEndByTime &&
 						(
 						 (Ecca.curvesAccepted > 0 && consecutiveZeros >= consecutiveZerosMax) ||
-						 (! cont && Ecca.curvesAccepted == 0 && consecutiveZeros >= (2* consecutiveZerosMax))
+						 (! cont && Ecca.curvesAccepted == 0 && consecutiveZeros >= (2* consecutiveZerosMax)) ||
+						 (inertialCalibrated && Ecca.curvesAccepted > 0 && i - lastInertialPhase_i >= (2* consecutiveZerosMax))
 						) &&
 						(restClustersSeconds == 0 || consecutiveZeros > restClustersSeconds * 1500)
 				  )
@@ -598,6 +607,8 @@ public abstract class EncoderCapture
 							lastDirectionStoredIsUp = ecc.up;
 						}
 
+						if(inertialCalibrated)
+							lastInertialPhase_i = i;
 					}
 
 					//on inertial is different
