@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -32,15 +32,21 @@ public class RunExecute : EventExecute
 	protected bool startIn;
 	
 	protected Chronopic cp;
-	//private Chronopic cp; //thi doesn't work
+	//private Chronopic cp; //this doesn't work
+
+	protected string wirelessPort; //"" if not using wireless
+	protected int wirelessBauds; //0 if not using wireless
+	protected bool wireless;
+
 	protected bool metersSecondsPreferred;
 
 	//used by the updateTimeProgressBar for display its time information
 	//changes a bit on runSimple and runInterval
 	//explained at each of the updateTimeProgressBar()
 	//measureRectionTime will be PLATFORM_INI_YES_TIME
+	//START_WIRELESS_UNKNOWN is because we do not know initial status on photocells
 	protected enum runPhases {
-		PRE_RUNNING, PLATFORM_INI_YES_TIME, PLATFORM_INI_NO_TIME, RUNNING, PLATFORM_END
+		START_WIRELESS_UNKNOWN, PRE_RUNNING, PLATFORM_INI_YES_TIME, PLATFORM_INI_NO_TIME, RUNNING, PLATFORM_END
 	}
 	protected static runPhases runPhase;
 		
@@ -76,8 +82,9 @@ public class RunExecute : EventExecute
 	}
 
 	//run execution
+	//if wireless: string wirelessPort, wirelessBauds will be used instead of Chronopic cp
 	public RunExecute(int personID, int sessionID, string type, double distance,   
-			Chronopic cp, Gtk.Window app,
+			Chronopic cp, string wirelessPort, int wirelessBauds, Gtk.Window app,
 			int pDN, bool metersSecondsPreferred,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			double progressbarLimit, ExecutingGraphData egd,
@@ -93,6 +100,10 @@ public class RunExecute : EventExecute
 		this.distance = distance;
 		
 		this.cp = cp;
+		this.wirelessPort = wirelessPort;
+		this.wirelessBauds = wirelessBauds;
+		wireless = (wirelessPort != "" && wirelessBauds > 0);
+		LogB.Information(string.Format("This is a run simple capture with wireless?: {0}", wireless));
 		this.app = app;
 
 		this.pDN = pDN;
@@ -150,20 +161,67 @@ public class RunExecute : EventExecute
 
 		//boolean to know if chronopic has been disconnected	
 		chronopicDisconnected = false;
+		runChangeImage = new RunChangeImage();
 
-		if (simulated) 
+		//if(wireless)
+		//	manageIniWireless();
+		//else
+		if(! wireless)
+			manageIniNotWireless();
+
+		//prepare jump for being cancelled if desired
+		cancel = false;
+
+		//start thread
+		thread = new Thread(new ThreadStart(waitEvent));
+		GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
+
+		LogB.ThreadStart();
+		thread.Start();
+	}
+
+	private void manageIniWireless()
+	{
+		/*
+		 * on wireless we cannot know if on start we are in contact or not
+		 * so we cannot set at the moment startIn, loggedState, runPhase
+		 */
+		LogB.Debug("MANAGE(wireless)!!!!");
+
+		feedbackMessage = Catalog.GetString("RUN when prepared!");
+		needShowFeedbackMessage = true;
+		Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn, gstreamer);
+
+
+		//runPhase = runPhases.START_WIRELESS_UNKNOWN;
+		//provem de forçar a que comencem en off, a veure si va be
+		platformState = Chronopic.Plataforma.OFF;
+		if (platformState==Chronopic.Plataforma.OFF) {
+			feedbackMessage = Catalog.GetString("You are OUT, RUN when prepared!");
+			needShowFeedbackMessage = true;
+			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn, gstreamer);
+
+			loggedState = States.OFF;
+			startIn = false;
+			runPhase = runPhases.PRE_RUNNING;
+			runChangeImage.Current = RunChangeImage.Types.RUNNING;
+		}
+	}
+
+	private void manageIniNotWireless()
+	{
+		if (simulated)
 			platformState = Chronopic.Plataforma.ON;
 		else
 			platformState = chronopicInitialValue(cp);
-		
-		LogB.Debug("MANAGE(b)!!!!");
-		runChangeImage = new RunChangeImage();
 
-		//you can start ON or OFF the platform, 
+		LogB.Debug("MANAGE(Not wireless)!!!!");
+
+		//you can start ON or OFF the platform,
 		//we record always de TF (or time between we abandonate the platform since we arrive)
 		if (platformState==Chronopic.Plataforma.ON) {
 			feedbackMessage = Catalog.GetString("You are IN, RUN when prepared!");
-			needShowFeedbackMessage = true; 
+			needShowFeedbackMessage = true;
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn, gstreamer);
 
 			loggedState = States.ON;
@@ -172,7 +230,7 @@ public class RunExecute : EventExecute
 			runChangeImage.Current = RunChangeImage.Types.PHOTOCELL;
 		} else if (platformState==Chronopic.Plataforma.OFF) {
 			feedbackMessage = Catalog.GetString("You are OUT, RUN when prepared!");
-			needShowFeedbackMessage = true; 
+			needShowFeedbackMessage = true;
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn, gstreamer);
 
 			loggedState = States.OFF;
@@ -185,14 +243,13 @@ public class RunExecute : EventExecute
 			return;
 		}
 
-	
 		if (simulated) {
 			if(startIn) {
 				//values of simulation will be the flightTime (between two platforms)
 				//at the first time (and the only)
 				//start running being on the platform
 				simulatedCurrentTimeIntervalsAreContact = false;
-			
+
 				//in simulated mode, make the run start just when we arrive to waitEvent at the first time
 				//mark now that we have abandoned platform:
 				platformState = Chronopic.Plataforma.OFF;
@@ -201,22 +258,12 @@ public class RunExecute : EventExecute
 				//at the first time, the second will be flightTime (between two platforms)
 				//come with previous run ("salida lanzada")
 				simulatedCurrentTimeIntervalsAreContact = true;
-				
+
 				//in simulated mode, make the run start just when we arrive to waitEvent at the first time
 				//mark now that we have reached the platform:
 				platformState = Chronopic.Plataforma.ON;
 			}
 		}
-
-		//prepare jump for being cancelled if desired
-		cancel = false;
-
-		//start thread
-		thread = new Thread(new ThreadStart(waitEvent));
-		GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
-			
-		LogB.ThreadStart(); 
-		thread.Start(); 
 	}
 
 	protected void timestampDCInitValues()
@@ -234,6 +281,7 @@ public class RunExecute : EventExecute
 		//firstTrackDone = false;
 
 		double timestamp = 0;
+		double timestampAccumulated = 0; //for wireless (because instead of split times, it comes absolute time)
 		bool ok;
 
 		timestampDCInitValues();
@@ -241,7 +289,7 @@ public class RunExecute : EventExecute
 
 		//prepare variables to allow being cancelled or finished
 		if(! simulated)
-			Chronopic.InitCancelAndFinish();
+			Chronopic.InitCancelAndFinish(); //ok for wireless
 
 		runEI = new RunExecuteInspector(
 				runEIType,
@@ -262,16 +310,50 @@ public class RunExecute : EventExecute
 				checkDoubleContactTime
 				);
 
+LogB.Information("going to call pwc.CaptureStart ()");
+		PhotocellWirelessCapture pwc = null;
+		if(wireless)
+		{
+			feedbackMessage = Catalog.GetString("Please, wait!");
+			needShowFeedbackMessage = true;
+			pwc = new PhotocellWirelessCapture(wirelessPort);
+			pwc.CaptureStart ();
+
+			manageIniWireless();
+		}
+
 		bool firstFromChronopicReceived = false;
 		bool exitWaitEventBucle = false;
 		do {
-			if(simulated)
+			if (wireless)
+			{
+				if(! pwc.CaptureLine())
+					cancel = true; //problem reading line (capturing)
+
+				ok = false;
+				if(pwc.CanRead())
+				{
+					LogB.Information("waitEvent 3");
+					PhotocellWirelessEvent pwe = pwc.PhotocellWirelessCaptureReadNext();
+					LogB.Information("wait_event pwe: " + pwe.ToString());
+					//TODO: photocell = pwe.photocell;
+					timestamp = pwe.timeMs - timestampAccumulated; //photocell does not send splittime, sends absolute time
+					timestampAccumulated += timestamp;
+
+					platformState = pwe.status;
+
+					ok = true;
+					LogB.Information("waitEvent 4");
+				}
+			}
+			else if(simulated)
 				ok = true;
 			else 
 				ok = cp.Read_event(out timestamp, out platformState);
 			
 			if (ok && ! cancel && ! finish)
 			{
+				LogB.Information("waitEvent 7");
 				if( ! firstFromChronopicReceived )
 				{
 					speedStart = has_arrived();
@@ -285,16 +367,25 @@ public class RunExecute : EventExecute
 				//LogB.Information("timestamp:" + timestamp);
 				if (has_arrived()) // timestamp is tf
 				{
+					LogB.Information("has arrived");
 					loggedState = States.ON;
 					runChangeImage.Current = RunChangeImage.Types.PHOTOCELL;
 
 					onlyInterval_NeedShowCountDownFalse();
 
+					//it has confirmed that first phase is PRE_RUNNING
+					if(wireless && runPhase == runPhases.START_WIRELESS_UNKNOWN)
+					{
+						runPhase = runPhases.PRE_RUNNING;
+						startIn = false;
+					}
+
 					if(runPhase == runPhases.PRE_RUNNING)
 					{
 						if(speedStartArrival || measureReactionTime) {
 							runPhase = runPhases.PLATFORM_INI_YES_TIME;
 							//run starts
+							LogB.Information("\ninitializeTimer at has_arrived");
 							initializeTimer(); //timerCount = 0
 							runEI.ChangePhase(RunExecuteInspector.Phases.IN,
 								"TimerStart");
@@ -339,14 +430,27 @@ public class RunExecute : EventExecute
 				}
 				else if (has_lifted()) // timestamp is tc
 				{
+					LogB.Information("has lifted");
 					loggedState = States.OFF;
 					runChangeImage.Current = RunChangeImage.Types.RUNNING;
 
 					lastTc = 0;
 
+					//it has confirmed that first phase is PLATFORM_INI_YES/NO_TIME
+					if(wireless && runPhase == runPhases.START_WIRELESS_UNKNOWN)
+					{
+						if(speedStartArrival || measureReactionTime)
+							runPhase = runPhases.PLATFORM_INI_YES_TIME;
+						else
+							runPhase = runPhases.PLATFORM_INI_NO_TIME;
+
+						startIn = true;
+					}
+
 					if(runPhase == runPhases.PLATFORM_INI_NO_TIME)
 					{
 						//run starts
+						LogB.Information("\ninitializeTimer at has_lifted");
 						initializeTimer(); //timerCount = 0
 						runEI.ChangePhase(RunExecuteInspector.Phases.OUT, "Timer start");
 
@@ -405,16 +509,27 @@ public class RunExecute : EventExecute
 
 		} while ( ! exitWaitEventBucle );
 
+		if(wireless)
+		{
+			pwc.Stop();
+		}
+
 		onlyInterval_FinishWaitEventWrite();
 	}
 
 	protected bool has_arrived()
 	{
-		return (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF);
+		if(wireless && runPhase == runPhases.START_WIRELESS_UNKNOWN)
+			return (platformState == Chronopic.Plataforma.ON);
+		else
+			return (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF);
 	}
 	protected bool has_lifted()
 	{
-		return (platformState == Chronopic.Plataforma.OFF && loggedState == States.ON);
+		if(wireless && runPhase == runPhases.START_WIRELESS_UNKNOWN)
+			return (platformState == Chronopic.Plataforma.OFF);
+		else
+			return (platformState == Chronopic.Plataforma.OFF && loggedState == States.ON);
 	}
 	
 	/* only run interval functions */
@@ -505,13 +620,13 @@ public class RunExecute : EventExecute
 	//big change in 1.8.1: this is called from GTK thread
 	//so don't write to SQL here
 	//and use static variables where needed
-	protected override void trackDone()
+	protected override bool trackDone()
 	{
 		LogB.Information("In trackDone() A");
 
 		runDC.TrackDoneHasToBeCalledAgain = false;
 		if(success)
-			return;
+			return true;
 
 		LogB.Information("In trackDone() B");
 		//double myTrackTime = 0;
@@ -542,7 +657,7 @@ public class RunExecute : EventExecute
 						runPTL.FirstRPIs = posOfBiggestTC +1;
 
 					runDC.UpdateStartPos(posOfBiggestTC);
-					return;
+					return true;
 				}
 				else
 				{
@@ -569,7 +684,7 @@ public class RunExecute : EventExecute
 		LogB.Information("trackTime: " + trackTime.ToString());
 		//solve possible problems of bad copied data between threads on start
 		if(trackTime == 0)
-			return;
+			return false; //helps to fix display of a contact time bigger than double contact time * 1.5
 
 		runEI.ChangePhase(RunExecuteInspector.Phases.IN,
 				string.Format("; timestamp: {0}; <b>trackTime: {1}</b>",
@@ -584,6 +699,7 @@ public class RunExecute : EventExecute
 		if(! success && runDC.TrackDoneHasToBeCalledAgain)
 			trackDone();
 
+		return true;
 	}
 
 	protected virtual void trackDoneRunSpecificStuff ()
@@ -642,8 +758,11 @@ public class RunExecute : EventExecute
 		
 		double myTimeValue = 0;
 		switch (runPhase) {
+			case runPhases.START_WIRELESS_UNKNOWN:
+				myTimeValue = -1; //don't show nothing on label_timer
+				break;
 			case runPhases.PRE_RUNNING:
-				myTimeValue = -1; //don't show nothing on label_timer 
+				myTimeValue = -1; //don't show nothing on label_timer
 				break;
 			case runPhases.PLATFORM_INI_NO_TIME:
 				myTimeValue = -1;
@@ -780,7 +899,8 @@ public class RunIntervalExecute : RunExecute
 
 	//run execution
 	public RunIntervalExecute(int personID, int sessionID, string type, double distanceInterval, double limitAsDouble, bool tracksLimited,  
-			Chronopic cp, Gtk.Window app, int pDN, bool metersSecondsPreferred,
+			Chronopic cp, string wirelessPort, int wirelessBauds, Gtk.Window app,
+			int pDN, bool metersSecondsPreferred,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			RepetitiveConditionsWindow repetitiveConditionsWin,
 			double progressbarLimit, ExecutingGraphData egd ,
@@ -813,6 +933,10 @@ public class RunIntervalExecute : RunExecute
 		
 		
 		this.cp = cp;
+		this.wirelessPort = wirelessPort;
+		this.wirelessBauds = wirelessBauds;
+		wireless = (wirelessPort != "" && wirelessBauds > 0);
+		LogB.Information(string.Format("This is a run interval capture with wireless?: {0}", wireless));
 		this.app = app;
 
 		this.metersSecondsPreferred = metersSecondsPreferred;
@@ -1021,6 +1145,7 @@ public class RunIntervalExecute : RunExecute
 		//check that the run started
 		//if( ! tracksLimited && limitAsDouble != -1 && timerCount > limitAsDouble 
 		if( ! tracksLimited && limitAsDouble != -1
+				&& !(runPhase == runPhases.START_WIRELESS_UNKNOWN)
 				&& !(runPhase == runPhases.PRE_RUNNING) 
 				&& !(runPhase == runPhases.PLATFORM_INI_NO_TIME)
 				&& !(runPhase == runPhases.PLATFORM_INI_YES_TIME)
@@ -1066,9 +1191,13 @@ public class RunIntervalExecute : RunExecute
 		double myTimeValue = 0;
 		bool percentageMode = true; //false is activity mode
 		switch (runPhase) {
+			case runPhases.START_WIRELESS_UNKNOWN:
+				percentageMode = false;
+				myTimeValue = -1; //don't show nothing on label_timer
+				break;
 			case runPhases.PRE_RUNNING:
 				percentageMode = false;
-				myTimeValue = -1; //don't show nothing on label_timer 
+				myTimeValue = -1; //don't show nothing on label_timer
 				break;
 			case runPhases.PLATFORM_INI_NO_TIME:
 				percentageMode = false;
