@@ -103,7 +103,8 @@ public class ExportSession
 				LogB.Warning(string.Format("File {0} exists with attributes {1}, created at {2}",
 							fileName, File.GetAttributes(fileName), File.GetCreationTime(fileName)));
 				LogB.Information("Overwrite...");
-				ConfirmWindow confirmWin = ConfirmWindow.Show(Catalog.GetString("Are you sure you want to overwrite file: "), "", fileName);
+				ConfirmWindow confirmWin = ConfirmWindow.Show(Catalog.GetString("Are you sure you want to overwrite file: "),
+						"", fileName);
 				confirmWin.Button_accept.Clicked += new EventHandler(on_overwrite_file_accepted);
 			} else {
 				writeFile();
@@ -184,7 +185,7 @@ public class ExportSession
 		myJumps= SqliteJump.SelectJumpsSA (true, mySession.UniqueID, -1, "", "",
 				Sqlite.Orders_by.DEFAULT, -1);
 
-		myJumpsRj = SqliteJumpRj.SelectJumps(true, mySession.UniqueID, -1, "", "");
+		myJumpsRj = SqliteJumpRj.SelectJumpsSA (true, mySession.UniqueID, -1, "", "");
 		myRuns= SqliteRun.SelectRunsSA (true, mySession.UniqueID, -1, "",
 				Sqlite.Orders_by.DEFAULT, -1);
 
