@@ -359,7 +359,8 @@ public partial class ChronoJumpWindow
 
 	private void on_show_all_person_events_activate (object o, EventArgs args)
 	{
-		personShowAllEventsWin = PersonShowAllEventsWindow.Show(app1, currentSession.UniqueID, currentPerson, true);
+		personShowAllEventsWin = PersonShowAllEventsWindow.Show(app1,
+				currentSession.UniqueID, currentPerson, true, preferences.colorBackground);
 	}
 	
 	
@@ -409,7 +410,7 @@ public partial class ChronoJumpWindow
 				currentSession.UniqueID, 
 				false); //means: do not returnPersonAndPSlist
 
-		personSelectWin = PersonSelectWindow.Show(app1, myPersons, currentPerson);
+		personSelectWin = PersonSelectWindow.Show(app1, myPersons, currentPerson, preferences.colorBackground);
 		personSelectWin.FakeButtonAddPerson.Clicked += new EventHandler(on_button_top_person_add_person);
 		personSelectWin.FakeButtonAddPersonMultiple.Clicked += new EventHandler(on_button_top_person_add_person_multiple);
 		personSelectWin.FakeButtonLoadPerson.Clicked += new EventHandler(on_button_top_person_load_person);
@@ -449,7 +450,8 @@ public partial class ChronoJumpWindow
 	}
 	private void on_button_top_person_show_all_events (object o, EventArgs args)
 	{
-		personShowAllEventsWin = PersonShowAllEventsWindow.Show(app1, currentSession.UniqueID, currentPerson, false);
+		personShowAllEventsWin = PersonShowAllEventsWindow.Show(app1,
+				currentSession.UniqueID, currentPerson, false, preferences.colorBackground);
 		personShowAllEventsWin.FakeButtonDone.Clicked -= new EventHandler(on_person_show_all_persons_event_close);
 		personShowAllEventsWin.FakeButtonDone.Clicked += new EventHandler(on_person_show_all_persons_event_close);
 	}
