@@ -791,9 +791,9 @@ public partial class ChronoJumpWindow
 		pen_green_discont_force_ai.SetLineAttributes (1, Gdk.LineStyle.OnOffDash, Gdk.CapStyle.Butt, Gdk.JoinStyle.Round);
 
 		layout_force_ai_text = new Pango.Layout (force_sensor_ai_drawingarea.PangoContext);
-		layout_force_ai_text.FontDescription = Pango.FontDescription.FromString ("Courier 10");
+		layout_force_ai_text.FontDescription = Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(10));
 		layout_force_ai_text_big = new Pango.Layout (force_sensor_ai_drawingarea.PangoContext);
-		layout_force_ai_text_big.FontDescription = Pango.FontDescription.FromString ("Courier 12");
+		layout_force_ai_text_big.FontDescription = Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(12));
 	}
 
 	private void forcePaintAnalyzeGeneralTimeValue(int time, bool solid)
@@ -813,13 +813,13 @@ public partial class ChronoJumpWindow
 			layout_force_ai_text.SetMarkup("Force (N)");
 			layout_force_ai_text.GetPixelSize(out textWidth, out textHeight);
 			force_sensor_ai_pixmap.DrawLayout (pen_gray_cont_force_ai,
-					xPx - textWidth/2, 0, layout_force_ai_text);
+					xPx - textWidth/2, 6, layout_force_ai_text);
 
 			force_sensor_ai_pixmap.DrawLine(pen_gray_cont_force_ai,
-					xPx, textHeight, xPx, force_sensor_ai_drawingarea.Allocation.Height - textHeight -6);
+					xPx, textHeight +6, xPx, force_sensor_ai_drawingarea.Allocation.Height - textHeight -6);
 		} else
 			force_sensor_ai_pixmap.DrawLine(pen_gray_discont_force_ai,
-					xPx, 6, xPx, force_sensor_ai_drawingarea.Allocation.Height - textHeight -6);
+					xPx, textHeight +6, xPx, force_sensor_ai_drawingarea.Allocation.Height - textHeight -6);
 	}
 
 	private void forcePaintAnalyzeGeneralHLine(int yForce, bool solid)
@@ -891,7 +891,8 @@ public partial class ChronoJumpWindow
 			return;
 
 		//needed to have mouse clicks button_press_event ()
-		force_sensor_ai_drawingarea.AddEvents((int) (Gdk.EventMask.ButtonPressMask | Gdk.EventMask.ButtonReleaseMask));
+//		force_sensor_ai_drawingarea.AddEvents((int) (Gdk.EventMask.ButtonPressMask | Gdk.EventMask.ButtonReleaseMask));
+		force_sensor_ai_drawingarea.AddEvents((int) Gdk.EventMask.ButtonPressMask);
 
 		/* in some mono installations, configure_event is not called, but expose_event yes.
 		 * Do here the initialization
@@ -1147,6 +1148,11 @@ public partial class ChronoJumpWindow
 				force_sensor_ai_pixmap.DrawLayout (pen_green_force_ai,
 						xPxEnd +2, fsAI.GetPxAtDispl(fsAI.FscAIPointsDispl.ForceMin) - textHeight/2, layout_force_ai_text);
 			}
+		} else
+		{
+			//we just need to set textHeight
+			layout_force_ai_text.SetMarkup("a");
+			layout_force_ai_text.GetPixelSize(out textWidth, out textHeight);
 		}
 
 		// 3) paint points as line (can be done also with DrawPoints to debug)
@@ -1228,15 +1234,15 @@ public partial class ChronoJumpWindow
 			// paint vertical line for each rep
 			if(sampleStart >= 0) {
 				xposRepStart = fsAI.GetXFromSampleCount(sampleStart);
-				//no need to graph two green lines together ir rep starts just on previous rep ends
+				//no need to graph two green lines together if rep starts just on previous rep ends
 				if(xposRepStart > xposRepEnd)
 					force_sensor_ai_pixmap.DrawLine(pen_green_force_ai,
-							xposRepStart, 0, xposRepStart, allocation.Height - textHeight - 6);
+							xposRepStart, textHeight +6, xposRepStart, allocation.Height - textHeight -6);
 			}
 			if(sampleEnd >= 0) {
 				xposRepEnd = fsAI.GetXFromSampleCount(sampleEnd);
 				force_sensor_ai_pixmap.DrawLine(pen_green_force_ai,
-						xposRepEnd, 0, xposRepEnd, allocation.Height -20);
+						xposRepEnd, textHeight +6, xposRepEnd, allocation.Height -textHeight -6);
 				//LogB.Information(string.Format("repetition paint, j: {0}, xposRepEnd: {1}", j, xposRepEnd));
 			}
 
@@ -1244,25 +1250,32 @@ public partial class ChronoJumpWindow
 			{
 				if(sampleStart >= 0)
 				{
-					forceSensorWriteRepetitionNumber(j, xposRepStart, xposRepEnd, true, true);
+					forceSensorWriteRepetitionCode (j, reps_l[j].TypeShort(), xposRepStart, xposRepEnd, true, true);
 
 					if(! forceSensorZoomApplied)
 						fsAIRepetitionMouseLimits.Add(xposRepStart, xposRepEnd);
 				} else {
 					//write the rep and arrow, but just if there is enough space
 					if(xposRepEnd - fsAI.GetXFromSampleCount(0) > 30)
-						forceSensorWriteRepetitionNumber(j,
+						forceSensorWriteRepetitionCode (j, reps_l[j].TypeShort(),
 								//fsAI.GetXFromSampleCount(hscale_force_sensor_ai_a_BeforeZoom),
 								fsAI.GetXFromSampleCount(0),
 								xposRepEnd, false, true);
 				}
 			}
 		}
-		//show the number of last repetition (when obviously no new rep will make writting it)
+		//show the start vertical line and the number of last repetition (when obviously no new rep will make writting it)
 		//but only if zoomed and that repetition exists (has an end)
-		if(xposRepEnd - xposRepStart > 30)
-			if(forceSensorZoomApplied && j >= 0 && j < reps_l.Count) // write last repetition count
-				forceSensorWriteRepetitionNumber(j, xposRepStart, xposRepEnd, true, false);
+		if(forceSensorZoomApplied && j >= 0 && j < reps_l.Count)
+		{
+			//write the vertical start line
+			force_sensor_ai_pixmap.DrawLine(pen_green_force_ai,
+					xposRepStart, textHeight +6, xposRepStart, allocation.Height - textHeight -6);
+
+			//write last repetition count
+			if(xposRepEnd - xposRepStart > 30)
+				forceSensorWriteRepetitionCode (j, reps_l[j].TypeShort(), xposRepStart, xposRepEnd, true, false);
+		}
 
 
 		/*
@@ -1320,27 +1333,32 @@ public partial class ChronoJumpWindow
 		LogB.Information("forceSensorAnalyzeManualGraphDo() END");
 	}
 
-	private void forceSensorWriteRepetitionNumber(int rep, int xposRepStart, int xposRepEnd, bool endsAtLeft, bool endsAtRight)
+	private void forceSensorWriteRepetitionCode (int number, string type, int xposRepStart, int xposRepEnd, bool endsAtLeft, bool endsAtRight)
 	{
-		LogB.Information(string.Format("at forceSensorWriteRepetitionNumber with (rep+1): {0}, endsAtLeft: {1}, endsAtRight: {2}", rep +1, endsAtLeft, endsAtRight));
+//		LogB.Information(string.Format("at forceSensorWriteRepetitionNumber with (rep+1): {0}, endsAtLeft: {1}, endsAtRight: {2}", rep +1, endsAtLeft, endsAtRight));
+//		layout_force_ai_text.SetMarkup((rep+1).ToString());
+
+		if(! currentForceSensorExercise.EccReps)
+			layout_force_ai_text.SetMarkup((number+1).ToString());
+		else
+			layout_force_ai_text.SetMarkup(string.Format("{0}{1}", Math.Ceiling((number +1)/2.0), type));
 
-		layout_force_ai_text.SetMarkup((rep+1).ToString());
 		int textWidth = 1; int textHeight = 1;
 		layout_force_ai_text.GetPixelSize(out textWidth, out textHeight);
 
 		int xposNumber = Convert.ToInt32((xposRepStart + xposRepEnd)/2 - textWidth/2);
 
 		force_sensor_ai_pixmap.DrawLayout (pen_green_force_ai,
-				xposNumber, 0, layout_force_ai_text);
+				xposNumber, 6, layout_force_ai_text);
 
 		//if it does not fit, do not plot the horizontal lines + arrows
 		if(xposNumber - xposRepStart < 16)
 			return;
 
 		//draw arrow to the left
-		UtilGtk.DrawHorizontalLine(force_sensor_ai_pixmap, pen_green_force_ai, xposRepStart, xposNumber, textHeight/2,
+		UtilGtk.DrawHorizontalLine(force_sensor_ai_pixmap, pen_green_force_ai, xposRepStart, xposNumber, 6 + textHeight/2,
 			6, endsAtLeft, false, 4);
-		UtilGtk.DrawHorizontalLine(force_sensor_ai_pixmap, pen_green_force_ai, xposNumber + textWidth, xposRepEnd, textHeight/2,
+		UtilGtk.DrawHorizontalLine(force_sensor_ai_pixmap, pen_green_force_ai, xposNumber + textWidth, xposRepEnd, 6 + textHeight/2,
 			6, false, endsAtRight, 4);
 	}
 
@@ -1543,11 +1561,46 @@ public partial class ChronoJumpWindow
 	{
 		hscale_force_sensor_ai_b.Value += 1;
 	}
+
 	private void on_button_hscale_force_sensor_ai_b_last_clicked (object o, EventArgs args)
 	{
 		hscale_force_sensor_ai_b.Value = fsAI.GetLength() -2;
 	}
 
+	private void on_button_hscale_force_sensor_ai_b_pre_1s_clicked (object o, EventArgs args)
+	{
+		if(fsAI == null || fsAI.GetLength() == 0)
+			return;
+
+		int startB = Convert.ToInt32(hscale_force_sensor_ai_b.Value);
+		double startBMs = fsAI.GetTimeMS(startB);
+		for(int i = startB; i > 0; i --)
+		{
+			if(startBMs - fsAI.GetTimeMS(i) >= 1000)
+			{
+				hscale_force_sensor_ai_b.Value += i - startB;
+				return;
+			}
+		}
+	}
+
+	private void on_button_hscale_force_sensor_ai_b_post_1s_clicked (object o, EventArgs args)
+	{
+		if(fsAI == null || fsAI.GetLength() == 0)
+			return;
+
+		int startB = Convert.ToInt32(hscale_force_sensor_ai_b.Value);
+		double startBMs = fsAI.GetTimeMS(startB);
+		for(int i = startB; i < fsAI.GetLength() -1; i ++)
+		{
+			if(fsAI.GetTimeMS(i) - startBMs >= 1000)
+			{
+				hscale_force_sensor_ai_b.Value += i - startB;
+				return;
+			}
+		}
+	}
+
 	private void manage_force_sensor_ai_table_visibilities()
 	{
 		bool visible = true;//checkbutton_force_sensor_ai_b.Active;
