@@ -46,6 +46,7 @@ public partial class ChronoJumpWindow
 	//[Widget] Gtk.Image image_persons_up;
 	//[Widget] Gtk.Image image_persons_down;
 	[Widget] Gtk.Image image_contacts_exercise;
+	[Widget] Gtk.Image image_contacts_exercise_settings;
 	[Widget] Gtk.Image image_contacts_exercise_close;
 	[Widget] Gtk.Image image_contacts_capture_load;
 	[Widget] Gtk.Image image_contacts_session_overview;
@@ -65,9 +66,9 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_contacts_close_and_capture;
 	[Widget] Gtk.Image image_encoder_close_and_capture;
 	[Widget] Gtk.Image image_tests_capture;
+	[Widget] Gtk.Image image_tests_analyze_jump_rj;
 	[Widget] Gtk.Image image_tests_sprint;
 	[Widget] Gtk.Image image_tests_analyze_general;
-	[Widget] Gtk.Image image_tests_analyze_general1;
 	[Widget] Gtk.Image image_info1;
 	[Widget] Gtk.Image image_info2;
 	[Widget] Gtk.Image image_info3;
@@ -87,10 +88,6 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_logo_contacts_transp;
 	[Widget] Gtk.Image image_logo_encoder;
 	[Widget] Gtk.Image image_logo_encoder_transp;
-	[Widget] Gtk.Frame frame_logo_contacts;
-	[Widget] Gtk.Frame frame_logo_encoder;
-	[Widget] Gtk.Viewport viewport_image_logo_contacts;
-	[Widget] Gtk.Viewport viewport_image_logo_encoder;
 
 	[Widget] Gtk.Image image_selector_start_jumps;
 	[Widget] Gtk.Image image_selector_start_runs;
@@ -119,6 +116,7 @@ public partial class ChronoJumpWindow
 	//run
 	[Widget] Gtk.Image image_run_execute_running;
 	[Widget] Gtk.Image image_run_execute_photocell;
+	[Widget] Gtk.Image image_sprint_analyze_save;
 
 	//encoder images
 	[Widget] Gtk.Image image_top_eccon;
@@ -135,6 +133,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_recalculate;
 	[Widget] Gtk.Image image_encoder_configuration;
 	[Widget] Gtk.Image image_encoder_exercise;
+	[Widget] Gtk.Image image_encoder_exercise_settings;
 	[Widget] Gtk.Image image_encoder_exercise_close;
 	[Widget] Gtk.Image image_encoder_capture_open;
 	[Widget] Gtk.Image image_encoder_capture_open1;
@@ -157,6 +156,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_encoder_analyze_image_compujump_send_email_image;
 	[Widget] Gtk.Image image_encoder_analyze_image_compujump_send_email_send;
 	[Widget] Gtk.Image image_encoder_analyze_check;
+	[Widget] Gtk.Image image_encoder_capture_inertial_ecc;
+	[Widget] Gtk.Image image_encoder_capture_inertial_con;
 
 	//force sensor
 	[Widget] Gtk.Image image_selector_start_force_sensor;
@@ -240,6 +241,8 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_settings.png");
 		image_menu_preferences.Pixbuf = pixbuf;
 		image_menu_preferences1.Pixbuf = pixbuf;
+		image_contacts_exercise_settings.Pixbuf = pixbuf;
+		image_encoder_exercise_settings.Pixbuf = pixbuf;
 
 		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_minimize.png");
 		//image_minimize.Pixbuf = pixbuf;
@@ -274,14 +277,19 @@ public partial class ChronoJumpWindow
 		image_message_permissions_at_boot.Pixbuf = pixbuf;
 		image_button_force_sensor_stiffness_problem.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "muscle-excentric.png");
+		image_encoder_capture_inertial_ecc.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "muscle-concentric.png");
 		image_top_eccon.Pixbuf = pixbuf;
+		image_encoder_capture_inertial_con.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "muscle-concentric.png");
 		image_encoder_eccon_concentric.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "muscle-excentric-concentric.png");
 		image_encoder_eccon_eccentric_concentric.Pixbuf = pixbuf;
 
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "laterality-both.png");
 		image_top_laterality.Pixbuf = pixbuf;
 		image_encoder_laterality_both.Pixbuf = pixbuf;
@@ -394,6 +402,10 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_new.png");
 		image_session_new1.Pixbuf = pixbuf;
 		image_session_new3.Pixbuf = pixbuf;
+		image_session_new_blue.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_new_yellow.png");
+		image_session_new_yellow.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_open.png");
 		image_session_load1.Pixbuf = pixbuf;
@@ -509,9 +521,6 @@ public partial class ChronoJumpWindow
 		image_logo_contacts_transp.Pixbuf = pixbuf;
 		image_logo_encoder_transp.Pixbuf = pixbuf;
 
-		UtilGtk.ViewportColor(viewport_image_logo_contacts, UtilGtk.BLUE_CHRONOJUMP);
-		UtilGtk.ViewportColor(viewport_image_logo_encoder, UtilGtk.BLUE_CHRONOJUMP);
-
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameIcon);
 		image_logo_icon.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameIconTransp);
@@ -538,6 +547,7 @@ public partial class ChronoJumpWindow
 		image_mode_jumps_small.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump_reactive.png");
 		image_mode_jumps_reactive_small.Pixbuf = pixbuf;
+		image_tests_analyze_jump_rj.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_simple.png");
 		image_mode_runs_small.Pixbuf = pixbuf;
 		image_mode_runs_small1.Pixbuf = pixbuf;
@@ -724,10 +734,13 @@ public partial class ChronoJumpWindow
 		image_jumps_dj_optimal_fall_save.Pixbuf = pixbuf;
 		image_jumps_weight_fv_profile_save.Pixbuf = pixbuf;
 		image_jumps_evolution_save.Pixbuf = pixbuf;
+		image_jumps_rj_fatigue_save.Pixbuf = pixbuf;
+		image_sprint_analyze_save.Pixbuf = pixbuf;
 		image_encoder_analyze_image_compujump_send_email_image.Pixbuf = pixbuf;
 		image_run_encoder_analyze_image_save_graph.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "save.png");
+		image_jumps_rj_fatigue_image_save.Pixbuf = pixbuf;
 		image_encoder_capture_curves_save.Pixbuf = pixbuf;
 		image_encoder_analyze_table_save_1.Pixbuf = pixbuf;
 		image_encoder_analyze_image_save_1.Pixbuf = pixbuf;
@@ -749,7 +762,6 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_analyze_general.png");
 		image_tests_analyze_general.Pixbuf = pixbuf;
-		image_tests_analyze_general1.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "jumps-profile-pie.png");
 		image_tab_jumps_profile.Pixbuf = pixbuf;
