@@ -277,7 +277,7 @@ public partial class ChronoJumpWindow
 				tv, tc, currentSession.UniqueID,
 				currentPerson.UniqueID, radio_contacts_graph_allPersons.Active,
 				Convert.ToInt32(spin_contacts_graph_last_limit.Value),
-				Constants.JumpTable, typeTemp, preferences.jumpsDjGraphHeights);
+				Constants.JumpTable, typeTemp, preferences.heightPreferred);
 		
 		if(eventGraph.personMAXAtSQLAllSessions > 0 || eventGraph.jumpsAtSQL.Count > 0)
 			PrepareJumpSimpleGraph(eventGraph, false); //don't animate
@@ -423,13 +423,13 @@ public partial class ChronoJumpWindow
 	private void on_more_jumps_cancelled (object o, EventArgs args) 
 	{
 		currentJumpType = previousJumpType;
-		extra_window_jumps_initialize(currentJumpType);
+		combo_select_jumps.Active = UtilGtk.ComboMakeActive(combo_select_jumps, currentJumpType.Name);
 	}
 	
 	private void on_more_jumps_rj_cancelled (object o, EventArgs args) 
 	{
 		currentJumpRjType = previousJumpRjType;
-		extra_window_jumps_rj_initialize(currentJumpRjType);
+		combo_select_jumps_rj.Active = UtilGtk.ComboMakeActive(combo_select_jumps_rj, currentJumpRjType.Name);
 	}
 	
 	private void extra_window_showWeightData (JumpType myJumpType, bool show) {
