@@ -349,7 +349,6 @@ public partial class ChronoJumpWindow
 		capturingRunEncoder = arduinoCaptureStatus.STARTING;
 
 		button_execute_test.Sensitive = false;
-		event_execute_button_finish.Sensitive = true;
 		event_execute_button_cancel.Sensitive = true;
 
 		//forceCaptureStartMark = false;
@@ -364,7 +363,7 @@ public partial class ChronoJumpWindow
 		contactsShowCaptureDoingButtons(true);
 
 		//runEncoderCaptureSimulated = menuitem_check_race_encoder_capture_simulate.Active; //TODO: show this in some way on 2.0
-		runEncoderCaptureSimulated = false;
+		runEncoderCaptureSimulated = false; //note that on simulated we need to click finish not so late
 
 		/*
 		//initialize
@@ -385,6 +384,8 @@ public partial class ChronoJumpWindow
 		return true;
 	}
 
+	string capturingMessage = "Capturing ...";
+
 	//non GTK on this method
 	private void runEncoderCaptureDo()
 	{
@@ -431,7 +432,7 @@ public partial class ChronoJumpWindow
 				pps = Convert.ToInt32(strPPS[1]);
 		}
 
-		runEncoderPulseMessage = "Capturing ...";
+		runEncoderPulseMessage = capturingMessage;
 
 		//forceCaptureStartMark = true;
 		capturingRunEncoder = arduinoCaptureStatus.CAPTURING;
@@ -550,7 +551,7 @@ public partial class ChronoJumpWindow
 			File.Copy(fileName, RunEncoder.GetCSVFileName(), true); //can be overwritten
 			lastRunEncoderFullPath = fileName;
 
-			raceEncoderCaptureGraphDo();
+			//raceEncoderCaptureGraphDo(); moved to pulseGTKRunEncoderCapture () where currentRunEncoder is created
 
 			capturingRunEncoder = arduinoCaptureStatus.COPIED_TO_TMP;
 		}
@@ -566,6 +567,7 @@ public partial class ChronoJumpWindow
 		// 1) encoderDisplacement (2 bytes)
                 int b0 = portRE.ReadByte(); //encoderDisplacement least significative
                 int b1 = portRE.ReadByte(); //encoderDisplacement most significative
+		LogB.Information(" 1 readed b0,b1");
 		/*
 		LogB.Information("bbbencDispl0:" + b0.ToString());
 		LogB.Information("bbbencDispl1:" + b1.ToString());
@@ -583,6 +585,7 @@ public partial class ChronoJumpWindow
                 b1 = portRE.ReadByte();
                 int b2 = portRE.ReadByte();
                 int b3 = portRE.ReadByte(); //most significative
+		LogB.Information(" 2 readed b0-b3");
 
 		/*
 		LogB.Information("bbbtime0:" + b0.ToString());
@@ -607,6 +610,7 @@ public partial class ChronoJumpWindow
 		b0 = portRE.ReadByte(); //least significative
 		b1 = portRE.ReadByte(); //most significative
 		readedNum = Convert.ToInt32(256 * b1 + b0);
+		LogB.Information(" 3 readed b0,b1");
 
 		/*
 		LogB.Information("bbbforce0:" + b0.ToString());
@@ -688,8 +692,9 @@ public partial class ChronoJumpWindow
 	        foreach	(Person p in personsPre)
 			persons[count++] = p.UniqueID.ToString() + ":" + p.Name;
 		genericWin.SetComboValues(persons, currentPerson.UniqueID + ":" + currentPerson.Name);
-		genericWin.SetComboLabel(Catalog.GetString("Change the owner of selected set") +
-				" (" + Catalog.GetString("code") + ":" + Catalog.GetString("name") + ")");
+		//genericWin.SetComboLabel(Catalog.GetString("Change the owner of selected set") +
+		//		" (" + Catalog.GetString("code") + ":" + Catalog.GetString("name") + ")");
+		genericWin.SetComboLabel(Catalog.GetString("Change person"));
 		genericWin.ShowEditRow(false);
 
 		//select row corresponding to current signal
@@ -957,13 +962,6 @@ public partial class ChronoJumpWindow
 		string title = Util.ChangeSpaceAndMinusForUnderscore(currentPerson.Name) + "-" +
 			Util.ChangeSpaceAndMinusForUnderscore(UtilGtk.ComboGetActive(combo_run_encoder_exercise));
 
-		string dateTimeGraph = "";
-		if(currentRunEncoder != null)
-			dateTimeGraph = currentRunEncoder.DateTimePublic;
-		else
-			dateTimeGraph = UtilDate.ToFile(runEncoderTimeStartCapture);
-
-
 		bool plotRawAccel =
 			( Preferences.runEncoderAnalyzeAccel.SqlCurrentName ==  Preferences.runEncoderAnalyzeAFPSqlRAW ||
 			 Preferences.runEncoderAnalyzeAccel.SqlCurrentName == Preferences.runEncoderAnalyzeAFPSqlBOTH );
@@ -990,8 +988,9 @@ public partial class ChronoJumpWindow
 				currentPersonSession.Height,
 				race_analyzer_temperature,
 				race_analyzer_device,
+				currentRunEncoderExercise, //TODO: do not let capture if there's no exercise
 				title,
-				dateTimeGraph,
+				currentRunEncoder.DateTimePublic,
 				preferences.runEncoderMinAccel,
 				plotRawAccel, plotFittedAccel,
 				plotRawForce, plotFittedForce,
@@ -1125,6 +1124,8 @@ public partial class ChronoJumpWindow
 					sensitiveLastTestButtons(true);
 					contactsShowCaptureDoingButtons(false);
 
+					raceEncoderCaptureGraphDo();
+
 					runEncoderAnalyzeOpenImage();
 					notebook_analyze.CurrentPage = Convert.ToInt32(notebook_analyze_pages.RACEENCODER);
 					radio_mode_contacts_analyze.Active = true;
@@ -1194,8 +1195,13 @@ public partial class ChronoJumpWindow
 			return false;
 		}
 		else
+		{
 			event_execute_label_message.Text = runEncoderPulseMessage;
 
+			if(runEncoderPulseMessage == capturingMessage)
+				event_execute_button_finish.Sensitive = true;
+		}
+
 
 		LogB.Information(" re E ");
 		/*
@@ -1293,7 +1299,7 @@ public partial class ChronoJumpWindow
 		if(currentSession == null || currentSession.UniqueID == -1)
 		{
 			try {
-				System.Diagnostics.Process.Start(RunEncoderGraph.GetDataDir(-1));
+				System.Diagnostics.Process.Start(RunEncoderGraph.GetDataDir(-1)); //also use Util.OpenFolder
 			} catch {
 				new DialogMessage(Constants.MessageTypes.WARNING,
 						Catalog.GetString("Error. Cannot open directory.") + "\n\n" + RunEncoderGraph.GetDataDir(-1));
@@ -1305,7 +1311,7 @@ public partial class ChronoJumpWindow
 		if(dataDir != "")
 		{
 			try {
-				System.Diagnostics.Process.Start(dataDir);
+				System.Diagnostics.Process.Start(dataDir); //also use Util.OpenFolder
 			} catch {
 				new DialogMessage(Constants.MessageTypes.WARNING,
 						Catalog.GetString("Error. Cannot open directory.") + "\n\n" + dataDir);
@@ -1383,6 +1389,7 @@ public partial class ChronoJumpWindow
 
 		ArrayList a1 = new ArrayList();
 		ArrayList a2 = new ArrayList();
+		ArrayList a3 = new ArrayList();
 
 		//0 is the widgget to show; 1 is the editable; 2 id default value
 		a1.Add(Constants.GenericWindowShow.ENTRY); a1.Add(true); a1.Add(ex.Name);
@@ -1391,6 +1398,9 @@ public partial class ChronoJumpWindow
 		a2.Add(Constants.GenericWindowShow.ENTRY2); a2.Add(true); a2.Add(ex.Description);
 		bigArray.Add(a2);
 
+		a3.Add(Constants.GenericWindowShow.SPININT2); a3.Add(true); a3.Add("");
+		bigArray.Add(a3);
+
 		genericWin = GenericWindow.Show(Catalog.GetString("Exercise"), false,	//don't show now
 				Catalog.GetString("Force sensor exercise:"), bigArray);
 		genericWin.LabelEntry2 = Catalog.GetString("Description");
@@ -1399,6 +1409,9 @@ public partial class ChronoJumpWindow
 		genericWin.HideOnAccept = false;
 
 		genericWin.uniqueID = ex.UniqueID;
+		genericWin.LabelSpinInt2 = "Segments size (m)";
+		genericWin.SetSpin2Range(1, 30);
+		genericWin.SetSpin2Value(ex.SegmentMeters);
 
 		genericWin.Button_accept.Clicked -= new EventHandler(on_button_run_encoder_exercise_edit_accepted);
 		genericWin.Button_accept.Clicked += new EventHandler(on_button_run_encoder_exercise_edit_accepted);
@@ -1411,6 +1424,7 @@ public partial class ChronoJumpWindow
 
 		ArrayList a1 = new ArrayList();
 		ArrayList a2 = new ArrayList();
+		ArrayList a3 = new ArrayList();
 
 		//0 is the widgget to show; 1 is the editable; 2 id default value
 		a1.Add(Constants.GenericWindowShow.ENTRY); a1.Add(true); a1.Add("");
@@ -1419,6 +1433,9 @@ public partial class ChronoJumpWindow
 		a2.Add(Constants.GenericWindowShow.ENTRY2); a2.Add(true); a2.Add("");
 		bigArray.Add(a2);
 
+		a3.Add(Constants.GenericWindowShow.SPININT2); a3.Add(true); a3.Add("");
+		bigArray.Add(a3);
+
 		genericWin = GenericWindow.Show(Catalog.GetString("Exercise"), false,	//don't show now
 				Catalog.GetString("Write the name of the exercise:"), bigArray);
 		genericWin.LabelEntry2 = Catalog.GetString("Description");
@@ -1426,6 +1443,10 @@ public partial class ChronoJumpWindow
 		genericWin.SetButtonAcceptLabel(Catalog.GetString("Add"));
 		genericWin.HideOnAccept = false;
 
+		genericWin.LabelSpinInt2 = "Segments size (m)";
+		genericWin.SetSpin2Range(1, 30);
+		genericWin.SetSpin2Value(RunEncoderExercise.SegmentMetersDefault);
+
 		genericWin.Button_accept.Clicked -= new EventHandler(on_button_run_encoder_exercise_add_accepted);
 		genericWin.Button_accept.Clicked += new EventHandler(on_button_run_encoder_exercise_add_accepted);
 		genericWin.ShowNow();
@@ -1483,9 +1504,12 @@ public partial class ChronoJumpWindow
 		}
 
 		if(adding)
-			SqliteRunEncoderExercise.Insert(false, -1, name, genericWin.Entry2Selected);
+			SqliteRunEncoderExercise.Insert(false, -1, name,
+					genericWin.Entry2Selected, genericWin.SpinInt2Selected);
 		else {
-			RunEncoderExercise ex = new RunEncoderExercise(genericWin.uniqueID, name, genericWin.Entry2Selected);
+			RunEncoderExercise ex = new RunEncoderExercise(genericWin.uniqueID, name,
+					genericWin.Entry2Selected, genericWin.SpinInt2Selected);
+
 			SqliteRunEncoderExercise.Update(false, ex);
 		}
 
