@@ -31,44 +31,9 @@ using Mono.Unix;
 
 public partial class ChronoJumpWindow
 {
-	[Widget] Gtk.Window app1sae_session_add_edit;
-	[Widget] Gtk.Entry app1sae_entry_name;
-	[Widget] Gtk.Entry app1sae_entry_place;
-
-	[Widget] Gtk.Label app1sae_label_session_add;
-	[Widget] Gtk.Label app1sae_label_session_edit;
-	[Widget] Gtk.Label app1sae_label_name;
-	[Widget] Gtk.Label app1sae_label_date;
-	
-	[Widget] Gtk.TextView app1sae_textview_comments;
 	//[Widget] Gtk.Button button_delete; //now disabled on edit window, just do it with special button on session/more
-	[Widget] Gtk.Button app1sae_button_accept;
-
-	[Widget] Gtk.Image image_sport_undefined;
-	[Widget] Gtk.Image image_speciallity_undefined;
-	[Widget] Gtk.Image image_level_undefined;
-	[Widget] Gtk.RadioButton app1sae_radiobutton_diff_sports;
-	[Widget] Gtk.RadioButton app1sae_radiobutton_same_sport;
-	[Widget] Gtk.RadioButton app1sae_radiobutton_diff_speciallities;
-	[Widget] Gtk.RadioButton app1sae_radiobutton_same_speciallity;
-	[Widget] Gtk.RadioButton app1sae_radiobutton_diff_levels;
-	[Widget] Gtk.RadioButton app1sae_radiobutton_same_level;
-	[Widget] Gtk.Box app1sae_hbox_sports;
-	[Widget] Gtk.Box app1sae_hbox_combo_sports;
-	[Widget] Gtk.ComboBox app1sae_combo_sports;
-	[Widget] Gtk.Box app1sae_vbox_speciallity;
-	[Widget] Gtk.Label app1sae_label_speciallity;
-	[Widget] Gtk.Box app1sae_hbox_speciallities;
-	[Widget] Gtk.Box app1sae_hbox_combo_speciallities;
-	[Widget] Gtk.ComboBox app1sae_combo_speciallities;
-	[Widget] Gtk.Box app1sae_vbox_level;
-	[Widget] Gtk.Label app1sae_label_level;
-	[Widget] Gtk.Box app1sae_hbox_levels;
-	[Widget] Gtk.Box app1sae_hbox_combo_levels;
-	[Widget] Gtk.ComboBox app1sae_combo_levels;
-	
-//	[Widget] Gtk.Label app1sae_label_persons_data;
-//	[Widget] Gtk.TextView app1sae_textview_persons_data;
+	//[Widget] Gtk.Label app1sae_label_persons_data;
+	//[Widget] Gtk.TextView app1sae_textview_persons_data;
 
 	DialogCalendar app1sae_dialogCalendar;
 	DateTime app1sae_dateTime;
@@ -89,6 +54,7 @@ public partial class ChronoJumpWindow
 	private void sessionAddEditShow (bool addSession)
 	{
 		app1s_notebook.CurrentPage = app1s_PAGE_ADD_EDIT;
+		app1sae_notebook_add_edit.CurrentPage = 0;
 
 		app1sae_addSession = addSession;
 
@@ -112,8 +78,8 @@ public partial class ChronoJumpWindow
 		app1sae_hbox_levels.Visible = false;
 
 		if(addSession) {
-			app1sae_label_session_add.Visible = true;
-			app1sae_label_session_edit.Visible = false;
+			hbox_session_add.Visible = true;
+			hbox_session_more_edit.Visible = false;
 			app1sae_dateTime = DateTime.Today;
 			app1sae_entry_name.Text = "";
 			app1sae_entry_place.Text = "";
@@ -131,8 +97,8 @@ public partial class ChronoJumpWindow
 			app1sae_button_accept.Sensitive = false;
 		
 		} else {
-			app1sae_label_session_add.Visible = false;
-			app1sae_label_session_edit.Visible = true;
+			hbox_session_add.Visible = false;
+			hbox_session_more_edit.Visible = true;
 
 			app1sae_dateTime = currentSession.Date;
 
@@ -644,51 +610,76 @@ public partial class ChronoJumpWindow
 	
 	void app1sae_on_button_accept_clicked (object o, EventArgs args)
 	{
+		//there is a bug here, just print some stuff to find it in next log
+		LogB.Information("app1sae_on_button_accept_clicked 0");
 		//check if name of session exists (is owned by other session),
 		//but all is ok if the name is the same as the old name (editing)
 		string name = Util.RemoveTildeAndColon(app1sae_entry_name.Text);
 		name = Util.RemoveChar(name, '/');
+		LogB.Information("app1sae_on_button_accept_clicked 1");
 
 		bool sessionNameExists = Sqlite.Exists (false, Constants.SessionTable, name);
-		if(sessionNameExists && name != currentSession.Name )
+		if(sessionNameExists && app1sae_addSession)
 		{
+			//if we try to add a new session with same name ...
+			LogB.Information("app1sae_on_button_accept_clicked add existing ...");
 			string myString = string.Format(Catalog.GetString("Session: '{0}' exists. Please, use another name"), name);
 			ErrorWindow.Show(myString);
+			LogB.Information("app1sae_on_button_accept_clicked add existing done!");
+		}
+		else if( sessionNameExists && ! app1sae_addSession && (currentSession == null || name != currentSession.Name) )
+		{
+			//if we edit a session but we changed name and it matches another existing session ...
+			LogB.Information("app1sae_on_button_accept_clicked edit existing not me ...");
+			string myString = string.Format(Catalog.GetString("Session: '{0}' exists. Please, use another name"), name);
+			ErrorWindow.Show(myString);
+			LogB.Information("app1sae_on_button_accept_clicked edit existing not me done!");
+
 		} else {
+			LogB.Information("app1sae_on_button_accept_clicked 4");
 			int sportID;
 			if(app1sae_radiobutton_diff_sports.Active)
 				sportID = Constants.SportUndefinedID;
 			else {
 				sportID = Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(app1sae_combo_sports), app1sae_sports));
 			}
+			LogB.Information("app1sae_on_button_accept_clicked 5");
 
 			int speciallityID;
 			if(! app1sae_label_speciallity.Visible || app1sae_radiobutton_diff_speciallities.Active)
 				speciallityID = Constants.SpeciallityUndefinedID; 
 			else
 				speciallityID = Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(app1sae_combo_speciallities), app1sae_speciallities));
+			LogB.Information("app1sae_on_button_accept_clicked 6");
 
 			int levelID;
 			if(! app1sae_label_level.Visible || app1sae_radiobutton_diff_levels.Active)
 				levelID = Constants.LevelUndefinedID;
 			else
 				levelID = Util.FetchID(UtilGtk.ComboGetActive(app1sae_combo_levels));
+			LogB.Information("app1sae_on_button_accept_clicked 7");
 
 			string place = Util.RemoveTildeAndColon(app1sae_entry_place.Text);
 			string comments = Util.RemoveTildeAndColon(app1sae_textview_comments.Buffer.Text);
+			LogB.Information("app1sae_on_button_accept_clicked 8");
 
 			if(app1sae_addSession)
 			{
+				LogB.Information("app1sae_on_button_accept_clicked 9");
 				currentSession = new Session (name, place,
 						app1sae_dateTime,
 						sportID, speciallityID, levelID,
 						comments,
 						Constants.ServerUndefinedID);
 
+				LogB.Information("app1sae_on_button_accept_clicked A");
 				on_new_session_accepted();
+				LogB.Information("app1sae_on_button_accept_clicked B");
 				notebook_supSetOldPage();
+				LogB.Information("app1sae_on_button_accept_clicked C");
 			} else
 			{
+				LogB.Information("app1sae_on_button_accept_clicked D");
 				currentSession.Name = name;
 				currentSession.Place = place;
 				currentSession.Date = app1sae_dateTime;
@@ -697,15 +688,21 @@ public partial class ChronoJumpWindow
 				currentSession.PersonsPractice = levelID;
 				currentSession.Comments = comments;
 
+				LogB.Information("app1sae_on_button_accept_clicked E");
 				SqliteSession.Update(currentSession.UniqueID, currentSession.Name, 
 						currentSession.Place, currentSession.Date, 
 						sportID, speciallityID, levelID,
 						currentSession.Comments);
+				LogB.Information("app1sae_on_button_accept_clicked F");
 
 				on_edit_session_accepted ();
+				LogB.Information("app1sae_on_button_accept_clicked G");
 				app1s_notebook.CurrentPage = app1s_PAGE_MODES;
+				LogB.Information("app1sae_on_button_accept_clicked H");
 			}
+			LogB.Information("app1sae_on_button_accept_clicked I");
 		}
+		LogB.Information("app1sae_on_button_accept_clicked J");
 	}
 
 }
