@@ -23,6 +23,7 @@ using System;
 using System.Collections.Generic; //List
 using Gtk;
 using Cairo;
+using Mono.Unix;
 
 public abstract class CairoXY
 {
@@ -33,6 +34,12 @@ public abstract class CairoXY
 	//regression line straight
 	protected double slope;
 	protected double intercept;
+	protected double f0;
+	protected double f0Rel;
+	protected double v0;
+	//samozino fv
+	protected double f0Opt;
+	protected double v0Opt;
 
 	//regression line parabole
 	protected double[] coefs;
@@ -44,9 +51,11 @@ public abstract class CairoXY
 	protected string title;
 	protected string jumpType;
 	protected string date;
+	protected Cairo.Color colorBackground;
 
 	protected Cairo.Context g;
 	protected const int textHeight = 12;
+	protected const int pointsRadius = 6;
 	protected string xVariable = "";
 	protected string yVariable = "";
 	protected string xUnits = "";
@@ -62,20 +71,43 @@ public abstract class CairoXY
 	protected int graphWidth;
 	protected int graphHeight;
 
-	Cairo.Color black;
+	protected Cairo.Color black;
+	protected Cairo.Color gray99;
 	Cairo.Color white;
-	Cairo.Color red;
+	protected Cairo.Color red;
 	Cairo.Color blue;
+	protected Cairo.Color bluePlots;
 
 	//for all 4 sides
 	protected int outerMargins = 40; //blank space outside the axis.
 	protected int innerMargins = 30; //space between the axis and the real coordinates.
+	private int crossMargins = 10; //cross slope line with margins will have this length
 	int totalMargins;
 
-	public abstract void Do();
+	//translated strings
+	//done to use Catalog just only on gui/cairo/xy.cs
+	//but jumpsWeightFVProfile has many messages, so done also there
+	protected string needToExecuteJumpsStr = Catalog.GetString("Need to execute jumps:");
+	protected string optimalFallHeightStr = Catalog.GetString("Optimal fall height");
+	protected string heightStr = Catalog.GetString("Height");
+	protected string extraWeightStr = Catalog.GetString("Extra weight");
+	protected string fallStr = Catalog.GetString("Fall");
+	protected string speedStr = Catalog.GetString("Speed");
+	protected string forceStr = Catalog.GetString("Force");
+	protected string dateStr = Catalog.GetString("Date");
+	protected string tfStr = Catalog.GetString("TF");
+	protected string tcStr = Catalog.GetString("TC");
+	protected string countStr = Catalog.GetString("Num");
+	protected string jumpTypeStr = Catalog.GetString("Jump type:");
+	protected string font;
 
-	protected void initGraph()
+	public abstract void Do(string font);
+
+	protected void initGraph(string font)
 	{
+		this.font = font;
+		LogB.Information("Font: " + font);
+
 		totalMargins = outerMargins + innerMargins;
 
 		//1 create context
@@ -92,18 +124,22 @@ public abstract class CairoXY
 		g.LineWidth = 2;
 
 		//4 prepare font
-		g.SelectFontFace("Helvetica", Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
+		g.SelectFontFace(font, Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
 		g.SetFontSize(textHeight);
 
 		black = colorFromRGB(0,0,0);
+		gray99 = colorFromRGB(99,99,99);
 		white = colorFromRGB(255,255,255);
 		red = colorFromRGB(200,0,0);
 		blue = colorFromRGB(178, 223, 238); //lightblue
+		bluePlots = colorFromRGB(0, 0, 200);
 
 		predictedPointDone = false;
 	}
 
-	protected void findPointMaximums()
+	//showFullGraph means that has to plot both axis at 0 and maximums have to be f0,v0
+	//used by default on jumpsWeightFVProfile
+	protected void findPointMaximums(bool showFullGraph)
 	{
 		foreach(PointF p in point_l)
 		{
@@ -117,6 +153,28 @@ public abstract class CairoXY
 				maxY = p.Y;
 		}
 
+		if (showFullGraph)
+		{
+			minX = 0;
+			minY = 0;
+
+			//fix axis problems if F0 or V0 are not ok
+			if(f0Rel > 0 && v0 > 0)
+			{
+				maxX = v0;
+				if(v0Opt > v0)
+					maxX = v0Opt;
+
+				maxY = f0Rel;
+				if(f0Opt > f0Rel)
+					maxY = f0Opt;
+			}
+
+			//have maxX and maxY a 2.5% bigger to have a nicer cut with the predicted line
+			maxX += .025 * maxX;
+			maxY += .025 * maxY;
+		}
+
 		//if there is only one point, or by any reason mins == maxs, have mins and maxs separated
 		separateMinXMaxXIfNeeded();
 		separateMinYMaxYIfNeeded();
@@ -125,6 +183,72 @@ public abstract class CairoXY
 		absoluteMaxY = maxY;
 	}
 
+	protected void plotAlternativeLineWithRealPoints (double ax, double ay, double bx, double by, bool showFullGraph)
+	{
+		LeastSquaresLine lsl = new LeastSquaresLine();
+		List<PointF> measures = new List<PointF> {
+			new PointF(ax, ay), new PointF(bx, by) };
+		lsl.Calculate(measures);
+
+		g.SetSourceRGB(255,0,0);
+		if(showFullGraph)
+			plotPredictedLine(predictedLineTypes.STRAIGHT, predictedLineCrossMargins.CROSS, lsl.Slope, lsl.Intercept);
+		else
+			plotPredictedLine(predictedLineTypes.STRAIGHT, predictedLineCrossMargins.DONOTTOUCH, lsl.Slope, lsl.Intercept);
+		g.SetSourceRGB(0,0,0);
+	}
+
+	//horiz or vertical to manage spacement of arrow points and tip draw
+	protected void plotArrow (double ax, double ay, double bx, double by, bool horiz, int spacement)
+	{
+		// 1) convert to graph coordinates
+		ax = calculatePaintX(ax);
+		ay = calculatePaintY(ay);
+		bx = calculatePaintX(bx);
+		by = calculatePaintY(by);
+
+		// 2) have spacements
+		if(horiz) {
+			ax += spacement;
+			bx -= spacement;
+		} else {
+			ay -= spacement;
+			by += spacement;
+		}
+		g.SetSourceRGB(255,0,0);
+
+		// 3) write line (if it fits)
+		if(horiz && bx > ax || ! horiz && ay > by)
+		{
+			g.MoveTo(ax, ay);
+			g.LineTo(bx, by);
+		} else {
+			//if it does not fit, move bx or by to have the arrow at the middle
+			if(horiz)
+				bx = Convert.ToInt32((ax + bx) / 2);
+			else
+				by = Convert.ToInt32((ay + by) / 2);
+			g.MoveTo(bx, by);
+		}
+
+		// 4) write arrow tip
+
+		int tip = 5;
+		if(horiz) {
+			g.LineTo(bx - tip, by - tip);
+			g.MoveTo(bx, by);
+			g.LineTo(bx - tip, by + tip);
+		} else {
+			g.LineTo(bx - tip, by + tip);
+			g.MoveTo(bx, by);
+			g.LineTo(bx + tip, by + tip);
+		}
+
+		// 5) end
+		g.Stroke ();
+		g.SetSourceRGB(0,0,0);
+	}
+
 	protected virtual void separateMinXMaxXIfNeeded()
 	{
 		if(minX == maxX)
@@ -160,17 +284,28 @@ public abstract class CairoXY
 		}
 	}
 
-	protected void paintAxisAndGrid(gridTypes gridType)
+	//reccomended to 1st paint the grid, then the axis
+	protected void paintGrid(gridTypes gridType, bool niceAutoValues)
+	{
+		g.LineWidth = 1; //to allow to be shown the red arrows on jumpsWeightFVProfile
+
+		if(niceAutoValues)
+			paintGridNiceAutoValues (minX, absoluteMaxX, minY, absoluteMaxY, 5, gridType);
+		else
+			paintGridInt (minX, absoluteMaxX, minY, absoluteMaxY, 1, gridType);
+	}
+
+	protected void paintAxis()
 	{
-		//1 paint axis
 		g.MoveTo(outerMargins, outerMargins);
 		g.LineTo(outerMargins, graphHeight - outerMargins);
 		g.LineTo(graphWidth - outerMargins, graphHeight - outerMargins);
 		g.Stroke ();
-		printText(2, Convert.ToInt32(outerMargins/2), 0, textHeight, getYAxisLabel(), g, false);
-		printText(graphWidth - Convert.ToInt32(outerMargins/2), graphHeight - outerMargins, 0, textHeight, getXAxisLabel(), g, false);
+		printText(2, Convert.ToInt32(outerMargins/2), 0, textHeight, getYAxisLabel(), g, alignTypes.LEFT);
+		printText(graphWidth - Convert.ToInt32(outerMargins/2), graphHeight - outerMargins, 0, textHeight, getXAxisLabel(), g, alignTypes.LEFT);
 
-		paintGrid (minX, absoluteMaxX, minY, absoluteMaxY, 5, gridType);
+		g.Stroke ();
+		g.LineWidth = 2;
 	}
 
 	private string getXAxisLabel()
@@ -189,7 +324,12 @@ public abstract class CairoXY
 	}
 
 	protected enum predictedLineTypes { STRAIGHT, PARABOLE }
-	protected void plotPredictedLine(predictedLineTypes plt)
+	protected enum predictedLineCrossMargins { TOUCH, CROSS, DONOTTOUCH }
+	protected void plotPredictedLine(predictedLineTypes plt, predictedLineCrossMargins crossMarginType)
+	{
+		plotPredictedLine(plt, crossMarginType, slope, intercept);
+	}
+	protected void plotPredictedLine(predictedLineTypes plt, predictedLineCrossMargins crossMarginType, double slope, double intercept)
 	{
 		bool firstValue = false;
 		double range = absoluteMaxX - minX;
@@ -218,10 +358,18 @@ public abstract class CairoXY
 			else //(plt == predictedLineTypes.PARABOLE)
 				ygraph = calculatePaintY(coefs[0] + coefs[1]*x + coefs[2]*Math.Pow(x,2));
 
-			//do not plot line outer the axis
+			// ---- do not plot line outer the axis ---->
+			int om = outerMargins;
+
+			// have a bit more distance
+			if(crossMarginType == predictedLineCrossMargins.CROSS)
+				om -= crossMargins;
+			else if(crossMarginType == predictedLineCrossMargins.DONOTTOUCH)
+				om += crossMargins;
+
 			if(
-					xgraph < outerMargins || xgraph > graphWidth - outerMargins ||
-					ygraph < outerMargins || ygraph > graphHeight - outerMargins )
+					xgraph < om || xgraph > graphWidth - om ||
+					ygraph < om || ygraph > graphHeight - om )
 			{
 				wasOutOfMargins = true;
 				continue;
@@ -231,6 +379,7 @@ public abstract class CairoXY
 
 				wasOutOfMargins = false;
 			}
+			// <---- end of do not plot line outer the axis ----
 
 			if(! firstValue)
 				g.LineTo(xgraph, ygraph);
@@ -241,17 +390,32 @@ public abstract class CairoXY
 		g.Stroke ();
 	}
 
-	protected void plotRealPoints()
+	protected void plotRealPoints(bool joinByLine)
 	{
+		if(joinByLine) //draw line first to not overlap the points
+		{
+			bool firstDone = false;
+			foreach(PointF p in point_l)
+			{
+				double xgraph = calculatePaintX(p.X);
+				double ygraph = calculatePaintY(p.Y);
+
+				if(! firstDone)
+				{
+					g.MoveTo(xgraph, ygraph);
+					firstDone = true;
+				} else
+					g.LineTo(xgraph, ygraph);
+			}
+			g.Stroke ();
+		}
+
 		foreach(PointF p in point_l)
 		{
-			LogB.Information(string.Format("point: {0}", p));
 			double xgraph = calculatePaintX(p.X);
 			double ygraph = calculatePaintY(p.Y);
-			LogB.Information(string.Format("{0}, {1}", xgraph, ygraph));
-			g.MoveTo(xgraph+6, ygraph);
-			g.Arc(xgraph, ygraph, 6.0, 0.0, 2.0 * Math.PI); //full circle
-			g.Color = blue;
+			g.Arc(xgraph, ygraph, pointsRadius, 0.0, 2.0 * Math.PI); //full circle
+			g.Color = colorBackground;
 			g.FillPreserve();
 			g.SetSourceRGB(0, 0, 0);
 			g.Stroke ();
@@ -261,13 +425,8 @@ public abstract class CairoXY
 			printText(xgraph, graphHeight - Convert.ToInt32(bottomMargin/2), 0, textHeight, Util.TrimDecimals(p.X, 2), g, true);
 			printText(Convert.ToInt32(leftMargin/2), ygraph, 0, textHeight, Util.TrimDecimals(p.Y, 2), g, true);
 			*/
-
-			LogB.Information(string.Format("xgraph: {0} corresponds to x real point: {1}", xgraph,
-						calculateRealX(xgraph)));
-			LogB.Information(string.Format("ygraph: {0} corresponds to y real point: {1}", ygraph,
-						calculateRealY(ygraph)));
 		}
-		getMinMaxXDrawable(graphWidth, absoluteMaxX, minX, totalMargins, totalMargins);
+		//getMinMaxXDrawable(graphWidth, absoluteMaxX, minX, totalMargins, totalMargins);
 	}
 
 	protected void plotPredictedMaxPoint()
@@ -298,32 +457,32 @@ public abstract class CairoXY
 
 	protected void writeTextPredictedPoint()
 	{
-		writeTextAtRight(0, "Fall: " + Util.TrimDecimals(xAtMMaxY, 2) + " cm", false);
-		writeTextAtRight(1, "Jump height: " + Util.TrimDecimals(yAtMMaxY, 2) + " cm", false);
+		writeTextAtRight(0, fallStr + ": " + Util.TrimDecimals(xAtMMaxY, 2) + " cm", false);
+		writeTextAtRight(1, heightStr + ": " + Util.TrimDecimals(yAtMMaxY, 2) + " cm", false);
 	}
 
 	protected void writeTextConcaveParabole()
 	{
-		writeTextAtRight(0, "Error:", false);
-		writeTextAtRight(1, "Parabole is concave", false);
+		writeTextAtRight(0, Catalog.GetString("Error") + ":", false);
+		writeTextAtRight(1, Catalog.GetString("Parabole is concave"), false);
 	}
 
 	protected void writeTextNeed3PointsWithDifferentFall()
 	{
-		writeTextAtRight(0, "Error:", false);
-		writeTextAtRight(1, "Need at least 3 points", false);
-		writeTextAtRight(2, "with different falling heights", false);
+		writeTextAtRight(0, Catalog.GetString("Error") + ":", false);
+		writeTextAtRight(1, Catalog.GetString("Need at least 3 points"), false);
+		writeTextAtRight(2, Catalog.GetString("with different falling heights"), false);
 	}
 
-	protected void writeTextAtRight(int line, string text, bool bold)
+	protected void writeTextAtRight(double line, string text, bool bold)
 	{
 		if(bold)
-			g.SelectFontFace("Helvetica", Cairo.FontSlant.Normal, Cairo.FontWeight.Bold);
+			g.SelectFontFace(font, Cairo.FontSlant.Normal, Cairo.FontWeight.Bold);
+
+		printText(graphWidth, Convert.ToInt32(graphHeight/2 + textHeight*2*line), 0, textHeight, text, g, alignTypes.LEFT);
 
-		printText(graphWidth + Convert.ToInt32(outerMargins/2), Convert.ToInt32(graphHeight/2) + textHeight*2*line, 0, textHeight, text, g, false);
-		
 		if(bold)
-			g.SelectFontFace("Helvetica", Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
+			g.SelectFontFace(font, Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
 	}
 
 	protected void writeCoordinatesOfMouseClick(double graphX, double graphY, double realX, double realY)
@@ -359,19 +518,27 @@ public abstract class CairoXY
 		writeTextAtRight(line +1, "Y: " + Util.TrimDecimals(realY, 2), false);
 		*/
 
+		LogB.Information("calling findClosestGraphPoint ...");
 		// 3) find closest point (including predicted point if any)
 		PointF pClosest = findClosestGraphPoint(graphX, graphY);
 
+		LogB.Information("writeSelectedValues ...");
 		// 4) write text at right
-		writeTextAtRight(line, "Selected:", false);
-		writeTextAtRight(line +1, string.Format("{0}: {1} {2}", xVariable, Util.TrimDecimals(pClosest.X, 2), xUnits), false);
-		writeTextAtRight(line +2, string.Format("{0}: {1} {2}", yVariable, Util.TrimDecimals(pClosest.Y, 2), yUnits), false);
+		writeSelectedValues(line, pClosest);
 
+		LogB.Information("painting rectangle ...");
+		// 4) write text at right
 		// 5) paint rectangle around that point
-		g.Color = red;
-		g.Rectangle(calculatePaintX(pClosest.X) -12, calculatePaintY(pClosest.Y) -12, 24, 24);
+		g.Color = bluePlots;
+		g.Rectangle(calculatePaintX(pClosest.X) - 2*pointsRadius, calculatePaintY(pClosest.Y) -2*pointsRadius,
+				4*pointsRadius, 4*pointsRadius);
 		g.Stroke();
 		g.Color = black;
+		LogB.Information("writeCoordinatesOfMouseClick done! disposing");
+
+		endGraphDisposing();
+
+		LogB.Information("writeCoordinatesOfMouseClick disposed!");
 	}
 
 	/*
@@ -392,14 +559,30 @@ public abstract class CairoXY
 			}
 		}
 
-		//also check predicted point if exits
+		//also check predicted point if exists
 		if(predictedPointDone && Math.Sqrt(Math.Pow(graphX - calculatePaintX(xAtMMaxY), 2) + Math.Pow(graphY - calculatePaintY(yAtMMaxY), 2)) < distMin)
 			pClosest = new PointF(xAtMMaxY, yAtMMaxY);
 
 		return pClosest;
 	}
 
-	protected void endGraph()
+	protected virtual void writeSelectedValues(int line, PointF pClosest)
+	{
+		g.Color = bluePlots;
+		writeTextAtRight(line, Catalog.GetString("Selected") + ":", false);
+		g.SetSourceRGB(0, 0, 0);
+
+		writeTextAtRight(line +1, string.Format("- {0}: {1} {2}", xVariable, Util.TrimDecimals(pClosest.X, 2), xUnits), false);
+		writeTextAtRight(line +2, string.Format("- {0}: {1} {2}", yVariable, Util.TrimDecimals(pClosest.Y, 2), yUnits), false);
+	}
+
+	/*
+	   need to dispose because Cairo does not clean ok on win and mac:
+	   Don’t forget to manually dispose the Context and the target Surface at the end of the expose event. Automatic garbage collecting is not yet 100% working in Cairo.
+		https://www.mono-project.com/docs/tools+libraries/libraries/Mono.Cairo/
+		eg. on Linux can do the writeCoordinatesOfMouseClick() without disposing, but on win and mac does not work, so dispose always.
+	 */
+	protected void endGraphDisposing()
 	{
 		g.GetTarget().Dispose ();
 		g.Dispose ();
@@ -407,7 +590,7 @@ public abstract class CairoXY
 
 	//TODO: fix if min == max (crashes)
 	protected enum gridTypes { BOTH, HORIZONTALLINES, VERTICALLINES }
-	protected void paintGrid (double minX, double maxX, double minY, double maxY, int seps, gridTypes gridType)
+	protected void paintGridNiceAutoValues (double minX, double maxX, double minY, double maxY, int seps, gridTypes gridType)
 	{
 		var gridXTuple = getGridStepAndBoundaries ((decimal) minX, (decimal) maxX, seps);
 		var gridYTuple = getGridStepAndBoundaries ((decimal) minY, (decimal) maxY, seps);
@@ -418,7 +601,7 @@ public abstract class CairoXY
 			for(double i = gridXTuple.Item1; i <= gridXTuple.Item2 ; i += gridXTuple.Item3)
 			{
 				int xtemp = Convert.ToInt32(calculatePaintX(i));
-				if(xtemp < outerMargins || xtemp > graphWidth - outerMargins)
+				if(xtemp <= outerMargins || xtemp >= graphWidth - outerMargins)
 					continue;
 
 				paintVerticalGridLine(xtemp, Util.TrimDecimals(i, 2));
@@ -428,7 +611,35 @@ public abstract class CairoXY
 			for(double i = gridYTuple.Item1; i <= gridYTuple.Item2 ; i += gridYTuple.Item3)
 			{
 				int ytemp = Convert.ToInt32(calculatePaintY(i));
-				if(ytemp < outerMargins || ytemp > graphHeight - outerMargins)
+				if(ytemp <= outerMargins || ytemp >= graphHeight - outerMargins)
+					continue;
+
+				paintHorizontalGridLine(ytemp, Util.TrimDecimals(i, 2));
+			}
+		g.Stroke ();
+		g.Restore();
+	}
+
+	//for a grid of integers
+	protected void paintGridInt (double minX, double maxX, double minY, double maxY, int by, gridTypes gridType)
+	{
+		g.Save();
+		g.SetDash(new double[]{1, 2}, 0);
+		if(gridType != gridTypes.HORIZONTALLINES)
+			for(double i = Math.Floor(minX); i <= Math.Ceiling(maxX) ; i += by)
+			{
+				int xtemp = Convert.ToInt32(calculatePaintX(i));
+				if(xtemp <= outerMargins || xtemp >= graphWidth - outerMargins)
+					continue;
+
+				paintVerticalGridLine(xtemp, Util.TrimDecimals(i, 2));
+			}
+
+		if(gridType != gridTypes.VERTICALLINES)
+			for(double i = Math.Floor(minX); i <= Math.Ceiling(maxY) ; i += by)
+			{
+				int ytemp = Convert.ToInt32(calculatePaintY(i));
+				if(ytemp <= outerMargins || ytemp >= graphHeight - outerMargins)
 					continue;
 
 				paintHorizontalGridLine(ytemp, Util.TrimDecimals(i, 2));
@@ -441,13 +652,13 @@ public abstract class CairoXY
 	{
 		g.MoveTo(outerMargins, ytemp);
 		g.LineTo(graphWidth - outerMargins, ytemp);
-		printText(Convert.ToInt32(outerMargins/2), ytemp, 0, textHeight, text, g, true);
+		printText(Convert.ToInt32(outerMargins/2), ytemp, 0, textHeight, text, g, alignTypes.CENTER);
 	}
 	protected void paintVerticalGridLine(int xtemp, string text)
 	{
 		g.MoveTo(xtemp, graphHeight - outerMargins);
 		g.LineTo(xtemp, outerMargins);
-		printText(xtemp, graphHeight - Convert.ToInt32(outerMargins/2), 0, textHeight, text, g, true);
+		printText(xtemp, graphHeight - Convert.ToInt32(outerMargins/2), 0, textHeight, text, g, alignTypes.CENTER);
 	}
 
 
@@ -560,6 +771,7 @@ public abstract class CairoXY
 		writeCoordinatesOfMouseClick(graphX, graphY, calculateRealX(graphX), calculateRealY(graphY));
 	}
 
+	/*
 	private void getMinMaxXDrawable(int ancho, double maxValue, double minValue, int rightMargin, int leftMargin)
 	{
 		LogB.Information(string.Format("Real points fitting on graph margins:  {0} , {1}",
@@ -567,21 +779,34 @@ public abstract class CairoXY
 					calculateRealX(graphWidth - totalMargins)
 					));
 	}
+	*/
 
+	//0 - 255
 	protected Cairo.Color colorFromRGB(int red, int green, int blue)
 	{
 		return new Cairo.Color(red/256.0, green/256.0, blue/256.0);
 	}
+	//0 - 65535
+	protected Cairo.Color colorFromGdk(Gdk.Color color)
+	{
+		return new Cairo.Color(color.Red/65536.0, color.Green/65536.0, color.Blue/65536.0);
+	}
 
-	protected void printText (int x, int y, int height, int textHeight, string text, Cairo.Context g, bool centered)
+	protected enum alignTypes { LEFT, CENTER, RIGHT }
+	protected void printText (int x, int y, int height, int textHeight, string text, Cairo.Context g, alignTypes align)
 	{
 		int moveToLeft = 0;
-		if(centered)
+		if(align == alignTypes.CENTER || align == alignTypes.RIGHT)
 		{
 			Cairo.TextExtents te;
 			te = g.TextExtents(text);
-			moveToLeft = Convert.ToInt32(te.Width/2);
+			
+			if(align == alignTypes.CENTER)
+				moveToLeft = Convert.ToInt32(te.Width/2);
+			else
+				moveToLeft = Convert.ToInt32(te.Width);
 		}
+
 		g.MoveTo( x - moveToLeft, ((y+y+height)/2) + textHeight/2 );
 		g.ShowText(text);
 	}
