@@ -27,7 +27,7 @@ using Mono.Unix;
 
 public class TypePix
 {
-	public ChronopicRegisterPort.Types Type; //public enum Types { UNKNOWN, CONTACTS, ENCODER, ARDUINO_FORCE, ARDUINO_RFID, ARDUINO_RUN_ENCODER, ACCELEROMETER }
+	public ChronopicRegisterPort.Types Type;
 	public Pixbuf Pix;
 
 	public TypePix(ChronopicRegisterPort.Types type, Pixbuf pix)
@@ -53,6 +53,27 @@ public static class TypePixList
 		l.Add(new TypePix(ChronopicRegisterPort.Types.ENCODER, new Pixbuf (null, Util.GetImagePath(false) + "board-encoder.png")));
 		l.Add(new TypePix(ChronopicRegisterPort.Types.ARDUINO_RFID, new Pixbuf (null, Util.GetImagePath(false) + "board-arduino-rfid.png")));
 		//l.Add(new TypePix(ChronopicRegisterPort.Types.ACCELEROMETER, new Pixbuf (null, Util.GetImagePath(false) + "board-accelerometer.png")));
+		l.Add(new TypePix(ChronopicRegisterPort.Types.RUN_WIRELESS, new Pixbuf (null, Util.GetImagePath(false) + "board-run-wireless.png")));
+	}
+
+	//used to hide new unfinished devices on chronojump release
+	public static void RemovePix(ChronopicRegisterPort.Types type)
+	{
+		int i = 0;
+		int pos = -1;
+		foreach(TypePix tp in l)
+		{
+			if(tp.Type == type)
+			{
+				pos = i;
+				break;
+			}
+
+			i ++;
+		}
+
+		if(pos >= 0)
+			l.RemoveAt(pos);
 	}
 
 	public static Pixbuf GetPix(ChronopicRegisterPort.Types type)
@@ -99,18 +120,33 @@ public static class TypePixList
 public class ChronopicRegisterWindow
 {
 	Gtk.Window chronopic_register_win;
+	Gtk.VBox vbox_top;
 	Gtk.VBox vbox_main;
 	private List<ChronopicRegisterPort> listConnected;
 	public Gtk.Button FakeButtonCloseSerialPort;
 
-	public ChronopicRegisterWindow(Gtk.Window app1, List<ChronopicRegisterPort> listAll)
+	public ChronopicRegisterWindow(Gtk.Window app1, List<ChronopicRegisterPort> listAll, bool compujump, bool showRunWireless)
 	{
+		// 1) remove undesired Pixs from list
+		if(! compujump)
+			TypePixList.RemovePix(ChronopicRegisterPort.Types.ARDUINO_RFID);
+
+		if(! showRunWireless)
+			TypePixList.RemovePix(ChronopicRegisterPort.Types.RUN_WIRELESS);
+
+		// 2) create window
+
 		createWindow(app1);
 		UtilGtk.IconWindow(chronopic_register_win); //put an icon to window
 
+		//manage window color
+		if(! Config.UseSystemColor)
+			UtilGtk.WindowColor(chronopic_register_win, Config.ColorBackground);
+
 		listConnected = new List<ChronopicRegisterPort>();
 
-		//create listConnected with connected chronopics
+		// 3)create listConnected with connected chronopics
+
 		int connectedCount = 0;
 		int unknownCount = 0;
 		foreach(ChronopicRegisterPort crp in listAll)
@@ -125,7 +161,7 @@ public class ChronopicRegisterWindow
 			}
 		}
 
-		createVBoxMain();
+		createVBoxsViewportAndFrame();
 		createContent(connectedCount, unknownCount);
 		createButtons();
 	}
@@ -143,6 +179,7 @@ public class ChronopicRegisterWindow
 		chronopic_register_win.Modal = true;
 		chronopic_register_win.TransientFor = app1;
 		chronopic_register_win.WindowPosition = Gtk.WindowPosition.CenterOnParent;
+		chronopic_register_win.TypeHint = WindowTypeHint.Dialog;
 
 		chronopic_register_win.DeleteEvent += on_delete_event;
 
@@ -150,10 +187,25 @@ public class ChronopicRegisterWindow
 		chronopic_register_win.BorderWidth= 20;
 	}
 
-	private void createVBoxMain()
+	private void createVBoxsViewportAndFrame()
 	{
-		vbox_main = new Gtk.VBox(false, 20);
-		chronopic_register_win.Add(vbox_main);
+		vbox_main = new Gtk.VBox(false, 12);
+		Gtk.Viewport viewport = new Gtk.Viewport(null, null);
+		Gtk.Frame frame = new Gtk.Frame();
+		frame.LabelXalign = 0;
+		frame.LabelYalign = 1;
+		frame.ShadowType = ShadowType.In;
+
+		vbox_main.BorderWidth = 8;
+		viewport.Add(vbox_main);
+
+		viewport.BorderWidth = 4;
+		frame.Add(viewport);
+
+		vbox_top = new Gtk.VBox(false, 20);
+		vbox_top.Add(frame);
+
+		chronopic_register_win.Add(vbox_top);
 	}
 
 	Gtk.Table table_main;
@@ -365,7 +417,7 @@ public class ChronopicRegisterWindow
 
 		hbox.Add(button_close);
 
-		vbox_main.Add(hbox);
+		vbox_top.Add(hbox);
 	}
 
 	private void on_button_left_clicked(object o, EventArgs args)
