@@ -26,7 +26,7 @@ using Glade;
 public class DialogMessage
 {
 	[Widget] Gtk.Dialog dialog_message;
-	[Widget] Gtk.ScrolledWindow scrolledwindow;
+	[Widget] Gtk.ScrolledWindow scrolledwindow_by_software;
 	[Widget] Gtk.Label label_message;
 
 	[Widget] Gtk.Image image_warning;
@@ -34,7 +34,7 @@ public class DialogMessage
 	[Widget] Gtk.Image image_help;
 	[Widget] Gtk.Image image_inspect;
 
-	[Widget] Gtk.Box hbox_stiffness_formula;
+	[Widget] Gtk.HBox hbox_stiffness_formula;
 	[Widget] Gtk.Button button_go;
 	public bool Visible;
 	private string button_go_link = "";
@@ -56,7 +56,10 @@ public class DialogMessage
 	{
 		initialize("", type, message, false);
 		if(objectToShow == "hbox_stiffness_formula")
+		{
 			hbox_stiffness_formula.Show();
+			UtilGtk.ContrastLabelsHBox (Config.ColorBackgroundIsDark, hbox_stiffness_formula);
+		}
 		else if(objectToShow == "button_go_r_mac")
 		{
 			button_go_link = Constants.RmacDownload;
@@ -64,7 +67,7 @@ public class DialogMessage
 		}
 	}
 
-	private void initialize(string title, Constants.MessageTypes type, string message, bool showScroledWinBar)
+	private void initialize(string title, Constants.MessageTypes type, string message, bool showScrolledWinBar)
 	{
 		LogB.Information("Dialog message: " + message);
 
@@ -79,6 +82,10 @@ public class DialogMessage
 
 		//put an icon to window
 		UtilGtk.IconWindow(dialog_message);
+
+		//manage window color
+		if(! Config.UseSystemColor)
+			UtilGtk.DialogColor(dialog_message, Config.ColorBackground);
 	
 		//with this, user doesn't see a moving/changing creation window
 		//if uncommented, then does weird bug in windows not showing dialog as its correct size until window is moves
@@ -112,13 +119,13 @@ public class DialogMessage
 			break;
 		}
 
-		if(showScroledWinBar)
+		if(showScrolledWinBar)
 		{
 			dialog_message.HeightRequest = 450;
-			scrolledwindow.SetPolicy(PolicyType.Never, PolicyType.Automatic);
+			scrolledwindow_by_software.SetPolicy(PolicyType.Never, PolicyType.Automatic);
 		}
 		else
-			scrolledwindow.SetPolicy(PolicyType.Never, PolicyType.Never);
+			scrolledwindow_by_software.SetPolicy(PolicyType.Never, PolicyType.Never);
 
 		label_message.Show();	
 		dialog_message.Show();	
@@ -127,11 +134,8 @@ public class DialogMessage
 	public void on_button_go_clicked (object obj, EventArgs args)
 	{
 		LogB.Information("Opening browser (r mac install) to: " + button_go_link);
-		try {
-			System.Diagnostics.Process.Start(button_go_link);
-		} catch {
+		if(! Util.OpenFolder(button_go_link))
 			label_message.Text = Constants.WebsiteNotFoundStr();
-		}
 	}
 
 	public void on_close_button_clicked (object obj, EventArgs args)
