@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2016-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2016-2020   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -33,11 +33,20 @@ public class DialogThreshold
 	[Widget] Gtk.TextView textview_jumps;
 	[Widget] Gtk.TextView textview_races;
 	[Widget] Gtk.TextView textview_other;
+	[Widget] Gtk.RadioButton radio_jumps;
+	[Widget] Gtk.RadioButton radio_races;
+	[Widget] Gtk.RadioButton radio_other;
 
 	[Widget] Gtk.Label label_threshold_name;
 	[Widget] Gtk.Label label_threshold_value;
 	[Widget] Gtk.HScale hscale_threshold;
 
+	//just for the colors
+	[Widget] Gtk.Label label_about;
+	[Widget] Gtk.Label label_radio_jumps;
+	[Widget] Gtk.Label label_radio_races;
+	[Widget] Gtk.Label label_radio_other;
+
 	private int thresholdCurrent;
 	public Button FakeButtonClose;
 
@@ -50,6 +59,18 @@ public class DialogThreshold
 		//put an icon to window
 		UtilGtk.IconWindow(dialog_threshold);
 
+		//manage window color
+		if(! Config.UseSystemColor)
+		{
+			UtilGtk.DialogColor(dialog_threshold, Config.ColorBackground);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_threshold_name);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_threshold_value);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_about);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_radio_jumps);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_radio_races);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_radio_other);
+		}
+
 		FakeButtonClose = new Gtk.Button();
 
 		this.thresholdCurrent = thresholdCurrent;
@@ -61,17 +82,17 @@ public class DialogThreshold
 		if(m == Constants.Menuitem_modes.JUMPSSIMPLE || m == Constants.Menuitem_modes.JUMPSREACTIVE)
 		{
 			label_threshold_name.Text = "<b>" + Catalog.GetString("Threshold for jumps") + "</b>";
-			notebook.CurrentPage = 0;
+			radio_jumps.Active = true;
 		}
                 else if(m == Constants.Menuitem_modes.RUNSSIMPLE || m == Constants.Menuitem_modes.RUNSINTERVALLIC)
 		{
 			label_threshold_name.Text = "<b>" + Catalog.GetString("Threshold for runs") + "</b>";
-			notebook.CurrentPage = 1;
+			radio_races.Active = true;
 		}
 		else 	//other
 		{
 			label_threshold_name.Text = "<b>" + Catalog.GetString("Threshold for other tests") + "</b>";
-			notebook.CurrentPage = 2;
+			radio_other.Active = true;
 		}
 
 		label_threshold_name.UseMarkup = true;
@@ -117,6 +138,24 @@ public class DialogThreshold
 		textview_other.Buffer = tb_other;
 	}
 
+	private void on_radio_jumps_toggled (object o, EventArgs args)
+	{
+		if(radio_jumps.Active)
+			notebook.CurrentPage = 0;
+	}
+
+	private void on_radio_races_toggled (object o, EventArgs args)
+	{
+		if(radio_races.Active)
+			notebook.CurrentPage = 1;
+	}
+
+	private void on_radio_other_toggled (object o, EventArgs args)
+	{
+		if(radio_other.Active)
+			notebook.CurrentPage = 2;
+	}
+
 	public void on_button_close_clicked (object obj, EventArgs args)
 	{
 		FakeButtonClose.Click(); //this will call DestroyDialog() later
