@@ -44,6 +44,13 @@ public class EncoderConfigurationWindow
 	
 	[Widget] Gtk.Button button_previous;
 	[Widget] Gtk.Button button_next;
+
+	//to colorize
+	[Widget] Gtk.Label label_radio_linear;
+	[Widget] Gtk.Label label_radio_rotary_friction;
+	[Widget] Gtk.Label label_radio_rotary_axis;
+	[Widget] Gtk.Label label_check_rotary_friction_inertia_on_axis;
+	[Widget] Gtk.Label label_selected;
 	[Widget] Gtk.Label label_count;
 
 	[Widget] Gtk.TextView textview;
@@ -87,6 +94,7 @@ public class EncoderConfigurationWindow
 	[Widget] Gtk.ComboBox combo_gearedUp;
 		
 	[Widget] Gtk.Box vbox_select_encoder;
+	[Widget] Gtk.Frame frame_notebook_side;
 	[Widget] Gtk.Notebook notebook_side;
 	[Widget] Gtk.TreeView treeview_select;
 	[Widget] Gtk.Image image_import;
@@ -130,7 +138,8 @@ public class EncoderConfigurationWindow
 	int main_gui_extraWeightN;
 
 
-	EncoderConfigurationWindow () {
+	EncoderConfigurationWindow ()
+	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "encoder_configuration.glade", "encoder_configuration", "chronojump");
 		gladeXML.Autoconnect(this);
@@ -174,12 +183,27 @@ public class EncoderConfigurationWindow
 				econfSO);
 
 		//A) side is hidden at start to ensure scr_treeview_select is scrolled and displays correctly the last row
-		EncoderConfigurationWindowBox.notebook_side.Visible = false;
+		EncoderConfigurationWindowBox.frame_notebook_side.Visible = false;
+
+		//B) done colors here because this win is created only once
+		//if done in constructor will not be updated on another color change
+
+		//manage window color
+		if(! Config.UseSystemColor)
+		{
+			UtilGtk.WindowColor(EncoderConfigurationWindowBox.encoder_configuration, Config.ColorBackground);
+			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, EncoderConfigurationWindowBox.label_radio_linear);
+			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, EncoderConfigurationWindowBox.label_radio_rotary_friction);
+			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, EncoderConfigurationWindowBox.label_radio_rotary_axis);
+			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, EncoderConfigurationWindowBox.label_check_rotary_friction_inertia_on_axis);
+			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, EncoderConfigurationWindowBox.label_selected);
+			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, EncoderConfigurationWindowBox.label_count);
+		}
 
 		EncoderConfigurationWindowBox.encoder_configuration.Show ();
 
-		//B) side is shown now, after showing the window in order to be displayed correctly (see A)
-		EncoderConfigurationWindowBox.notebook_side.Visible = (EncoderConfigurationWindowBox.sideMode != sideModes.HIDDEN);
+		//C) side is shown now, after showing the window in order to be displayed correctly (see A)
+		EncoderConfigurationWindowBox.frame_notebook_side.Visible = (EncoderConfigurationWindowBox.sideMode != sideModes.HIDDEN);
 
 		return EncoderConfigurationWindowBox;
 	}
@@ -229,7 +253,7 @@ public class EncoderConfigurationWindow
 	}
 	
 	private void on_check_rotary_friction_inertia_on_axis_toggled (object obj, EventArgs args) {
-		initializeList(Constants.EncoderType.ROTARYFRICTION, true, check_rotary_friction_inertia_on_axis.Active, 0);
+		initializeList(Constants.EncoderType.ROTARYFRICTION, true, check_rotary_friction_inertia_on_axis.Active, listCurrent);
 	}
 	
 
@@ -538,7 +562,7 @@ public class EncoderConfigurationWindow
 		else if(sideMode == sideModes.CAPTUREINERTIAL)
 			notebook_side.CurrentPage = 1;
 
-		notebook_side.Visible = (sideMode != sideModes.HIDDEN);
+		frame_notebook_side.Visible = (sideMode != sideModes.HIDDEN);
 
 		button_encoder_capture_inertial_cancel.Sensitive = (sideMode != sideModes.CAPTUREINERTIAL);
 		//button_encoder_capture_inertial_finish.Sensitive = (sideMode != sideModes.CAPTUREINERTIAL);
