@@ -47,6 +47,7 @@ public class EncoderGraphDoPlot
 	private Gtk.ListStore encoderCaptureListStore;
 	private bool relativeToSet;
 	private double maxPowerSpeedForceIntersession; //it will be one of these 3
+	private string maxPowerSpeedForceIntersessionDate;
 
 	private int discardFirstN;
 	private int showNRepetitions;
@@ -136,7 +137,7 @@ public class EncoderGraphDoPlot
 		
 		if(layout_encoder_capture_curves_bars != null)
 			layout_encoder_capture_curves_bars.FontDescription =
-				Pango.FontDescription.FromString ("Courier " + preferences.encoderCaptureBarplotFontSize.ToString());
+				Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(preferences.encoderCaptureBarplotFontSize));
 	}
 
 	public void Start (
@@ -146,7 +147,7 @@ public class EncoderGraphDoPlot
 			bool hasInertia, bool playSoundsFromFile,
 			ArrayList data7Variables, Gtk.ListStore encoderCaptureListStore,
 			bool relativeToSet,
-			double maxPowerSpeedForceIntersession)
+			double maxPowerSpeedForceIntersession, string maxPowerSpeedForceIntersessionDate)
 	{
 		this.mainVariable = mainVariable;
 		this.mainVariableHigher = mainVariableHigher;
@@ -161,6 +162,7 @@ public class EncoderGraphDoPlot
         	this.encoderCaptureListStore = encoderCaptureListStore;
 		this.relativeToSet = relativeToSet;
 		this.maxPowerSpeedForceIntersession = maxPowerSpeedForceIntersession;
+		this.maxPowerSpeedForceIntersessionDate = maxPowerSpeedForceIntersessionDate;
 
 		graphWidth = drawingarea.Allocation.Width;
 		graphHeight = drawingarea.Allocation.Height;
@@ -239,13 +241,13 @@ public class EncoderGraphDoPlot
 
 		layout_encoder_capture_curves_bars = new Pango.Layout (drawingarea.PangoContext);
 		layout_encoder_capture_curves_bars.FontDescription =
-			Pango.FontDescription.FromString ("Courier " + preferences.encoderCaptureBarplotFontSize.ToString());
+			Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(preferences.encoderCaptureBarplotFontSize));
 		
 		layout_encoder_capture_curves_bars_text = new Pango.Layout (drawingarea.PangoContext);
-		layout_encoder_capture_curves_bars_text.FontDescription = Pango.FontDescription.FromString ("Courier 10");
+		layout_encoder_capture_curves_bars_text.FontDescription = Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(10));
 
 		layout_encoder_capture_curves_bars_superbig = new Pango.Layout (drawingarea.PangoContext);
-		layout_encoder_capture_curves_bars_superbig.FontDescription = Pango.FontDescription.FromString ("Courier 300");
+		layout_encoder_capture_curves_bars_superbig.FontDescription = Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(300));
 
 		//defined as drawingarea instead of encoder_capture_signal_drawingarea
 		//because the 2nd is null if config.EncoderCaptureShowOnlyBars == TRUE
@@ -345,6 +347,8 @@ public class EncoderGraphDoPlot
 		//know not-discarded phases
 		double countValid = 0;
 		double sumValid = 0;
+		double workTotal = 0; //can be J or Kcal (shown in cal)
+		double impulseTotal = 0;
 
 		foreach(double d in data)
 		{
@@ -447,11 +451,11 @@ public class EncoderGraphDoPlot
 		if (data.Count >= 10 && data.Count < 20) {
 			sep = 10;
 			layout_encoder_capture_curves_bars.FontDescription =
-				Pango.FontDescription.FromString ("Courier " + (preferences.encoderCaptureBarplotFontSize -2).ToString());
+				Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(preferences.encoderCaptureBarplotFontSize -2));
 		} else if (data.Count >= 20) {
 			sep = 2;
 			layout_encoder_capture_curves_bars.FontDescription =
-				Pango.FontDescription.FromString ("Courier " + (preferences.encoderCaptureBarplotFontSize -4).ToString());
+				Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(preferences.encoderCaptureBarplotFontSize -4));
 			left_margin = 2;
 		}
 
@@ -459,12 +463,12 @@ public class EncoderGraphDoPlot
 		{
 			sep = 2;
 			layout_encoder_capture_curves_bars.FontDescription =
-				Pango.FontDescription.FromString ("Courier " + (preferences.encoderCaptureBarplotFontSize -4).ToString());
+				Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(preferences.encoderCaptureBarplotFontSize -4));
 			left_margin = 2;
 		}
 
 		layout_encoder_capture_curves_bars_text.FontDescription =
-			Pango.FontDescription.FromString ("Courier " + preferences.encoderCaptureBarplotFontSize.ToString());
+			Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(preferences.encoderCaptureBarplotFontSize));
 		layout_encoder_capture_curves_bars_text.FontDescription.Weight = Pango.Weight.Bold;
 		
 		Rectangle rect;
@@ -499,6 +503,15 @@ public class EncoderGraphDoPlot
 					graphWidth - right_margin, top_margin);
 
 
+			//write date
+			layout_encoder_capture_curves_bars_text.SetMarkup(maxPowerSpeedForceIntersessionDate);
+			layout_encoder_capture_curves_bars_text.GetPixelSize(out textWidth, out textHeight);
+			pixmap.DrawLayout (pen_black_encoder_capture,
+						graphWidth - (right_margin + textWidth),
+						top_margin - 2*textHeight,
+						layout_encoder_capture_curves_bars_text);
+
+			//write value
 			int decs = 0;
 			if(mainVariable == Constants.MeanPower)
 				units = " W";
@@ -815,7 +828,17 @@ public class EncoderGraphDoPlot
 					countSaved ++;
 				}
 			}
-			
+
+			//work
+			if(iterOk) {
+				if(preferences.encoderWorkKcal)
+					workTotal += ((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).WorkKcalD;
+				else
+					workTotal += ((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).WorkJD;
+
+				impulseTotal += ((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).ImpulseD;
+			}
+
 			//add text on the bottom
 			if (eccon == "c" || Util.IsEven(count +1)) //par
 			{
@@ -886,12 +909,12 @@ public class EncoderGraphDoPlot
 		//LogB.Information(string.Format("sumSaved: {0}, countSaved: {1}, div: {2}", sumSaved, countSaved, sumSaved / countSaved));
 
 		//add avg and avg of saved values
-		string title = mainVariable + " [X = " + 
+		string title = mainVariable + " [X: " +
 			Util.TrimDecimals( (sumValid / countValid), decimals) +
 			" " + units + "; ";
 
 		if(countSaved > 0)
-			title += "X" + Catalog.GetString("saved") + " = " +
+			title += "X" + Catalog.GetString("saved") + ": " +
 				Util.TrimDecimals( (sumSaved / countSaved), decimals) + 
 				" " + units;
 
@@ -913,14 +936,28 @@ public class EncoderGraphDoPlot
 			}
 		}
 
+		//work and impulse are in separate string variables because maybe we will select to show one or the other
+		//work
+		string workString = "]    " + Catalog.GetString("Work") + ": " + Util.TrimDecimals(workTotal, decimals);
+		if(preferences.encoderWorkKcal)
+			workString += " Kcal";
+		else
+			workString += " J";
+
+		//impulse
+		string impulseString = "    " + Catalog.GetString("Impulse") + ": " + Util.TrimDecimals(impulseTotal, decimals) + " N*s";
+
 		//have title and titleFull to be able to position all perfectly but having two pens (colors)
-		string titleFull = title + lossString + "]";
+		string titleFull = title + lossString + workString + impulseString;
+
 
 		// 1) get the width of titleFull, title, lossString
 		textHeight = 1;
 		int titleFullWidth = 1;
 		int titleWidth = 1;
 		int lossStringWidth = 1;
+		int workStringWidth = 1;
+		int impulseStringWidth = 1;
 
 		layout_encoder_capture_curves_bars_text.SetMarkup(titleFull);
 		layout_encoder_capture_curves_bars_text.GetPixelSize(out titleFullWidth, out textHeight);
@@ -952,6 +989,10 @@ public class EncoderGraphDoPlot
 		layout_encoder_capture_curves_bars_text.GetPixelSize(out titleWidth, out textHeight);
 		layout_encoder_capture_curves_bars_text.SetMarkup(lossString);
 		layout_encoder_capture_curves_bars_text.GetPixelSize(out lossStringWidth, out textHeight);
+		layout_encoder_capture_curves_bars_text.SetMarkup(workString);
+		layout_encoder_capture_curves_bars_text.GetPixelSize(out workStringWidth, out textHeight);
+		layout_encoder_capture_curves_bars_text.SetMarkup(impulseString);
+		layout_encoder_capture_curves_bars_text.GetPixelSize(out impulseStringWidth, out textHeight);
 
 		// 3) paint only title text (with black pen)
 		layout_encoder_capture_curves_bars_text.SetMarkup(title);
@@ -965,12 +1006,17 @@ public class EncoderGraphDoPlot
 				Convert.ToInt32( (graphWidth/2) - titleFullWidth/2 + titleWidth), 0, //x, y
 				layout_encoder_capture_curves_bars_text);
 
-		// 5) paint the "]";
-		layout_encoder_capture_curves_bars_text.SetMarkup("]");
+		// 5) paint workString && impulse string;
+		layout_encoder_capture_curves_bars_text.SetMarkup(workString);
 		pixmap.DrawLayout (pen_black_encoder_capture,
 				Convert.ToInt32( (graphWidth/2) - titleFullWidth/2 + titleWidth + lossStringWidth), 0, //x, y
 				layout_encoder_capture_curves_bars_text);
 
+		layout_encoder_capture_curves_bars_text.SetMarkup(impulseString);
+		pixmap.DrawLayout (pen_black_encoder_capture,
+				Convert.ToInt32( (graphWidth/2) - titleFullWidth/2 + titleWidth + lossStringWidth + workStringWidth), 0, //x, y
+				layout_encoder_capture_curves_bars_text);
+
 		// 6) return layout font size to its original value
 		layout_encoder_capture_curves_bars_text.FontDescription.Size = savedFontSize;
 
@@ -1046,7 +1092,7 @@ public class EncoderGraphDoPlot
 			//rect = new Rectangle(dLeft, dTop, dWidth, dHeight);
 			rect = new Rectangle(
 					Convert.ToInt32( (graphWidth/2) - (textWidth/2) -30),
-					Convert.ToInt32( (graphHeight/2) - (textHeight/2) ), //textHeight is too high on Courier font 300
+					Convert.ToInt32( (graphHeight/2) - (textHeight/2) ), //textHeight is too high on font 300
 					textWidth + 60,
 					textHeight);
 			pixmap.DrawRectangle(pen_black_encoder_capture, true, rect);
@@ -1071,9 +1117,9 @@ public class EncoderGraphDoPlot
 	{
 		Pango.Layout layout_message = new Pango.Layout (drawingarea.PangoContext);
 		if(big)
-			layout_message.FontDescription = Pango.FontDescription.FromString ("Courier 16");
+			layout_message.FontDescription = Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(16));
 		else
-			layout_message.FontDescription = Pango.FontDescription.FromString ("Courier 10");
+			layout_message.FontDescription = Pango.FontDescription.FromString (preferences.GetFontTypeWithSize(10));
 		
 		int graphWidth = drawingarea.Allocation.Width;
 		int graphHeight = drawingarea.Allocation.Height;
