@@ -179,9 +179,9 @@ public class EncoderSelectRepetitionsIndividualCurrentSession : EncoderSelectRep
 {
 	ArrayList dataPrint;
 
-	public EncoderSelectRepetitionsIndividualCurrentSession() {
+	public EncoderSelectRepetitionsIndividualCurrentSession()
+	{
 		Type = Types.INDIVIDUAL_CURRENT_SESSION;
-
 		FakeButtonDeleteCurve = new Gtk.Button();
 	}
 
