@@ -611,13 +611,8 @@ public class EventMoreWindow
 	public EventMoreWindow () {
 	}
 
-	public EventMoreWindow (Gtk.Window parent, bool testOrDelete) {
-		/*
-		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "jumps_runs_more.glade", "jumps_runs_more", "chronojump");
-		gladeXML.Autoconnect(this);
-		*/
-
+	public EventMoreWindow (Gtk.Window parent, bool testOrDelete)
+	{
 		//name, startIn, weight, description
 		store = new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string));
 
@@ -696,7 +691,8 @@ public class EventMoreWindow
 					Util.ArrayListToSingleString(sessionValues, ", ") + "\n\n" +
 					Catalog.GetString("please first edit or delete them."));
 		else {
-			ConfirmWindow confirmWin = ConfirmWindow.Show(Catalog.GetString("Are you sure you want to delete this test type?"), "", selectedEventName);
+			ConfirmWindow confirmWin = ConfirmWindow.Show(Catalog.GetString("Are you sure you want to delete this test type?"), "",
+					selectedEventName);
 			confirmWin.Button_accept.Clicked += new EventHandler(on_button_delete_type_accepted);
 		}
 	}
