@@ -58,6 +58,7 @@ public class GenericWindow
 	//Edit row
 	[Widget] Gtk.Box hbox_edit_row;
 	[Widget] Gtk.Label hbox_combo_label;
+	[Widget] Gtk.Label label_comment;
 	[Widget] Gtk.Box hbox_combo;
 	[Widget] Gtk.ComboBox combo;
 	[Widget] Gtk.Button hbox_combo_button_apply;
@@ -131,6 +132,16 @@ public class GenericWindow
 	
 		//put an icon to window
 		UtilGtk.IconWindow(generic_window);
+
+		//manage window color
+		if(! Config.UseSystemColor)
+		{
+			UtilGtk.WindowColor(generic_window, Config.ColorBackground);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_header);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_error);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, hbox_combo_label);
+			UtilGtk.ContrastLabelsLabel (Config.ColorBackgroundIsDark, label_comment);
+		}
 		
 		generic_window.Resizable = false;
 		setTitle(title);
@@ -389,6 +400,12 @@ public class GenericWindow
 	public void SetSize(int width, int height) {
 		generic_window.SetDefaultSize(width, height);
 	}
+
+	//this works (but can resize lower than needed)
+	public void SetSizeRequest(int width, int height) {
+		generic_window.SetSizeRequest(width, height);
+	}
+
 	
 	public void SetTreeviewSize(int width, int height) {
 		treeview.SetSizeRequest(width, height);
