@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -433,42 +433,16 @@ public partial class ChronoJumpWindow
 		//configAutodetectPort = Config.AutodetectPortEnum.INACTIVE;
 
 		if(m == Constants.Menuitem_modes.JUMPSSIMPLE)
-		{
-			if(radio_menuitem_mode_jumps_simple.Active) {
-				//needed if people select again the same option
-				select_menuitem_mode_toggled(Constants.Menuitem_modes.JUMPSSIMPLE);
-			} else
-				radio_menuitem_mode_jumps_simple.Active = true;
-		}
+			changeMode (Constants.Menuitem_modes.JUMPSSIMPLE);
 		else if(m == Constants.Menuitem_modes.JUMPSREACTIVE)
-		{
-			if(radio_menuitem_mode_jumps_reactive.Active)
-				select_menuitem_mode_toggled(Constants.Menuitem_modes.JUMPSREACTIVE);
-			else
-				radio_menuitem_mode_jumps_reactive.Active = true;
-		}
+			changeMode (Constants.Menuitem_modes.JUMPSREACTIVE);
 		else if(m == Constants.Menuitem_modes.RUNSSIMPLE)
-		{
-			if(radio_menuitem_mode_runs_simple.Active)
-				select_menuitem_mode_toggled(Constants.Menuitem_modes.RUNSSIMPLE);
-			else
-				radio_menuitem_mode_runs_simple.Active = true;
-		}
+			changeMode (Constants.Menuitem_modes.RUNSSIMPLE);
 		else if(m == Constants.Menuitem_modes.POWERGRAVITATORY)
-		{
-			if(radio_menuitem_mode_power_gravitatory.Active)
-				select_menuitem_mode_toggled(Constants.Menuitem_modes.POWERGRAVITATORY);
-			else
-				radio_menuitem_mode_power_gravitatory.Active = true;
-		}
+			changeMode (Constants.Menuitem_modes.POWERGRAVITATORY);
 		else if(m == Constants.Menuitem_modes.POWERINERTIAL)
-		{
-			if(radio_menuitem_mode_power_inertial.Active)
-				select_menuitem_mode_toggled(Constants.Menuitem_modes.POWERINERTIAL);
-			else
-				radio_menuitem_mode_power_inertial.Active = true;
-		}
-		
+			changeMode (Constants.Menuitem_modes.POWERINERTIAL);
+
 		LogB.TestEnd("chronojumpWindowTestsMode");
 	}
 
@@ -477,14 +451,14 @@ public partial class ChronoJumpWindow
 		LogB.TestStart("chronojumpWindowTestsLoadSession");
 
 		on_open_activate(new Object(), new EventArgs());
-		bool exists = sessionLoadWin.SelectRowByID(sID); //0 is the first
+		bool exists = app1s_SelectRowByID(sID); //0 is the first
 		if(! exists) {
 			testsActive = false;
 			new DialogMessage(Constants.MessageTypes.WARNING, "Warning, This session ID does not exists");
 			return;
 		}
 
-		sessionLoadWin.Button_accept.Click();
+		app1s_Button_accept.Click();
 		
 		LogB.TestEnd("chronojumpWindowTestsLoadSession");
 	}
@@ -635,6 +609,9 @@ public partial class ChronoJumpWindow
 	//saves all best none 4top randomly
 	private void chronojumpWindowTestsEncoderSetSaveReps()
 	{
+		/*
+		 * TODO: redo this with new combo_encoder_capture_curves_save
+		 *
 		LogB.TestStart("chronojumpWindowTestsEncoderSetSaveReps");
 
 		//Constants.EncoderAutoSaveCurve easc;
@@ -655,6 +632,7 @@ public partial class ChronoJumpWindow
 		//encoderCaptureSaveCurvesAllNoneBest(easc, encoderCaptureOptionsWin.GetMainVariable());
 		
 		LogB.TestEnd("chronojumpWindowTestsEncoderSetSaveReps: " + d.ToString());
+		*/
 	}
 	
 	//saves all best none 4top randomly
@@ -676,6 +654,10 @@ public partial class ChronoJumpWindow
 	int saveRepsLastI;
 	private bool chronojumpWindowTestsEncoderSetSaveRepsBucleDo()
 	{
+		return false;
+		/*
+		 * TODO: redo this with new combo_encoder_capture_curves_save
+		 *
 		if(! saveRepsBucleDoing)
 			return false;
 		
@@ -708,6 +690,7 @@ public partial class ChronoJumpWindow
 			chronojumpWindowTestsNext();
 			return false;
 		}
+		*/
 	}
 	
 	private void chronojumpWindowTestsWait5seconds()
