@@ -77,8 +77,10 @@ public partial class ChronoJumpWindow
 		bool showRunDistance = false;
 		if(myMultiChronopicType.Name == Constants.MultiChronopicName) {
 			showSyncAndDeleteFirst = true;
+			setLabelContactsExerciseSelected(Catalog.GetString("Multi Chronopic"));
 		} else if(myMultiChronopicType.Name == Constants.RunAnalysisName) {
 			showRunDistance = true;
+			setLabelContactsExerciseSelected(Catalog.GetString("Race analysis"));
 		}
 		extra_window_multichronopic_showSyncAndDeleteFirst(showSyncAndDeleteFirst);
 		extra_window_multichronopic_showRunDistance(showRunDistance);
