@@ -100,7 +100,7 @@ public partial class ChronoJumpWindow
 	//[Widget] Gtk.Button button_menu_outside_menu;
 	//[Widget] Gtk.Button button_menu_outside_menu1;
 
-	private enum linuxTypeEnum { NOTLINUX, LINUX, RASPBERRY, NETWORKS }
+	//private enum linuxTypeEnum { NOTLINUX, LINUX, RASPBERRY, NETWORKS }
 	private bool encoderUpdateTreeViewWhileCapturing = true;
 
 	static Thread threadRFID;
@@ -620,6 +620,12 @@ public partial class ChronoJumpWindow
 			return true;
 		}
 
+		//show a Readed message nice if the network is slow or there is any problem with the web services
+		label_rfid_wait.Text = Catalog.GetString("Readed");
+		label_rfid_encoder_wait.Text = Catalog.GetString("Readed");
+		label_rfid_wait.Visible = true;
+		label_rfid_encoder_wait.Visible = true;
+
 		shouldUpdateRFIDGui = false;
 		updatingRFIDGuiStuff = true;
 
@@ -889,6 +895,15 @@ public partial class ChronoJumpWindow
 	}
 
 
+	/*
+	//just to debug dialog without networks
+	public void ShowDialogPersonPopup()
+	{
+		currentPerson = SqlitePerson.Select(1);
+		compujumpAutologout = new CompujumpAutologout();
+		showDialogPersonPopup(new List<Task> (), new List<StationCount> (), "some net dev", true);
+	}
+	*/
 	private void showDialogPersonPopup(List<Task> tasks, List<StationCount> stationsCount, string networkDevices, bool serverConnected)
 	{
 		if(dialogPersonPopup != null)
