@@ -38,8 +38,9 @@ public class PersonAddModifyWindow
 	[Widget] Gtk.TextView textview_description;
 	[Widget] Gtk.TextView textview_ps_comments;
 
-	[Widget] Gtk.Notebook notebook_main;
+	[Widget] Gtk.Frame frame_main;
 	[Widget] Gtk.HButtonBox hbuttonbox_main;
+	[Widget] Gtk.HBox hbox_units;
 	[Widget] Gtk.VBox vbox_error;
 	[Widget] Gtk.Label label_error;
 	[Widget] Gtk.Button button_load_person;
@@ -156,7 +157,14 @@ public class PersonAddModifyWindow
 		
 		//put an icon to window
 		UtilGtk.IconWindow(person_win);
-	
+
+		//manage window color
+		if(! Config.UseSystemColor)
+		{
+			UtilGtk.WindowColor(person_win, Config.ColorBackground);
+			UtilGtk.ContrastLabelsLabel(Config.ColorBackgroundIsDark, label_error);
+		}
+
 		person_win.Parent = parent;
 		this.currentSession = currentSession;
 		this.currentPerson = currentPerson;
@@ -1083,7 +1091,7 @@ public class PersonAddModifyWindow
 				//see if this person has done jumps with weight
 				string [] myJumpsNormal = SqliteJump.SelectJumpsSA (false, currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "",
 						Sqlite.Orders_by.DEFAULT, -1);
-				string [] myJumpsReactive = SqliteJumpRj.SelectJumps(false, currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "");
+				string [] myJumpsReactive = SqliteJumpRj.SelectJumpsSA (false, currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "");
 
 				if(myJumpsNormal.Length > 0 || myJumpsReactive.Length > 0) {
 					//create the convertWeight Window
@@ -1116,7 +1124,8 @@ public class PersonAddModifyWindow
 	private void showErrorMessage(bool show, bool showLoadPerson)
 	{
 		vbox_error.Visible = show;
-		notebook_main.Visible = ! show;
+		frame_main.Visible = ! show;
+		hbox_units.Visible = ! show;
 		hbuttonbox_main.Visible = ! show;
 
 		button_load_person.Visible = showLoadPerson;
