@@ -83,7 +83,7 @@ public class PersonAddMultipleWindow
 	
 	int rows;
 	
-	[Widget] Gtk.ScrolledWindow scrolledwindow;
+	//[Widget] Gtk.ScrolledWindow scrolledwindow;
 	[Widget] Gtk.Table table_main;
 	[Widget] Gtk.Label label_message;
 	
@@ -108,6 +108,10 @@ public class PersonAddMultipleWindow
 		
 		//put an icon to window
 		UtilGtk.IconWindow(person_multiple_infinite);
+
+		//manage window color
+		if(! Config.UseSystemColor)
+			UtilGtk.WindowColor(person_multiple_infinite, Config.ColorBackground);
 	
 		person_multiple_infinite.Parent = parent;
 		this.currentSession = currentSession;
@@ -442,7 +446,7 @@ public class PersonAddMultipleWindow
 		}
 
 		table_main.Show();
-		scrolledwindow.Visible = true;
+		table_main.Visible = true;
 		notebook.CurrentPage = 0;
 
 		button_accept.Sensitive = true;
