@@ -49,6 +49,7 @@ public class PreferencesWindow
 	//view more tabs
 	[Widget] Gtk.Button button_view_more_tabs;
 	[Widget] Gtk.HBox hbox_more_tabs;
+	[Widget] Gtk.Label label_view_more_tabs;
 	[Widget] Gtk.CheckButton check_view_jumps;
 	[Widget] Gtk.CheckButton check_view_runs;
 	[Widget] Gtk.CheckButton check_view_encoder;
@@ -70,10 +71,26 @@ public class PreferencesWindow
 	[Widget] Gtk.CheckButton check_appearance_person_photo;
 	[Widget] Gtk.Alignment alignment_undecorated;
 	[Widget] Gtk.Label label_recommended_undecorated;
+	[Widget] Gtk.RadioButton radio_font_courier;
+	[Widget] Gtk.RadioButton radio_font_helvetica;
+	[Widget] Gtk.Label label_radio_font_needs_restart;
+
+	[Widget] Gtk.RadioButton radio_color_custom;
+	[Widget] Gtk.RadioButton radio_color_chronojump_blue;
+	[Widget] Gtk.RadioButton radio_color_os;
 	[Widget] Gtk.DrawingArea drawingarea_background_color;
+	[Widget] Gtk.Button button_color_choose;
+	[Widget] Gtk.DrawingArea drawingarea_background_color_chronojump_blue;
+	[Widget] Gtk.Label label_radio_color_os_needs_restart;
+
 	[Widget] Gtk.CheckButton check_logo_animated;
+	[Widget] Gtk.HBox hbox_last_session_and_mode;
+	[Widget] Gtk.CheckButton check_session_autoload_at_start;
+	[Widget] Gtk.CheckButton check_mode_autoload_at_start;
+
 
 	//jumps tab	
+//	[Widget] Gtk.Label label_jumps;
 	[Widget] Gtk.CheckButton checkbutton_power;
 	[Widget] Gtk.CheckButton checkbutton_stiffness;
 	[Widget] Gtk.CheckButton checkbutton_initial_speed;
@@ -82,10 +99,8 @@ public class PreferencesWindow
 	[Widget] Gtk.Box hbox_indexes;
 	[Widget] Gtk.RadioButton radiobutton_show_q_index;
 	[Widget] Gtk.RadioButton radiobutton_show_dj_index;
-	[Widget] Gtk.RadioButton radio_jumps_dj_capture_show_heights;
-	[Widget] Gtk.RadioButton radio_jumps_dj_capture_show_times;
-	[Widget] Gtk.RadioButton radio_elevation_height;
-	[Widget] Gtk.RadioButton radio_elevation_tf;
+	[Widget] Gtk.RadioButton radio_jumps_dj_heights;
+	[Widget] Gtk.RadioButton radio_jumps_dj_times;
 	[Widget] Gtk.RadioButton radio_weight_percent;
 	[Widget] Gtk.RadioButton radio_weight_kg;
 	[Widget] Gtk.RadioButton radio_use_heights_on_jump_indexes;
@@ -218,7 +233,7 @@ public class PreferencesWindow
 	[Widget] Gtk.RadioButton radio_language_force;
 	[Widget] Gtk.RadioButton radio_graphs_translate;
 	[Widget] Gtk.RadioButton radio_graphs_no_translate;
-	[Widget] Gtk.Box hbox_need_restart;
+	[Widget] Gtk.VBox vbox_need_restart;
 		
 	//advanced tab
 	[Widget] Gtk.ComboBox combo_decimals;
@@ -256,12 +271,12 @@ public class PreferencesWindow
 	
 	ListStore langsStore;
 
-	const int JUMPSPAGE = 1;
-	const int RUNSPAGE = 2;
-	const int ENCODERCAPTUREPAGE = 3;
-	const int ENCODEROTHERPAGE = 4;
-	const int FORCESENSORPAGE = 5;
-	const int RUNENCODERPAGE = 6;
+	const int JUMPSPAGE = 2;
+	const int RUNSPAGE = 3;
+	const int ENCODERCAPTUREPAGE = 4;
+	const int ENCODEROTHERPAGE = 5;
+	const int FORCESENSORPAGE = 6;
+	const int RUNENCODERPAGE = 7;
 
 	static private WebcamDeviceList wd_list;
 	private WebcamFfmpegSupportedModes wfsm;
@@ -374,14 +389,28 @@ public class PreferencesWindow
 		else //if(preferences.menuType == Preferences.MenuTypes.ICONS)
 			PreferencesWindowBox.radio_menu_show_icons.Active = true;
 
-		PreferencesWindowBox.colorBackground = UtilGtk.ColorParse(preferences.colorBackgroundString);
-		PreferencesWindowBox.paintColorDrawingArea(PreferencesWindowBox.colorBackground);
-
 		if(preferences.logoAnimatedShow)
 			PreferencesWindowBox.check_logo_animated.Active = true;
 		else
 			PreferencesWindowBox.check_logo_animated.Active = false;
 
+		PreferencesWindowBox.hbox_last_session_and_mode.Visible = ! compujump;
+
+		if(preferences.loadLastSessionAtStart)
+			PreferencesWindowBox.check_session_autoload_at_start.Active = true;
+		else
+			PreferencesWindowBox.check_session_autoload_at_start.Active = false;
+
+		if(preferences.loadLastModeAtStart)
+			PreferencesWindowBox.check_mode_autoload_at_start.Active = true;
+		else
+			PreferencesWindowBox.check_mode_autoload_at_start.Active = false;
+
+		if(preferences.fontType == Preferences.FontTypes.Courier)
+			PreferencesWindowBox.radio_font_courier.Active = true;
+		else
+			PreferencesWindowBox.radio_font_helvetica.Active = true;
+
 		//multimedia tab
 		if(preferences.volumeOn)  
 			PreferencesWindowBox.checkbutton_volume.Active = true; 
@@ -480,10 +509,10 @@ public class PreferencesWindow
 			PreferencesWindowBox.hbox_indexes.Hide();
 		}
 
-		if(preferences.jumpsDjGraphHeights)
-			PreferencesWindowBox.radio_jumps_dj_capture_show_heights.Active = true;
+		if(preferences.heightPreferred)
+			PreferencesWindowBox.radio_jumps_dj_heights.Active = true;
 		else
-			PreferencesWindowBox.radio_jumps_dj_capture_show_times.Active = true;
+			PreferencesWindowBox.radio_jumps_dj_times.Active = true;
 
 		if(preferences.askDeletion)
 			PreferencesWindowBox.checkbutton_ask_deletion.Active = true; 
@@ -499,13 +528,6 @@ public class PreferencesWindow
 			PreferencesWindowBox.radio_weight_percent.Active = true; 
 		else 
 			PreferencesWindowBox.radio_weight_kg.Active = true; 
-		
-
-		if(preferences.heightPreferred)  
-			PreferencesWindowBox.radio_elevation_height.Active = true; 
-		else 
-			PreferencesWindowBox.radio_elevation_tf.Active = true; 
-		
 
 		if(preferences.metersSecondsPreferred)  
 			PreferencesWindowBox.radio_speed_ms.Active = true; 
@@ -698,6 +720,25 @@ public class PreferencesWindow
 		else //if(preferences.importerPythonVersion == Preferences.pythonVersionEnum.Python)
 			PreferencesWindowBox.radio_python_default.Active = true;
 
+		if(preferences.colorBackgroundOsColor) {
+			PreferencesWindowBox.radio_color_os.Active = true;
+			PreferencesWindowBox.button_color_choose.Sensitive = false;
+
+			//do not show the visible tag at open the window, only when user changes to this option.
+			PreferencesWindowBox.label_radio_color_os_needs_restart.Visible = false;
+		}
+		else if((preferences.colorBackgroundString).ToLower() == "#0e1e46") {
+			PreferencesWindowBox.radio_color_chronojump_blue.Active = true;
+			PreferencesWindowBox.button_color_choose.Sensitive = false;
+		}
+		else {
+			PreferencesWindowBox.radio_color_custom.Active = true;
+			PreferencesWindowBox.button_color_choose.Sensitive = true;
+		}
+
+		PreferencesWindowBox.colorBackground = UtilGtk.ColorParse(preferences.colorBackgroundString);
+		PreferencesWindowBox.paintColorDrawingAreaAndBg (PreferencesWindowBox.colorBackground);
+		UtilGtk.PaintColorDrawingArea(PreferencesWindowBox.drawingarea_background_color_chronojump_blue, UtilGtk.BLUE_CHRONOJUMP);
 
 		PreferencesWindowBox.preferences_win.Show ();
 		return PreferencesWindowBox;
@@ -753,10 +794,32 @@ public class PreferencesWindow
 		check_example_menu_icons.Visible = (o == (object) radio_menu_show_icons && radio_menu_show_icons.Active);
 	}
 
-	private void paintColorDrawingArea(Gdk.Color color)
+	private void paintColorDrawingAreaAndBg (Gdk.Color color)
 	{
 		UtilGtk.PaintColorDrawingArea(drawingarea_background_color, color);
+		if(! preferences.colorBackgroundOsColor)
+		{
+			UtilGtk.WindowColor(preferences_win, color);
+			UtilGtk.ContrastLabelsLabel (preferences.colorBackgroundIsDark, label_view_more_tabs);
+		}
 	}
+
+	private void on_radio_color_custom_toggled (object o, EventArgs args)
+	{
+		button_color_choose.Sensitive = true;
+		label_radio_color_os_needs_restart.Visible = false;
+	}
+	private void on_radio_color_chronojump_blue_toggled (object o, EventArgs args)
+	{
+		button_color_choose.Sensitive = false;
+		label_radio_color_os_needs_restart.Visible = false;
+	}
+	private void on_radio_color_os_toggled (object o, EventArgs args)
+	{
+		button_color_choose.Sensitive = false;
+		label_radio_color_os_needs_restart.Visible = true;
+	}
+
 	private void on_button_color_choose_clicked(object o, EventArgs args)
 	{
 		using (ColorSelectionDialog colorSelectionDialog = new ColorSelectionDialog (Catalog.GetString("Select color")))
@@ -767,7 +830,7 @@ public class PreferencesWindow
 
 			if (colorSelectionDialog.Run () == (int) ResponseType.Ok) {
 				colorBackground = colorSelectionDialog.ColorSelection.CurrentColor;
-				paintColorDrawingArea(colorBackground);
+				paintColorDrawingAreaAndBg(colorBackground);
 
 				/*
 				LogB.Information(string.Format("color: red {0}, green {1}, blue {2}",
@@ -782,6 +845,15 @@ public class PreferencesWindow
 		}
 	}
 
+	private void on_radio_font_courier_toggled (object o, EventArgs args)
+	{
+		label_radio_font_needs_restart.Visible = true;
+	}
+	private void on_radio_font_helvetica_toggled (object o, EventArgs args)
+	{
+		label_radio_font_needs_restart.Visible = true;
+	}
+
 	private void on_radio_encoder_capture_show_all_bars_toggled (object o, EventArgs args)
 	{
 		spin_encoder_capture_show_only_some_bars.Sensitive = false;
@@ -1336,15 +1408,15 @@ public class PreferencesWindow
 		hbox_combo_language.Sensitive = radio_language_force.Active;
 
 		if(hbox_language_signalOn)
-			hbox_need_restart.Visible = true;
+			vbox_need_restart.Visible = true;
 	}
 	private void on_radio_translate_toggled (object obj, EventArgs args) {
 		if(hbox_language_signalOn)
-			hbox_need_restart.Visible = true;
+			vbox_need_restart.Visible = true;
 	}
 	private	void combo_language_changed (object obj, EventArgs args) {
 		if(hbox_language_signalOn)
-			hbox_need_restart.Visible = true;
+			vbox_need_restart.Visible = true;
 	}
 
 
@@ -1450,14 +1522,10 @@ public class PreferencesWindow
 				return;
 			}
 		}
-		
-		try {
-			System.Diagnostics.Process.Start(dir); 
-		}
-		catch {
+
+		if(! Util.OpenFolder(dir))
 			new DialogMessage(Constants.MessageTypes.WARNING, 
 					Constants.DirectoryCannotOpenStr() + "\n\n" + dir);
-		}
 	}
 	
 	void on_button_tmp_folder_open_clicked (object o, EventArgs args)
@@ -1470,12 +1538,9 @@ public class PreferencesWindow
 			return;
 		}
 
-		try {
-			System.Diagnostics.Process.Start(dir);
-		} catch {
+		if(! Util.OpenFolder(dir))
 			new DialogMessage(Constants.MessageTypes.WARNING, 
 					Constants.DirectoryCannotOpenStr() + "\n\n" + dir);
-		}
 	}
 
 	void on_button_import_configuration_clicked (object o, EventArgs args)
@@ -1641,15 +1706,57 @@ public class PreferencesWindow
 			preferences.menuType = Preferences.MenuTypes.ICONS;
 		}
 
-		preferences.colorBackgroundString = Preferences.PreferencesChange(
-				SqlitePreferences.ColorBackground, preferences.colorBackgroundString,
-				UtilGtk.ColorToColorString(colorBackground)); //this does the reverse of Gdk.Color.Parse on UtilGtk.ColorParse()
-		preferences.colorBackgroundIsDark = UtilGtk.ColorIsDark(colorBackground);
+		if(radio_color_chronojump_blue.Active) 
+		{
+			preferences.colorBackgroundString = Preferences.PreferencesChange(
+					SqlitePreferences.ColorBackground, preferences.colorBackgroundString,
+					"#0e1e46");
+			preferences.colorBackgroundOsColor = Preferences.PreferencesChange(
+					SqlitePreferences.ColorBackgroundOsColor, preferences.colorBackgroundOsColor,
+					false);
+			preferences.colorBackgroundIsDark = true;
+		} else if(radio_color_os.Active)
+		{
+			//radio_color_os does not change the colorBackgroundString, it changes the Config.UseSystemColor
+			//but note that on showing cairo and execute graphs, primary color will be colorBackground
+			preferences.colorBackgroundOsColor = Preferences.PreferencesChange(
+					SqlitePreferences.ColorBackgroundOsColor, preferences.colorBackgroundOsColor,
+					true);
+			preferences.colorBackgroundIsDark = false; //is not important as it is not going to be used
+		} else {
+			preferences.colorBackgroundString = Preferences.PreferencesChange(
+					SqlitePreferences.ColorBackground, preferences.colorBackgroundString,
+					UtilGtk.ColorToColorString(colorBackground)); //this does the reverse of Gdk.Color.Parse on UtilGtk.ColorParse()
+			preferences.colorBackgroundOsColor = Preferences.PreferencesChange(
+					SqlitePreferences.ColorBackgroundOsColor, preferences.colorBackgroundOsColor,
+					false);
+			preferences.colorBackgroundIsDark = UtilGtk.ColorIsDark(colorBackground);
+		}
 
 		preferences.logoAnimatedShow = Preferences.PreferencesChange(
 				SqlitePreferences.LogoAnimatedShow, preferences.logoAnimatedShow,
 				PreferencesWindowBox.check_logo_animated.Active);
 
+		preferences.loadLastSessionAtStart = Preferences.PreferencesChange(
+				SqlitePreferences.LoadLastSessionAtStart, preferences.loadLastSessionAtStart,
+				PreferencesWindowBox.check_session_autoload_at_start.Active);
+
+		preferences.loadLastModeAtStart = Preferences.PreferencesChange(
+				SqlitePreferences.LoadLastModeAtStart, preferences.loadLastModeAtStart,
+				PreferencesWindowBox.check_mode_autoload_at_start.Active);
+
+
+		if(preferences.fontType == Preferences.FontTypes.Courier && radio_font_helvetica.Active)
+		{
+			SqlitePreferences.Update(SqlitePreferences.FontsOnGraphs, Preferences.FontTypes.Helvetica.ToString(), true);
+			preferences.fontType = Preferences.FontTypes.Helvetica;
+		}
+		else if(preferences.fontType == Preferences.FontTypes.Helvetica && radio_font_courier.Active)
+		{
+			SqlitePreferences.Update(SqlitePreferences.FontsOnGraphs, Preferences.FontTypes.Courier.ToString(), true);
+			preferences.fontType = Preferences.FontTypes.Courier;
+		}
+
 		if( preferences.digitsNumber != Convert.ToInt32(UtilGtk.ComboGetActive(combo_decimals)) ) {
 			SqlitePreferences.Update("digitsNumber", UtilGtk.ComboGetActive(combo_decimals), true);
 			preferences.digitsNumber = Convert.ToInt32(UtilGtk.ComboGetActive(combo_decimals));
@@ -1689,10 +1796,10 @@ public class PreferencesWindow
 					"showDjIndex", preferences.showDjIndex, false);
 		}
 
-		preferences.jumpsDjGraphHeights = Preferences.PreferencesChange(
-				SqlitePreferences.JumpsDjGraphHeights,
-				preferences.jumpsDjGraphHeights,
-				radio_jumps_dj_capture_show_heights.Active);
+		preferences.heightPreferred = Preferences.PreferencesChange(
+				"heightPreferred",
+				preferences.heightPreferred,
+				radio_jumps_dj_heights.Active);
 
 		
 		if( preferences.askDeletion != PreferencesWindowBox.checkbutton_ask_deletion.Active ) {
@@ -1713,11 +1820,6 @@ public class PreferencesWindow
 			preferences.weightStatsPercent = PreferencesWindowBox.radio_weight_percent.Active;
 		}
 
-		if( preferences.heightPreferred != PreferencesWindowBox.radio_elevation_height.Active ) {
-			SqlitePreferences.Update("heightPreferred", PreferencesWindowBox.radio_elevation_height.Active.ToString(), true);
-			preferences.heightPreferred = PreferencesWindowBox.radio_elevation_height.Active;
-		}
-
 		if( preferences.metersSecondsPreferred != PreferencesWindowBox.radio_speed_ms.Active ) {
 			SqlitePreferences.Update("metersSecondsPreferred", PreferencesWindowBox.radio_speed_ms.Active.ToString(), true);
 			preferences.metersSecondsPreferred = PreferencesWindowBox.radio_speed_ms.Active;
