@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -31,17 +31,19 @@ using Mono.Unix;
 
 public partial class ChronoJumpWindow 
 {
+	/*
 	//presentation
 	[Widget] Gtk.Box vbox_presentation;
 	[Widget] Gtk.Image image_presentation_logo;
 	[Widget] Gtk.Label label_presentation_current;
+	*/
 
 	//static WebKit.WebView presentation;
 
 	bool presentationInitialized = false;
 
 	void on_menuitem_presentation_activate (object o, EventArgs args) {
-		vbox_presentation.Visible = ! vbox_presentation.Visible;
+		//vbox_presentation.Visible = ! vbox_presentation.Visible;
 	}
 
  
@@ -66,7 +68,6 @@ public partial class ChronoJumpWindow
 	/*
 		Gtk.Button button = (Gtk.Button) o;
 
-		//main_menu.Visible =	( button != button_presentation_fullscreen);
 		vbox_persons.Visible =	( button != button_presentation_fullscreen);
 		notebook_sup.ShowTabs =	( button != button_presentation_fullscreen);
 		//button_presentation_fullscreen.Sensitive =	( button != button_presentation_fullscreen);
@@ -122,10 +123,12 @@ public partial class ChronoJumpWindow
 			presentationOpenStatic("file://" + file + "#" + presentation_slide_current.ToString());
 	}
 
-	void updatePresentationLabel() {	
+	void updatePresentationLabel() {
+		/*
 		label_presentation_current.Text = 
 			(presentation_slide_current +1).ToString() + " / " + 
 			(presentation_slide_max +1).ToString();
+			*/
 	}
 	
 	private void loadInitialPresentation()
