@@ -19,6 +19,7 @@
  */
 
 using System;
+using System.IO;
 using Gtk;
 using Glade;
 using System.Text; //StringBuilder
@@ -32,6 +33,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Button button_sprint;
 	[Widget] Gtk.Viewport viewport_sprint;
 	[Widget] Gtk.Image image_sprint;
+	[Widget] Gtk.Button button_sprint_save_image;
 
 	static Sprint sprint;
 	TreeStore storeSprint;
@@ -41,15 +43,17 @@ public partial class ChronoJumpWindow
 		LogB.Information("SPRINT create START");
 		UtilGtk.RemoveColumns(tv);
 		button_sprint.Sensitive = false;
+		image_sprint.Sensitive = false;
+		button_sprint_save_image.Sensitive = false;
 
 		tv.HeadersVisible=true;
 
 		int count = 0;
-		tv.AppendColumn ("Type", new CellRendererText(), "text", count++);
+		tv.AppendColumn (Catalog.GetString("Type"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ("ID", new CellRendererText(), "text", count++);
-		tv.AppendColumn ("Distances", new CellRendererText(), "text", count++);
-		tv.AppendColumn ("Split times", new CellRendererText(), "text", count++);
-		tv.AppendColumn ("Total time", new CellRendererText(), "text", count++);
+		tv.AppendColumn (Catalog.GetString("Distances"), new CellRendererText(), "text", count++);
+		tv.AppendColumn (Catalog.GetString("Split times"), new CellRendererText(), "text", count++);
+		tv.AppendColumn (Catalog.GetString("Total time"), new CellRendererText(), "text", count++);
 
 		storeSprint = new TreeStore(
 				typeof (string), typeof (string), typeof (string),
@@ -229,6 +233,7 @@ public partial class ChronoJumpWindow
 
 	private bool on_button_sprint_do ()
 	{
+		button_sprint_save_image.Sensitive = false;
 		if(currentPersonSession.Weight == 0)
 		{
 			new DialogMessage(Constants.MessageTypes.WARNING,
@@ -257,7 +262,8 @@ public partial class ChronoJumpWindow
 
 		bool success = sprint.CallR(
 				viewport_sprint.Allocation.Width -5,
-				viewport_sprint.Allocation.Height -5);
+				viewport_sprint.Allocation.Height -5,
+				currentPerson.Name);
 
 		if(! success)
 		{
@@ -271,7 +277,32 @@ public partial class ChronoJumpWindow
 				UtilEncoder.GetSprintImage(),
 				image_sprint);
 		image_sprint.Sensitive = true;
+		button_sprint_save_image.Sensitive = true;
 		return true;
 	}
 
+	private void on_button_sprint_save_image_clicked (object o, EventArgs args)
+	{
+		checkFile(Constants.CheckFileOp.RUNS_SPRINT_SAVE_IMAGE);
+	}
+
+	private void on_button_runs_sprint_save_image_selected (string destination)
+	{
+		try {
+			File.Copy(UtilEncoder.GetSprintImage(), destination, true);
+		} catch {
+			string myString = string.Format(
+					Catalog.GetString("Cannot save file {0} "), destination);
+			new DialogMessage(Constants.MessageTypes.WARNING, myString);
+		}
+	}
+
+	private void on_overwrite_file_runs_sprint_save_image_accepted (object o, EventArgs args)
+	{
+		on_button_runs_sprint_save_image_selected(exportFileName);
+
+		string myString = string.Format(Catalog.GetString("Saved to {0}"), exportFileName);
+		new DialogMessage(Constants.MessageTypes.INFO, myString);
+	}
+
 }
