@@ -15,7 +15,8 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2016-2017 Carles Pina & Xavier de Blas
+ * Copyright (C) 2016-2017 Carles Pina
+ * Copyright (C) 2016-2020 Xavier de Blas
  */
 
 using System;
@@ -664,431 +665,78 @@ public class JsonCompujump : Json
 		return true;
 	}
 
-	~JsonCompujump() {}
-}
-
-public class UploadSprintDataObject
-{
-	public int uniqueId; //used for SQL load and delete
-	public int personId;
-	public string sprintPositions;
-	public List<double> splitTimesL;
-	public double k;
-	public double vmax;
-	public double amax;
-	public double fmax;
-	public double pmax;
-
-	public UploadSprintDataObject (int uniqueId, int personId, string sprintPositions, List<double> splitTimesL,
-			double k, double vmax, double amax, double fmax, double pmax)
+	public bool UploadForceSensorData(UploadForceSensorDataFullObject o)
 	{
-		this.uniqueId = uniqueId;
-		this.personId = personId;
-		this.sprintPositions = sprintPositions;
-		this.splitTimesL = splitTimesL;
-		this.k = k;
-		this.vmax = vmax;
-		this.amax = amax;
-		this.fmax = fmax;
-		this.pmax = pmax;
-	}
+		// Create a request using a URL that can receive a post.
+		if (! createWebRequest(requestType.GENERIC, "/uploadForceSensorData"))
+			return false;
 
-	public string ToSQLInsertString ()
-	{
-		return
-			"NULL, " +
-			personId.ToString() + ", " +
-			"\"" + sprintPositions + "\", " +
-			"\"" + splitTimesLToString() + "\", " +
-			Util.ConvertToPoint(k) + ", " +
-			Util.ConvertToPoint(vmax) + ", " +
-			Util.ConvertToPoint(amax) + ", " +
-			Util.ConvertToPoint(fmax) + ", " +
-			Util.ConvertToPoint(pmax) + ")";
-	}
+		// Set the Method property of the request to POST.
+		request.Method = "POST";
 
-	public static List<double> SplitTimesStringToList(string sqlSelectSplitTimes)
-	{
-		List<double> l = new List<double>();
-		if(sqlSelectSplitTimes == null || sqlSelectSplitTimes == "")
-			return l;
+		// Set the ContentType property of the WebRequest.
+		request.ContentType = "application/json; Charset=UTF-8"; //but this is not enough, see this line:
+		//exerciseName = Util.RemoveAccents(exerciseName);
 
-		string [] myStringFull = sqlSelectSplitTimes.Split(new char[] {';'});
-		foreach (string time in myStringFull)
-			l.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(time)));
+		// Creates the json object
+		JsonObject json = new JsonObject();
+		json.Add("personId", o.personId);
+		json.Add("stationId", o.stationId);
+		//json.Add("exerciseName", exerciseName);
+		json.Add("exerciseId", o.exerciseId);
+		json.Add("laterality", o.laterality);
+		json.Add("resistance", o.resistance);
 
-		return l;
-	}
 
-	private string splitTimesLToString()
-	{
-		string str = "";
-		string sep = "";
-		foreach(double d in splitTimesL)
-		{
-			str += sep + Util.ConvertToPoint(d);
-			sep = ";";
-		}
+		json.Add("variability", o.uo.variability);
+		json.Add("timeTotal", o.uo.timeTotal);
+		json.Add("impulse", o.uo.impulse);
+		json.Add("workJ", o.uo.workJ);
+		json.Add("repetitions", o.uo.repetitions);
+		json.Add("numRep", o.uo.numRep);
+		json.Add("repCriteria", o.uo.repCriteria);
+		json.Add("time", o.uo.time);
+		json.Add("range", o.uo.range);
+		json.Add("fmaxRaw", o.uo.fmaxRaw);
+		json.Add("rfdmeanRaw", o.uo.rfdmeanRaw);
+		json.Add("rfdmaxRaw", o.uo.rfdmaxRaw);
+		json.Add("fmaxModel", o.uo.fmaxModel);
+		json.Add("rfdmaxModel", o.uo.rfdmaxModel);
+		json.Add("vmean", o.uo.vmean);
+		json.Add("vmax", o.uo.vmax);
+		json.Add("amean", o.uo.amean);
+		json.Add("amax", o.uo.amax);
+		json.Add("pmean", o.uo.pmean);
+		json.Add("pmax", o.uo.pmax);
 
-		return str;
-	}
-}
+		// Converts it to a String
+		String js = json.ToString();
+		LogB.Information("json UploadForceSensorData: ", js);
 
-public class UploadEncoderDataFullObject
-{
-	public int uniqueId; //used for SQL load and delete
-	public int personId;
-	public int stationId;
-	public int exerciseId;
-	public string laterality;
-	public string resistance;
-	public UploadEncoderDataObject uo;
+		// Writes the json object into the request dataStream
+		Stream dataStream;
+		if(! getWebRequestStream (request, out dataStream, Catalog.GetString("Could not upload force sensor data.")))
+			return false;
 
-	public UploadEncoderDataFullObject(int uniqueId, int personId, int stationId, int exerciseId,
-			string laterality, string resistance, UploadEncoderDataObject uo)
-	{
-		this.uniqueId = uniqueId;
-		this.personId = personId;
-		this.stationId = stationId;
-		this.exerciseId = exerciseId;
-		this.laterality = laterality;
-		this.resistance = resistance;
-		this.uo = uo;
-	}
+		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
 
-	public string ToSQLInsertString ()
-	{
-		return
-			"NULL, " +
-			personId.ToString() + ", " +
-			stationId.ToString() + ", " +
-			exerciseId.ToString() + ", " +
-			"\"" + laterality + "\", " +
-			"\"" + resistance + "\", " +
-			uo.repetitions.ToString() + ", " +
-			uo.numBySpeed.ToString() + ", " +
-			uo.lossBySpeed.ToString() + ", " +
-			"\"" + uo.rangeBySpeed.ToString() + "\", " +
-			"\"" + uo.vmeanBySpeed.ToString() + "\"," +
-			"\"" + uo.vmaxBySpeed.ToString() + "\"," +
-			"\"" + uo.pmeanBySpeed.ToString() + "\"," +
-			"\"" + uo.pmaxBySpeed.ToString() + "\"," +
-			uo.numByPower.ToString() + ", " +
-			uo.lossByPower.ToString() + ", " +
-			"\"" + uo.rangeByPower.ToString() + "\", " +
-			"\"" + uo.vmeanByPower.ToString() + "\"," +
-			"\"" + uo.vmaxByPower.ToString() + "\"," +
-			"\"" + uo.pmeanByPower.ToString() + "\"," +
-			"\"" + uo.pmaxByPower.ToString() + "\")";
-	}
+		dataStream.Close ();
 
-}
+		// Get the response.
+		WebResponse response;
+		if(! getWebResponse (request, out response, Catalog.GetString("Could not upload force sensor data.")))
+			return false;
 
-public class UploadEncoderDataObject
-{
-	private enum byTypes { SPEED, POWER }
+		// Display the status (will be 202, CREATED)
+		Console.WriteLine (((HttpWebResponse)response).StatusDescription);
 
-	public int repetitions;
-
-	//variables calculated BySpeed (by best mean speed)
-	public int numBySpeed;
-	public int lossBySpeed;
-	public string rangeBySpeed; //strings with . as decimal point
-	public string vmeanBySpeed;
-	public string vmaxBySpeed;
-	public string pmeanBySpeed;
-	public string pmaxBySpeed;
-
-	//variables calculated ByPower (by best mean power)
-	public int numByPower;
-	public int lossByPower;
-	public string rangeByPower; //strings with . as decimal point
-	public string vmeanByPower;
-	public string vmaxByPower;
-	public string pmeanByPower;
-	public string pmaxByPower;
-
-	public double  pmeanByPowerAsDouble;
-
-	private ArrayList curves;
-	private string eccon;
-
-	//constructor called after capture
-	public UploadEncoderDataObject(ArrayList curves, string eccon)
-	{
-		this.curves = curves;
-		this.eccon = eccon;
-	}
-
-	//returns false if on discarding, there are no curves
-	public bool InertialDiscardFirstN(int inertialDiscardFirstN)
-	{
-		if(eccon == "c")
-		{
-			if(curves.Count > inertialDiscardFirstN)
-				curves.RemoveRange(0, inertialDiscardFirstN);
-			else
-				return false;
-		} else {
-			if(curves.Count > inertialDiscardFirstN *2)
-				curves.RemoveRange(0, inertialDiscardFirstN *2);
-			else
-				return false;
-		}
+		// Clean up the streams.
+		dataStream.Close ();
+		response.Close ();
 
+		this.ResultMessage = "Force sensor data sent.";
 		return true;
 	}
 
-	public void Calcule()
-	{
-		if(eccon == "c")
-			calculeObjectCon (curves);
-		else
-			calculeObjectEccCon (curves);
-	}
-
-
-	private void calculeObjectCon (ArrayList curves)
-	{
-		repetitions = curves.Count;
-
-		int nSpeed = getBestRep(curves, byTypes.SPEED);
-		int nPower = getBestRep(curves, byTypes.POWER);
-
-		EncoderCurve curveBySpeed = (EncoderCurve) curves[nSpeed];
-		EncoderCurve curveByPower = (EncoderCurve) curves[nPower];
-
-		rangeBySpeed = Util.ConvertToPoint(curveBySpeed.Height);
-		rangeByPower = Util.ConvertToPoint(curveByPower.Height);
-
-		vmeanBySpeed = Util.ConvertToPoint(curveBySpeed.MeanSpeed);
-		vmeanByPower = Util.ConvertToPoint(curveByPower.MeanSpeed);
-		vmaxBySpeed = Util.ConvertToPoint(curveBySpeed.MaxSpeed);
-		vmaxByPower = Util.ConvertToPoint(curveByPower.MaxSpeed);
-
-		pmeanBySpeed = Util.ConvertToPoint(curveBySpeed.MeanPower);
-		pmeanByPower = Util.ConvertToPoint(curveByPower.MeanPower);
-		pmaxBySpeed = Util.ConvertToPoint(curveBySpeed.PeakPower);
-		pmaxByPower = Util.ConvertToPoint(curveByPower.PeakPower);
-
-		pmeanByPowerAsDouble = Convert.ToDouble(curveByPower.MeanPower);
-
-		//add +1 to show to user
-		numBySpeed = nSpeed + 1;
-		numByPower = nPower + 1;
-
-		lossBySpeed = getConLoss(curves, byTypes.SPEED);
-		lossByPower = getConLoss(curves, byTypes.POWER);
-	}
-
-	private void calculeObjectEccCon (ArrayList curves)
-	{
-		repetitions = curves.Count / 2;
-		EncoderSignal eSignal = new EncoderSignal(curves);
-
-		//this n is the n of the ecc curve
-		int nSpeed = eSignal.FindPosOfBestEccCon(0, Constants.MeanSpeed);
-		int nPower = eSignal.FindPosOfBestEccCon(0, Constants.MeanPower);
-
-		rangeBySpeed = Util.ConvertToPoint( eSignal.GetEccConMax(nSpeed, Constants.Range) );
-		rangeByPower = Util.ConvertToPoint( eSignal.GetEccConMax(nPower, Constants.Range) );
-
-		vmeanBySpeed = Util.ConvertToPoint( eSignal.GetEccConMean(nSpeed, Constants.MeanSpeed) );
-		vmeanByPower = Util.ConvertToPoint( eSignal.GetEccConMean(nPower, Constants.MeanSpeed) );
-		vmaxBySpeed = Util.ConvertToPoint( eSignal.GetEccConMax(nSpeed, Constants.MaxSpeed) );
-		vmaxByPower = Util.ConvertToPoint( eSignal.GetEccConMax(nPower, Constants.MaxSpeed) );
-
-		pmeanBySpeed = Util.ConvertToPoint( eSignal.GetEccConMean(nSpeed, Constants.MeanPower) );
-		pmeanByPower = Util.ConvertToPoint( eSignal.GetEccConMean(nPower, Constants.MeanPower) );
-		pmaxBySpeed = Util.ConvertToPoint( eSignal.GetEccConMax(nSpeed, Constants.PeakPower) );
-		pmaxByPower = Util.ConvertToPoint( eSignal.GetEccConMax(nPower, Constants.PeakPower) );
-
-		pmeanByPowerAsDouble = Convert.ToDouble( eSignal.GetEccConMean(nPower, Constants.MeanPower) );
-
-		//add +1 to show to user
-		numBySpeed = (nSpeed /2) + 1;
-		numByPower = (nPower /2) + 1;
-
-		//lossBySpeed = eSignal.GetEccConLoss(Constants.MeanSpeed);
-		//lossByPower = eSignal.GetEccConLoss(Constants.MeanPower);
-		lossBySpeed = eSignal.GetEccConLossByOnlyConPhase(Constants.MeanSpeed);
-		lossByPower = eSignal.GetEccConLossByOnlyConPhase(Constants.MeanPower);
-	}
-
-	//constructor called on SQL load SqliteJson.SelectTempEncoder()
-	public UploadEncoderDataObject(int repetitions,
-			int numBySpeed, int lossBySpeed, string rangeBySpeed,
-			string vmeanBySpeed, string vmaxBySpeed, string pmeanBySpeed, string pmaxBySpeed,
-			int numByPower, int lossByPower, string rangeByPower,
-			string vmeanByPower, string vmaxByPower, string pmeanByPower, string pmaxByPower)
-	{
-		this.repetitions = repetitions;
-		this.numBySpeed = numBySpeed;
-		this.lossBySpeed = lossBySpeed;
-		this.rangeBySpeed = rangeBySpeed;
-		this.vmeanBySpeed = vmeanBySpeed;
-		this.vmaxBySpeed = vmaxBySpeed;
-		this.pmeanBySpeed = pmeanBySpeed;
-		this.pmaxBySpeed = pmaxBySpeed;
-		this.numByPower = numByPower;
-		this.lossByPower = lossByPower;
-		this.rangeByPower = rangeByPower;
-		this.vmeanByPower = vmeanByPower;
-		this.vmaxByPower = vmaxByPower;
-		this.pmeanByPower = pmeanByPower;
-		this.pmaxByPower = pmaxByPower;
-	}
-
-	private int getBestRep(ArrayList curves, byTypes by)
-	{
-		int curveNum = 0;
-		int i = 0;
-		double highest = 0;
-
-		foreach (EncoderCurve curve in curves)
-		{
-			double compareTo = curve.MeanSpeedD;
-			if(by == byTypes.POWER)
-				compareTo = curve.MeanPowerD;
-
-			if(compareTo > highest)
-			{
-				highest = compareTo;
-				curveNum = i;
-			}
-			i ++;
-		}
-		return curveNum;
-	}
-
-	private int getConLoss(ArrayList curves, byTypes by)
-	{
-		double lowest = 100000;
-		double highest = 0;
-
-		//int i=0;
-		foreach (EncoderCurve curve in curves)
-		{
-			double compareTo = curve.MeanSpeedD;
-			if(by == byTypes.POWER)
-				compareTo = curve.MeanPowerD;
-
-			if(compareTo < lowest)
-				lowest = compareTo;
-			if(compareTo > highest)
-				highest = compareTo;
-
-			//LogB.Information(string.Format("Loss (con) of {0}; i: {1} is: {2}", by.ToString(), i++, Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest))));
-		}
-		return Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest));
-	}
-}
-
-public class Task
-{
-	public int Id;
-	public char Type; //initially 'P'arametrized or 'F'ree. Now all are 'P'
-	public int PersonId;
-	public int StationId;
-	public int ExerciseId;
-	public string ExerciseName;
-	public int Sets;
-	public int Nreps;
-	public float Load;
-	public float Speed;
-	public float PercentMaxSpeed;
-	public string Laterality;
-	public string Comment;
-
-	public Task()
-	{
-		Id = -1;
-		Comment = "";
-	}
-
-	public Task(int id, int personId, int stationId, int exerciseId, string exerciseName,
-			int sets, int nreps, float load, float speed, float percentMaxSpeed,
-			string laterality, string comment)
-	{
-		Type = 'P'; //parametrized
-
-		Id = id;
-		PersonId = personId;
-		StationId = stationId;
-		ExerciseId = exerciseId;
-		ExerciseName = exerciseName;
-		Sets = sets;
-		Nreps = nreps;
-		Load = load;
-		Speed = speed;
-		PercentMaxSpeed = percentMaxSpeed;
-		Laterality = laterality;
-		Comment = comment;
-	}
-
-	public override string ToString()
-	{
-		string sep = "";
-		string str = "";
-		if (Laterality == "R" || Laterality == "L")
-		{
-			string lateralityStr = Catalog.GetString("Right");
-			if (Laterality == "L")
-				lateralityStr = Catalog.GetString("Left");
-
-			str += sep + lateralityStr;
-			sep = "; ";
-		}
-		if (Load != -1)
-		{
-			str += sep + "Càrrega = " + Load.ToString() + " Kg";
-			sep = "; ";
-		}
-		if (Sets != -1)
-		{
-			str += sep + "Series = " + Sets.ToString();
-			sep = "; ";
-		}
-		if (Nreps != -1)
-		{
-			str += sep + "Repeticions = " + Nreps.ToString();
-			sep = "; ";
-		}
-		if (Speed != -1)
-		{
-			str += sep + "Velocitat = " + Speed.ToString() + " m/s";
-			sep = "; ";
-		}
-		if (PercentMaxSpeed != -1)
-		{
-			str += sep + "Velocitat = " + PercentMaxSpeed.ToString() + " %";
-			sep = "; ";
-		}
-		if (Comment != "")
-		{
-			str += "\n" + Comment;
-		}
-		return ExerciseName + ": " + str;
-	}
-}
-
-public class StationCount
-{
-	private string stationName;
-	private int tasksCount;
-
-	public StationCount()
-	{
-	}
-
-	public StationCount(string name, int count)
-	{
-		stationName = name;
-		tasksCount = count;
-	}
-
-	public override string ToString()
-	{
-		return stationName + " (" + tasksCount.ToString() + ")";
-	}
+	~JsonCompujump() {}
 }
