@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -39,8 +39,10 @@ public class JumpType : EventType
 	
 	public override bool FindIfIsPredefined() {
 		string [] predefinedTests = {
-			"Free", "SJ", "CMJ", "ABK", "Rocket",
-			"SJl", "CMJl", "slCMJleft", "slCMJright", "ABKl", "DJa", "DJna",
+			"Free", "SJ", "SJl",
+			"CMJ", "CMJl", "slCMJleft", "slCMJright",
+			"ABK", "ABKl", "DJa", "DJna",
+			"Rocket", "TakeOff", "TakeOffWeight",
 			"RJ(j)", "RJ(t)", "RJ(unlimited)",
 			"RJ(hexagon)", "triple jump"
 		};
