@@ -15,12 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
 using System.Collections.Generic; //List<T>
 using System.IO; //StringReader
+using Mono.Unix;
 	
 public class Networks
 {
@@ -152,3 +153,62 @@ public class NetworksSendMail
 	// another option will be use C-sharp methods, see:
 	// https://stackoverflow.com/questions/2825950/sending-email-with-attachments-from-c-attachments-arrive-as-part-1-2-in-thunde
 }
+
+/*
+ * on Networks to check if eth0 or wifi devices (interfaces) are on
+ * read to see if they are "up":
+ * /sys/class/net/eth0/operstate
+ * /sys/class/net/wlan.../operstate
+*/
+public class NetworksCheckDevices
+{
+	private List<string> devicesUp;
+	private string path = "/sys/class/net/";
+
+	public NetworksCheckDevices ()
+	{
+		devicesUp = new List<string>();
+
+		DirectoryInfo pathDirInfo = new DirectoryInfo(path);
+		DirectoryInfo [] subdirs = pathDirInfo.GetDirectories();
+
+		/*
+		 * check eth0, wlan*
+		 * but note our computers have interface enp2s0, wlp3s0
+		 * they are valid: https://www.freedesktop.org/wiki/Software/systemd/PredictableNetworkInterfaceNames/
+		 */
+		foreach (DirectoryInfo dir in subdirs)
+			if( ( dir.Name.StartsWith("eth") || dir.Name.StartsWith("en") || dir.Name.StartsWith("wl") ) && checkDevice(dir.Name))
+				devicesUp.Add(dir.Name);
+	}
+
+	private bool checkDevice(string device)
+	{
+		string filename = path + device + "/operstate";
+		if(File.Exists(filename))
+		{
+			List<string> l = Util.ReadFileAsStringList(filename);
+			foreach(string str in l)
+				if(str.Contains("up"))
+					return true;
+		}
+
+		return false;
+	}
+
+	public override string ToString()
+	{
+		if(devicesUp.Count == 0)
+			return Catalog.GetString("No active Internet devices.");
+		else {
+			string str = Catalog.GetString("Active Internet devices:");
+			string sep = " ";
+			foreach(string device in devicesUp)
+			{
+				str += sep + device;
+				sep = ", ";
+			}
+			return str;
+		}
+	}
+}
