@@ -28,7 +28,7 @@ public class Preferences
 	 * these are sent to preferences window
 	 */
 
-	//appearance tab
+	//main tab
 	public enum MaximizedTypes { NO, YES, YESUNDECORATED};
 	public MaximizedTypes maximized;
 	public bool personWinHide;
@@ -36,9 +36,22 @@ public class Preferences
 	//public string colorBackgroundString = "#0e1e46";
 	public enum MenuTypes { ALL, TEXT, ICONS};
 	public MenuTypes menuType;
-	public string colorBackgroundString;
+	public string colorBackgroundString; //"" means system color (do not do nothing)
 	public bool colorBackgroundIsDark; //this is assigned when colorBackgroundString changes. And this is used by the rest of the program. Not stored on SQL.
+	public bool colorBackgroundOsColor;
 	public bool logoAnimatedShow;
+	public enum FontTypes { Courier, Helvetica};
+	public FontTypes fontType;
+
+	public string GetFontTypeWithSize(int size) {
+		return string.Format("{0} {1}", fontType, size);
+	}
+
+	public bool loadLastSessionAtStart;
+	public int lastSessionID;
+	public bool loadLastModeAtStart;
+	public Constants.Menuitem_modes lastMode;
+
 
 	public enum UnitsEnum { METRIC, IMPERIAL };
 	public UnitsEnum units;
@@ -53,7 +66,6 @@ public class Preferences
 	public bool showAngle;
 	public bool showQIndex;
 	public bool showDjIndex;
-	public bool jumpsDjGraphHeights;
 	public bool weightStatsPercent;		//AKA weightPercentPreferred
 	public bool heightPreferred;
 	public bool metersSecondsPreferred;
@@ -174,6 +186,11 @@ public class Preferences
 	public Constants.MultimediaStorage multimediaStorage;
 	public string databaseVersion;
 
+	//jumps
+	public bool jumpsFVProfileOnlyBestInWeight;
+	public bool jumpsFVProfileShowFullGraph;
+	public bool jumpsEvolutionOnlyBestInSession;
+
 	//encoder
 	public Constants.EncoderAutoSaveCurve encoderAutoSaveCurve;
 	public int encoderAutoSaveCurveBestNValue;
@@ -449,6 +466,11 @@ public class Preferences
 		return sNew;
 	}
 
+	public Gdk.Color colorBackground
+	{
+		get { return UtilGtk.ColorParse(colorBackgroundString); }
+	}
+
 	~Preferences() {}
 	   
 }
