@@ -47,13 +47,13 @@ class SqlitePerson : Sqlite
 			"countryID INT, " + 
 			"description TEXT, " +	
 			"future1 TEXT, " + //rfid
-			"future2 TEXT, " +	
+			"future2 TEXT, " + //clubID
 			"serverUniqueID INT ) ";
 		dbcmd.ExecuteNonQuery();
 	 }
 
 	public static int Insert(bool dbconOpened, string uniqueID, string name, string sex, DateTime dateBorn, 
-			int race, int countryID, string description, string future1, int serverUniqueID)
+			int race, int countryID, string description, string future1, string future2, int serverUniqueID)
 	{
 		LogB.SQL("going to insert");
 		if(! dbconOpened)
@@ -68,7 +68,7 @@ class SqlitePerson : Sqlite
 		string myString = "INSERT INTO " + Constants.PersonTable + 
 			" (uniqueID, name, sex, dateBorn, race, countryID, description, future1, future2, serverUniqueID) VALUES (" + uniqueID + ", \"" +
 			name + "\", \"" + sex + "\", \"" + UtilDate.ToSql(dateBorn) + "\", " + 
-			race + ", " + countryID + ", \"" + description + "\", \"" + future1 + "\", \"\", " + serverUniqueID + ")";
+			race + ", " + countryID + ", \"" + description + "\", \"" + future1 + "\", \"" + future2 + "\", " + serverUniqueID + ")";
 		
 		dbcmd.CommandText = myString;
 		LogB.SQL(dbcmd.CommandText.ToString());
@@ -94,8 +94,8 @@ class SqlitePerson : Sqlite
 	public static Person Select(int uniqueID) {
 		return Select(false, " WHERE uniqueID = " + uniqueID);
 	}
-	public static Person SelectByName(string name) {
-		return Select(false, " WHERE name = \"" + name + "\"");
+	public static Person SelectByName(bool dbconOpened, string name) {
+		return Select(dbconOpened, " WHERE name = \"" + name + "\"");
 	}
 	public static Person SelectByRFID(string rfid) {
 		return Select(false, " WHERE future1 = \"" + rfid + "\"");
@@ -124,6 +124,7 @@ class SqlitePerson : Sqlite
 					Convert.ToInt32(reader[5].ToString()), //countryID
 					reader[6].ToString(), 			//description
 					reader[7].ToString(), 			//future1: rfid
+					reader[8].ToString(), 			//future2: clubID
 					Convert.ToInt32(reader[9].ToString()) //serverUniqueID
 					);
 		}
@@ -268,6 +269,7 @@ finishForeach:
 						Convert.ToInt32(reader2[5].ToString()), //countryID
 						reader2[6].ToString(), 			//description
 						reader2[7].ToString(), 			//future1: rfid
+						reader2[8].ToString(), 			//future2: clubID
 						Convert.ToInt32(reader2[9].ToString()) //serverUniqueID
 						);
 				arrayReturn.Add(p);
@@ -293,6 +295,8 @@ finishForeach:
 		ArrayList arrayMCs = new ArrayList(2);
 		ArrayList arrayEncS = new ArrayList(2);
 		ArrayList arrayEncC = new ArrayList(2);
+		ArrayList arrayForce = new ArrayList(2);
+		ArrayList arrayRunEncoder = new ArrayList(2);
 		
 		string tps = Constants.PersonSessionTable;
 	
@@ -417,7 +421,29 @@ finishForeach:
 			arrayEncC.Add ( reader[0].ToString() + ":" + reader[1].ToString() );
 		}
 		reader.Close();
-	
+
+		//forceSensor
+		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.ForceSensorTable + " WHERE personID = " + personID +
+			" GROUP BY sessionID ORDER BY sessionID";
+		LogB.SQL(dbcmd.CommandText.ToString());
+
+		reader = dbcmd.ExecuteReader();
+		while(reader.Read()) {
+			arrayForce.Add ( reader[0].ToString() + ":" + reader[1].ToString() );
+		}
+		reader.Close();
+
+		//runEncoder
+		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.RunEncoderTable + " WHERE personID = " + personID +
+			" GROUP BY sessionID ORDER BY sessionID";
+		LogB.SQL(dbcmd.CommandText.ToString());
+
+		reader = dbcmd.ExecuteReader();
+		while(reader.Read()) {
+			arrayRunEncoder.Add ( reader[0].ToString() + ":" + reader[1].ToString() );
+		}
+		reader.Close();
+
 
 
 		Sqlite.Close();
@@ -433,6 +459,8 @@ finishForeach:
 		string tempMCs;
 		string tempEncS;
 		string tempEncC;
+		string tempForce;
+		string tempRunEncoder;
 		bool found; 	//using found because a person can be loaded in a session 
 				//but whithout having done any event yet
 
@@ -448,6 +476,8 @@ finishForeach:
 			tempMCs = "";
 			tempEncS = "";
 			tempEncC = "";
+			tempForce = "";
+			tempRunEncoder = "";
 			found = false;
 			
 			foreach (string myJumps in arrayJumps) {
@@ -531,6 +561,24 @@ finishForeach:
 				}
 			}
 
+			foreach (string f in arrayForce) {
+				string [] myStr = f.Split(new char[] {':'});
+				if(myStrSession[0] == myStr[0]) {
+					tempForce = myStr[1];
+					found = true;
+					break;
+				}
+			}
+
+			foreach (string re in arrayRunEncoder) {
+				string [] myStr = re.Split(new char[] {':'});
+				if(myStrSession[0] == myStr[0]) {
+					tempRunEncoder = myStr[1];
+					found = true;
+					break;
+				}
+			}
+
 
 			//if has events, write it's data
 			if (found) {
@@ -539,7 +587,8 @@ finishForeach:
 						tempJumpsRj + ":" + tempRuns + ":" + 		//jumpsRj, Runs
 						tempRunsInterval + ":" + tempRTs + ":" + 	//runsInterval, Reaction times
 						tempPulses + ":" + tempMCs + ":" +		//pulses, MultiChronopic
-						tempEncS + ":" + tempEncC			//encoder signal, encoder curve
+						tempEncS + ":" + tempEncC + ":" + 		//encoder signal, encoder curve
+						tempForce + ":" + tempRunEncoder 		//forceSensor, runEncoder
 						);
 			}
 		}
@@ -583,7 +632,8 @@ finishForeach:
 			"\", race = " + myPerson.Race +
 			", countryID = " + myPerson.CountryID +
 			", description = \"" + myPerson.Description +
-			"\", future1 = \"" + myPerson.Future1 + 			//rfid
+			"\", future1 = \"" + myPerson.Future1 + 		//rfid
+			"\", future2 = \"" + myPerson.Future2 + 		//clubID
 			"\", serverUniqueID = " + myPerson.ServerUniqueID +
 			" WHERE uniqueID == " + myPerson.UniqueID;
 		LogB.SQL(dbcmd.CommandText.ToString());
