@@ -30,10 +30,14 @@ class SqlitePreferences : Sqlite
 	public const string UnitsStr = "units";
 	public const string MenuType = "menuType";
 	public const string ColorBackground = "colorBackground";
+	public const string ColorBackgroundOsColor = "colorBackgroundOsColor";
 	public const string LogoAnimatedShow = "logoAnimatedShow";
+	public const string FontsOnGraphs = "fontsOnGraphs";
 
 	//contacts
-	public const string JumpsDjGraphHeights = "jumpsDjGraphHeights";
+	public const string JumpsFVProfileOnlyBestInWeight = "jumpsFVProfileOnlyBestInWeight";
+	public const string JumpsFVProfileShowFullGraph = "jumpsFVProfileShowFullGraph";
+	public const string JumpsEvolutionOnlyBestInSession = "jumpsEvolutionOnlyBestInSession";
 
 	//encoder
 	public const string EncoderCaptureInfinite = "encoderCaptureInfinite";
@@ -93,6 +97,12 @@ class SqlitePreferences : Sqlite
 	//advanced
 	public const string ImporterPythonVersion = "importerPythonVersion";
 
+	//session
+	public const string LoadLastSessionAtStart = "loadLastSessionAtStart";
+	public const string LastSessionID = "lastSessionID";
+	public const string LoadLastModeAtStart = "loadLastModeAtStart";
+	public const string LastMode = "lastMode";
+
 	protected internal static new void createTable()
 	{
 		dbcmd.CommandText = 
@@ -124,9 +134,11 @@ class SqlitePreferences : Sqlite
 				Insert (MenuType, Preferences.MenuTypes.ALL.ToString(), dbcmdTr);
 				Insert (LogoAnimatedShow, "True", dbcmdTr);
 				Insert (ColorBackground, "#0e1e46", dbcmdTr);
+				Insert (ColorBackgroundOsColor, "False", dbcmdTr);
+				Insert (FontsOnGraphs, Preferences.FontTypes.Helvetica.ToString(), dbcmdTr);
 				Insert (UnitsStr, Preferences.UnitsEnum.METRIC.ToString(), dbcmdTr);
 				Insert (EncoderCaptureInfinite, "False", dbcmdTr);
-				Insert ("encoderCaptureShowOnlyBars", "False", dbcmdTr);
+				Insert ("encoderCaptureShowOnlyBars", "True", dbcmdTr);
 				Insert ("encoderCaptureShowNRepetitions", "-1", dbcmdTr);
 				Insert ("digitsNumber", "3", dbcmdTr);
 				Insert ("showPower", "True", dbcmdTr);
@@ -135,7 +147,6 @@ class SqlitePreferences : Sqlite
 				Insert ("showAngle", "False", dbcmdTr); //for treeviewjumps
 				Insert ("showQIndex", "False", dbcmdTr); //for treeviewJumps
 				Insert ("showDjIndex", "False", dbcmdTr); //for treeviewJumps
-				Insert (JumpsDjGraphHeights, "True", dbcmdTr);
 				Insert ("simulated", "True", dbcmdTr);
 				Insert ("weightStatsPercent", "False", dbcmdTr);
 				Insert ("askDeletion", "True", dbcmdTr);
@@ -176,6 +187,11 @@ class SqlitePreferences : Sqlite
 
 				Insert ("multimediaStorage", Constants.MultimediaStorage.BYSESSION.ToString(), dbcmdTr);
 
+				//jumps
+				SqlitePreferences.Insert (JumpsFVProfileOnlyBestInWeight, "True", dbcmdTr);
+				SqlitePreferences.Insert (JumpsFVProfileShowFullGraph, "True", dbcmdTr);
+				SqlitePreferences.Insert (JumpsEvolutionOnlyBestInSession, "False", dbcmdTr);
+
 				//encoder
 				Insert ("encoderCaptureTime", "60", dbcmdTr);
 				Insert ("encoderCaptureInactivityEndTime", "3", dbcmdTr);
@@ -284,7 +300,12 @@ class SqlitePreferences : Sqlite
 				Insert ("muteLogs", "False", dbcmdTr);
 				Insert (ImporterPythonVersion, Preferences.pythonVersionEnum.Python.ToString(), dbcmdTr);
 
-				
+				//session
+				Insert (LoadLastSessionAtStart, "True", dbcmdTr);
+				Insert (LastSessionID, "-1", dbcmdTr);
+				Insert (LoadLastModeAtStart, "True", dbcmdTr);
+				Insert (LastMode, Constants.Menuitem_modes.UNDEFINED.ToString(), dbcmdTr);
+
 				//removed on 1.37
 				//Insert ("encoderConfiguration", new EncoderConfiguration().ToStringOutput(EncoderConfiguration.Outputs.SQL), dbcmdTr);
 
@@ -311,6 +332,10 @@ class SqlitePreferences : Sqlite
 		//Sqlite.Close();
 	}
 
+	public static void Update(string myName, bool myValue, bool dbconOpened)
+	{
+		Update(myName, myValue.ToString(), dbconOpened);
+	}
 	public static void Update(string myName, string myValue, bool dbconOpened)
 	{
 		if(! dbconOpened)
@@ -392,8 +417,13 @@ class SqlitePreferences : Sqlite
 				preferences.colorBackgroundString = reader[1].ToString();
 				preferences.colorBackgroundIsDark = UtilGtk.ColorIsDark(reader[1].ToString());
 			}
+			else if(reader[0].ToString() == ColorBackgroundOsColor)
+				preferences.colorBackgroundOsColor = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == LogoAnimatedShow)
 				preferences.logoAnimatedShow = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == FontsOnGraphs)
+				preferences.fontType = (Preferences.FontTypes)
+					Enum.Parse(typeof(Preferences.FontTypes), reader[1].ToString());
 			else if(reader[0].ToString() == UnitsStr)
 				preferences.units = (Preferences.UnitsEnum)
 					Enum.Parse(typeof(Preferences.UnitsEnum), reader[1].ToString());
@@ -415,14 +445,19 @@ class SqlitePreferences : Sqlite
 				preferences.showQIndex = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showDjIndex")
 				preferences.showDjIndex = reader[1].ToString() == "True";
-			else if(reader[0].ToString() == JumpsDjGraphHeights)
-				preferences.jumpsDjGraphHeights = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "weightStatsPercent")
 				preferences.weightStatsPercent = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "heightPreferred")
 				preferences.heightPreferred = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "metersSecondsPreferred")
 				preferences.metersSecondsPreferred = reader[1].ToString() == "True";
+			//jumps
+			else if(reader[0].ToString() == JumpsFVProfileOnlyBestInWeight)
+				preferences.jumpsFVProfileOnlyBestInWeight = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == JumpsFVProfileShowFullGraph)
+				preferences.jumpsFVProfileShowFullGraph = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == JumpsEvolutionOnlyBestInSession)
+				preferences.jumpsEvolutionOnlyBestInSession = reader[1].ToString() == "True";
 			//encoder capture
 			else if(reader[0].ToString() == "encoderCaptureTime")
 				preferences.encoderCaptureTime = Convert.ToInt32(reader[1].ToString());
@@ -653,6 +688,22 @@ class SqlitePreferences : Sqlite
 					Enum.Parse(typeof(Preferences.pythonVersionEnum), reader[1].ToString());
 			else if(reader[0].ToString() == "databaseVersion")
 				preferences.databaseVersion = reader[1].ToString();
+
+			//session
+			else if(reader[0].ToString() == LoadLastSessionAtStart)
+				preferences.loadLastSessionAtStart = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == LastSessionID)
+			{
+				if(Util.IsNumber(reader[1].ToString(), false))
+					preferences.lastSessionID = Convert.ToInt32(reader[1].ToString());
+				else
+					preferences.lastSessionID = -1;
+			}
+			else if(reader[0].ToString() == LoadLastModeAtStart)
+				preferences.loadLastModeAtStart = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == LastMode)
+				preferences.lastMode = (Constants.Menuitem_modes)
+					Enum.Parse(typeof(Constants.Menuitem_modes), reader[1].ToString());
 		}
 
 		reader.Close();
