@@ -472,9 +472,13 @@ public class Util
 	}
 	//new code (2019 ...) sends and returns doubles
 	public static double GetHeightInCentimeters (double tv) {
-		// s = 4.9 * (tv/2)^2
+		// s = 100 * 4.9 * (tv/2)^2
 		return 100 * 4.9 * Math.Pow( tv / 2.0 , 2 );
 	}
+	public static double GetHeightInMeters (double tv) {
+		// s = 4.9 * (tv/2)^2
+		return 4.9 * Math.Pow( tv / 2.0 , 2 );
+	}
 	
 	public static double WeightFromKgToPercent (double jumpKg, double personKg) {
 		return (double) jumpKg *100 / (double) personKg;
@@ -739,6 +743,11 @@ public class Util
 
 		return initialSpeed;
 	}
+
+	public static double GetAverageImpulsionSpeed(double jumpHeightM)
+	{
+		return Math.Sqrt( (9.81 * jumpHeightM) / 2);
+	}
 	
 	public static double GetDjPower (double tc, double tf, double mass, double fallHeight) 
 	{
@@ -1238,12 +1247,16 @@ public class Util
 
 	/********** start of rfid paths ************/
 
+	/*
+	   Not used anymore, read: src/gui/networks.cs
+
 	public static string GetRFIDCaptureScript() {
 		return Path.Combine(GetPrefixDir(), "bin/chronojump_rfid_capture.py");
 	}
 	public static string GetRFIDCapturedFile() {
 		return Path.Combine(Path.GetTempPath(), "chronojump_rfid.txt");
 	}
+	*/
 
 
 	/********** end of rfid paths ************/
@@ -1472,7 +1485,23 @@ public class Util
 			//maybe R is not installed
 		}
 	}
-	
+
+	public static bool OpenFolder(string url)
+	{
+		LogB.Information("OpenFolder: " + url);
+		try {
+			//more system specific methods on: https://stackoverflow.com/a/49664847/12366369
+			//also if do not work, check about relative paths here: https://stackoverflow.com/questions/52599105/c-sharp-under-linux-process-start-exception-of-no-such-file-or-directory
+			if(operatingSystem == UtilAll.OperatingSystems.LINUX)
+				System.Diagnostics.Process.Start("xdg-open", url);
+			else
+				System.Diagnostics.Process.Start(url);
+
+			return true;
+		} catch {
+			return false;
+		}
+	}
 
 /*
  * currently not used, we copy the assemblies now
