@@ -52,14 +52,32 @@ public class UtilDate
 			UtilAll.DigitsCreate(dt.Second,2);
 	}
 
+	//returns YYYY-MM-DD hh:mm:ss
+	public static string GetDatetimePrint (DateTime dt)
+	{
+		return UtilAll.DigitsCreate(dt.Year,4) + "-" +
+			UtilAll.DigitsCreate(dt.Month,2) + "-" +
+			UtilAll.DigitsCreate(dt.Day,2) + " " +
+			UtilAll.DigitsCreate(dt.Hour,2) + ":" +
+			UtilAll.DigitsCreate(dt.Minute,2) + ":" +
+			UtilAll.DigitsCreate(dt.Second,2);
+	}
+
 	//records date & time, useful to backup database without having strange chars on filename
 	//used also on SQL when time wants to be stored also
 	public static DateTime FromFile (string s)
 	{
-		//TODO: check possible errors
 		string [] allFull = s.Split(new char[] {'_'});
+
+		if(allFull.Length != 2)
+			return DateTime.MinValue;
+
 		string [] dateFull = allFull[0].Split(new char[] {'-'});
 		string [] timeFull = allFull[1].Split(new char[] {'-'});
+
+		if(dateFull.Length != 3 || timeFull.Length != 3)
+			return DateTime.MinValue;
+
 		return new DateTime(
 				Convert.ToInt32(dateFull[0]),
 				Convert.ToInt32(dateFull[1]),
