@@ -602,6 +602,16 @@ public class UtilGtk
 		}
 	}
 
+	public static void WindowColor(Gtk.Window w, Gdk.Color color)
+	{
+		w.ModifyBg(StateType.Normal, color);
+	}
+
+	public static void DialogColor(Gtk.Dialog d, Gdk.Color color)
+	{
+		d.ModifyBg(StateType.Normal, color);
+	}
+
 	public static void ViewportColor(Gtk.Viewport v, Gdk.Color color)
 	{
 		v.ModifyBg(StateType.Normal, color);
@@ -1019,4 +1029,14 @@ public class UtilGtk
 		pixmap.DrawPolygon(pen, true, points);
 	}
 
+	public static void FindPangoFonts(Gtk.DrawingArea drawingarea)
+	{
+		LogB.Information("Available Pango fonts:");
+		foreach(Pango.FontFamily ff in drawingarea.PangoContext.Families)
+		{
+			LogB.Information(ff.Name);
+			foreach(Pango.FontFace faces in ff.Faces)
+				LogB.Information("- " + faces.FaceName);
+		}
+	}
 }
